@@ -18,9 +18,10 @@
  */
 package org.apache.iceberg.util;
 
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+
 import java.io.IOException;
 import java.util.Arrays;
-import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.Test;
 
 public class TestExceptionUtil {
@@ -36,7 +37,7 @@ public class TestExceptionUtil {
     CustomCheckedException exc = new CustomCheckedException("test");
     Exception suppressedOne = new Exception("test catch suppression");
     RuntimeException suppressedTwo = new RuntimeException("test finally suppression");
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 ExceptionUtil.runSafely(
                     () -> {
@@ -62,7 +63,7 @@ public class TestExceptionUtil {
     CustomCheckedException exc = new CustomCheckedException("test");
     Exception suppressedOne = new Exception("test catch suppression");
     RuntimeException suppressedTwo = new RuntimeException("test finally suppression");
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 ExceptionUtil.runSafely(
                     (ExceptionUtil.Block<
@@ -91,7 +92,7 @@ public class TestExceptionUtil {
     CustomCheckedException exc = new CustomCheckedException("test");
     Exception suppressedOne = new Exception("test catch suppression");
     RuntimeException suppressedTwo = new RuntimeException("test finally suppression");
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 ExceptionUtil.runSafely(
                     (ExceptionUtil.Block<
@@ -121,7 +122,7 @@ public class TestExceptionUtil {
     RuntimeException exc = new RuntimeException("test");
     Exception suppressedOne = new Exception("test catch suppression");
     CustomCheckedException suppressedTwo = new CustomCheckedException("test finally suppression");
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 ExceptionUtil.runSafely(
                     () -> {
