@@ -186,54 +186,6 @@ public class VectorizedColumnIterator extends BaseColumnIterator {
     }
   }
 
-  /** @deprecated will be removed in 1.4.0 */
-  @Deprecated
-  public class IntBackedDecimalBatchReader extends BatchReader {
-    @Override
-    protected int nextBatchOf(
-        final FieldVector vector,
-        final int expectedBatchSize,
-        final int numValsInVector,
-        final int typeWidth,
-        NullabilityHolder holder) {
-      return vectorizedPageIterator
-          .intBackedDecimalPageReader()
-          .nextBatch(vector, expectedBatchSize, numValsInVector, typeWidth, holder);
-    }
-  }
-
-  /** @deprecated will be removed in 1.4.0 */
-  @Deprecated
-  public class LongBackedDecimalBatchReader extends BatchReader {
-    @Override
-    protected int nextBatchOf(
-        final FieldVector vector,
-        final int expectedBatchSize,
-        final int numValsInVector,
-        final int typeWidth,
-        NullabilityHolder holder) {
-      return vectorizedPageIterator
-          .longBackedDecimalPageReader()
-          .nextBatch(vector, expectedBatchSize, numValsInVector, typeWidth, holder);
-    }
-  }
-
-  /** @deprecated will be removed in 1.4.0 */
-  @Deprecated
-  public class FixedLengthDecimalBatchReader extends BatchReader {
-    @Override
-    protected int nextBatchOf(
-        final FieldVector vector,
-        final int expectedBatchSize,
-        final int numValsInVector,
-        final int typeWidth,
-        NullabilityHolder holder) {
-      return vectorizedPageIterator
-          .fixedLengthDecimalPageReader()
-          .nextBatch(vector, expectedBatchSize, numValsInVector, typeWidth, holder);
-    }
-  }
-
   public class FixedSizeBinaryBatchReader extends BatchReader {
     @Override
     protected int nextBatchOf(
@@ -262,6 +214,10 @@ public class VectorizedColumnIterator extends BaseColumnIterator {
     }
   }
 
+  /**
+   * @deprecated since 1.7.0, will be removed in 1.8.0.
+   */
+  @Deprecated
   public class FixedWidthTypeBinaryBatchReader extends BatchReader {
     @Override
     protected int nextBatchOf(
@@ -318,24 +274,6 @@ public class VectorizedColumnIterator extends BaseColumnIterator {
     return new DoubleBatchReader();
   }
 
-  /** @deprecated will be removed in 1.4.0 */
-  @Deprecated
-  public IntBackedDecimalBatchReader intBackedDecimalBatchReader() {
-    return new IntBackedDecimalBatchReader();
-  }
-
-  /** @deprecated will be removed in 1.4.0 */
-  @Deprecated
-  public LongBackedDecimalBatchReader longBackedDecimalBatchReader() {
-    return new LongBackedDecimalBatchReader();
-  }
-
-  /** @deprecated will be removed in 1.4.0 */
-  @Deprecated
-  public FixedLengthDecimalBatchReader fixedLengthDecimalBatchReader() {
-    return new FixedLengthDecimalBatchReader();
-  }
-
   public FixedSizeBinaryBatchReader fixedSizeBinaryBatchReader() {
     return new FixedSizeBinaryBatchReader();
   }
@@ -344,6 +282,10 @@ public class VectorizedColumnIterator extends BaseColumnIterator {
     return new VarWidthTypeBatchReader();
   }
 
+  /**
+   * @deprecated since 1.7.0, will be removed in 1.8.0.
+   */
+  @Deprecated
   public FixedWidthTypeBinaryBatchReader fixedWidthTypeBinaryBatchReader() {
     return new FixedWidthTypeBinaryBatchReader();
   }
