@@ -19,16 +19,17 @@
 package org.apache.iceberg.arrow.vectorized.parquet;
 
 import java.nio.ByteBuffer;
+import java.nio.ByteOrder;
 import org.apache.arrow.memory.ArrowBuf;
 import org.apache.arrow.vector.BaseVariableWidthVector;
 import org.apache.arrow.vector.BitVector;
 import org.apache.arrow.vector.BitVectorHelper;
-import org.apache.arrow.vector.DecimalVector;
 import org.apache.arrow.vector.FieldVector;
 import org.apache.arrow.vector.FixedSizeBinaryVector;
 import org.apache.arrow.vector.IntVector;
 import org.apache.arrow.vector.VarBinaryVector;
 import org.apache.iceberg.arrow.vectorized.NullabilityHolder;
+import org.apache.iceberg.parquet.ParquetUtil;
 import org.apache.iceberg.parquet.ValuesAsBytesReader;
 import org.apache.parquet.column.Dictionary;
 
@@ -447,6 +448,55 @@ public final class VectorizedParquetDefinitionLevelReader
     }
   }
 
+  class TimestampInt96Reader extends BaseReader {
+    @Override
+    protected void nextVal(
+        FieldVector vector,
+        int idx,
+        ValuesAsBytesReader valuesReader,
+        int typeWidth,
+        byte[] byteArray) {
+      // 8 bytes (time of day nanos) + 4 bytes(julianDay) = 12 bytes
+      ByteBuffer buffer = valuesReader.getBuffer(12).order(ByteOrder.LITTLE_ENDIAN);
+      long timestampInt96 = ParquetUtil.extractTimestampInt96(buffer);
+      vector.getDataBuffer().setLong((long) idx * typeWidth, timestampInt96);
+    }
+
+    @Override
+    protected void nextDictEncodedVal(
+        FieldVector vector,
+        int idx,
+        VectorizedDictionaryEncodedParquetValuesReader reader,
+        int numValuesToRead,
+        Dictionary dict,
+        NullabilityHolder nullabilityHolder,
+        int typeWidth,
+        Mode mode) {
+      switch (mode) {
+        case RLE:
+          reader
+              .timestampInt96DictEncodedReader()
+              .nextBatch(vector, idx, numValuesToRead, dict, nullabilityHolder, typeWidth);
+          break;
+        case PACKED:
+          ByteBuffer buffer =
+              dict.decodeToBinary(reader.readInteger())
+                  .toByteBuffer()
+                  .order(ByteOrder.LITTLE_ENDIAN);
+          long timestampInt96 = ParquetUtil.extractTimestampInt96(buffer);
+          vector.getDataBuffer().setLong(idx, timestampInt96);
+          break;
+        default:
+          throw new UnsupportedOperationException(
+              "Unsupported mode for timestamp int96 reader: " + mode);
+      }
+    }
+  }
+
+  /**
+   * @deprecated since 1.7.0, will be removed in 1.8.0.
+   */
+  @Deprecated
   class FixedWidthBinaryReader extends BaseReader {
     @Override
     protected void nextVal(
@@ -485,39 +535,6 @@ public final class VectorizedParquetDefinitionLevelReader
     }
   }
 
-  class FixedLengthDecimalReader extends BaseReader {
-    @Override
-    protected void nextVal(
-        FieldVector vector,
-        int idx,
-        ValuesAsBytesReader valuesReader,
-        int typeWidth,
-        byte[] byteArray) {
-      valuesReader.getBuffer(typeWidth).get(byteArray, 0, typeWidth);
-      DecimalVectorUtil.setBigEndian((DecimalVector) vector, idx, byteArray);
-    }
-
-    @Override
-    protected void nextDictEncodedVal(
-        FieldVector vector,
-        int idx,
-        VectorizedDictionaryEncodedParquetValuesReader reader,
-        int numValuesToRead,
-        Dictionary dict,
-        NullabilityHolder nullabilityHolder,
-        int typeWidth,
-        Mode mode) {
-      if (Mode.RLE.equals(mode)) {
-        reader
-            .fixedLengthDecimalDictEncodedReader()
-            .nextBatch(vector, idx, numValuesToRead, dict, nullabilityHolder, typeWidth);
-      } else if (Mode.PACKED.equals(mode)) {
-        byte[] bytes = dict.decodeToBinary(reader.readInteger()).getBytesUnsafe();
-        DecimalVectorUtil.setBigEndian((DecimalVector) vector, idx, bytes);
-      }
-    }
-  }
-
   class FixedSizeBinaryReader extends BaseReader {
     @Override
     protected void nextVal(
@@ -598,68 +615,6 @@ public final class VectorizedParquetDefinitionLevelReader
     }
   }
 
-  class IntBackedDecimalReader extends BaseReader {
-    @Override
-    protected void nextVal(
-        FieldVector vector,
-        int idx,
-        ValuesAsBytesReader valuesReader,
-        int typeWidth,
-        byte[] byteArray) {
-      ((DecimalVector) vector).set(idx, valuesReader.getBuffer(Integer.BYTES).getInt());
-    }
-
-    @Override
-    protected void nextDictEncodedVal(
-        FieldVector vector,
-        int idx,
-        VectorizedDictionaryEncodedParquetValuesReader reader,
-        int numValuesToRead,
-        Dictionary dict,
-        NullabilityHolder nullabilityHolder,
-        int typeWidth,
-        Mode mode) {
-      if (Mode.RLE.equals(mode)) {
-        reader
-            .intBackedDecimalDictEncodedReader()
-            .nextBatch(vector, idx, numValuesToRead, dict, nullabilityHolder, typeWidth);
-      } else if (Mode.PACKED.equals(mode)) {
-        ((DecimalVector) vector).set(idx, dict.decodeToInt(reader.readInteger()));
-      }
-    }
-  }
-
-  class LongBackedDecimalReader extends BaseReader {
-    @Override
-    protected void nextVal(
-        FieldVector vector,
-        int idx,
-        ValuesAsBytesReader valuesReader,
-        int typeWidth,
-        byte[] byteArray) {
-      ((DecimalVector) vector).set(idx, valuesReader.getBuffer(Long.BYTES).getLong());
-    }
-
-    @Override
-    protected void nextDictEncodedVal(
-        FieldVector vector,
-        int idx,
-        VectorizedDictionaryEncodedParquetValuesReader reader,
-        int numValuesToRead,
-        Dictionary dict,
-        NullabilityHolder nullabilityHolder,
-        int typeWidth,
-        Mode mode) {
-      if (Mode.RLE.equals(mode)) {
-        reader
-            .longBackedDecimalDictEncodedReader()
-            .nextBatch(vector, idx, numValuesToRead, dict, nullabilityHolder, typeWidth);
-      } else if (Mode.PACKED.equals(mode)) {
-        ((DecimalVector) vector).set(idx, dict.decodeToLong(reader.readInteger()));
-      }
-    }
-  }
-
   class BooleanReader extends BaseReader {
     @Override
     protected void nextVal(
@@ -777,12 +732,16 @@ public final class VectorizedParquetDefinitionLevelReader
     return new TimestampMillisReader();
   }
 
-  FixedWidthBinaryReader fixedWidthBinaryReader() {
-    return new FixedWidthBinaryReader();
+  TimestampInt96Reader timestampInt96Reader() {
+    return new TimestampInt96Reader();
   }
 
-  FixedLengthDecimalReader fixedLengthDecimalReader() {
-    return new FixedLengthDecimalReader();
+  /**
+   * @deprecated since 1.7.0, will be removed in 1.8.0.
+   */
+  @Deprecated
+  FixedWidthBinaryReader fixedWidthBinaryReader() {
+    return new FixedWidthBinaryReader();
   }
 
   FixedSizeBinaryReader fixedSizeBinaryReader() {
@@ -793,14 +752,6 @@ public final class VectorizedParquetDefinitionLevelReader
     return new VarWidthReader();
   }
 
-  IntBackedDecimalReader intBackedDecimalReader() {
-    return new IntBackedDecimalReader();
-  }
-
-  LongBackedDecimalReader longBackedDecimalReader() {
-    return new LongBackedDecimalReader();
-  }
-
   BooleanReader booleanReader() {
     return new BooleanReader();
   }
