@@ -30,8 +30,8 @@ import org.apache.avro.Schema;
 import org.apache.avro.generic.IndexedRecord;
 import org.apache.avro.specific.SpecificData;
 import org.apache.iceberg.avro.AvroSchemaUtil;
+import org.apache.iceberg.avro.SupportsIndexProjection;
 import org.apache.iceberg.relocated.com.google.common.base.MoreObjects;
-import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.types.Type;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.ArrayUtil;
@@ -39,7 +39,7 @@ import org.apache.iceberg.util.ByteBuffers;
 import org.apache.iceberg.util.SerializableMap;
 
 /** Base class for both {@link DataFile} and {@link DeleteFile}. */
-abstract class BaseFile<F>
+abstract class BaseFile<F> extends SupportsIndexProjection
     implements ContentFile<F>,
         IndexedRecord,
         StructLike,
@@ -55,10 +55,10 @@ abstract class BaseFile<F>
         }
       };
 
-  private int[] fromProjectionPos;
   private Types.StructType partitionType;
 
   private Long fileOrdinal = null;
+  private String manifestLocation = null;
   private int partitionSpecId = -1;
   private FileContent content = FileContent.DATA;
   private String filePath = null;
@@ -84,40 +84,51 @@ abstract class BaseFile<F>
   // cached schema
   private transient Schema avroSchema = null;
 
+  // struct type that corresponds to the positions used for internalGet and internalSet
+  private static final Types.StructType BASE_TYPE =
+      Types.StructType.of(
+          DataFile.CONTENT,
+          DataFile.FILE_PATH,
+          DataFile.FILE_FORMAT,
+          DataFile.SPEC_ID,
+          Types.NestedField.required(
+              DataFile.PARTITION_ID,
+              DataFile.PARTITION_NAME,
+              EMPTY_STRUCT_TYPE,
+              DataFile.PARTITION_DOC),
+          DataFile.RECORD_COUNT,
+          DataFile.FILE_SIZE,
+          DataFile.COLUMN_SIZES,
+          DataFile.VALUE_COUNTS,
+          DataFile.NULL_VALUE_COUNTS,
+          DataFile.NAN_VALUE_COUNTS,
+          DataFile.LOWER_BOUNDS,
+          DataFile.UPPER_BOUNDS,
+          DataFile.KEY_METADATA,
+          DataFile.SPLIT_OFFSETS,
+          DataFile.EQUALITY_IDS,
+          DataFile.SORT_ORDER_ID,
+          MetadataColumns.ROW_POSITION);
+
   /** Used by Avro reflection to instantiate this class when reading manifest files. */
   BaseFile(Schema avroSchema) {
+    this(AvroSchemaUtil.convert(avroSchema).asStructType());
     this.avroSchema = avroSchema;
+  }
 
-    Types.StructType schema = AvroSchemaUtil.convert(avroSchema).asNestedType().asStructType();
+  /** Used by internal readers to instantiate this class with a projection schema. */
+  BaseFile(Types.StructType projection) {
+    super(BASE_TYPE, projection);
+    this.avroSchema = AvroSchemaUtil.convert(projection, "data_file");
 
     // partition type may be null if the field was not projected
-    Type partType = schema.fieldType("partition");
+    Type partType = projection.fieldType("partition");
     if (partType != null) {
       this.partitionType = partType.asNestedType().asStructType();
     } else {
       this.partitionType = EMPTY_STRUCT_TYPE;
     }
 
-    List<Types.NestedField> fields = schema.fields();
-    List<Types.NestedField> allFields = Lists.newArrayList();
-    allFields.addAll(DataFile.getType(partitionType).fields());
-    allFields.add(MetadataColumns.ROW_POSITION);
-
-    this.fromProjectionPos = new int[fields.size()];
-    for (int i = 0; i < fromProjectionPos.length; i += 1) {
-      boolean found = false;
-      for (int j = 0; j < allFields.size(); j += 1) {
-        if (fields.get(i).fieldId() == allFields.get(j).fieldId()) {
-          found = true;
-          fromProjectionPos[i] = j;
-        }
-      }
-
-      if (!found) {
-        throw new IllegalArgumentException("Cannot find projected field: " + fields.get(i));
-      }
-    }
-
     this.partitionData = new PartitionData(partitionType);
   }
 
@@ -139,6 +150,7 @@ abstract class BaseFile<F>
       int[] equalityFieldIds,
       Integer sortOrderId,
       ByteBuffer keyMetadata) {
+    super(BASE_TYPE.fields().size());
     this.partitionSpecId = specId;
     this.content = content;
     this.filePath = filePath;
@@ -177,7 +189,9 @@ abstract class BaseFile<F>
    *     column stat is kept.
    */
   BaseFile(BaseFile<F> toCopy, boolean copyStats, Set<Integer> requestedColumnIds) {
+    super(toCopy);
     this.fileOrdinal = toCopy.fileOrdinal;
+    this.manifestLocation = toCopy.manifestLocation;
     this.partitionSpecId = toCopy.partitionSpecId;
     this.content = toCopy.content;
     this.filePath = toCopy.filePath;
@@ -201,7 +215,6 @@ abstract class BaseFile<F>
       this.lowerBounds = null;
       this.upperBounds = null;
     }
-    this.fromProjectionPos = toCopy.fromProjectionPos;
     this.keyMetadata =
         toCopy.keyMetadata == null
             ? null
@@ -220,7 +233,9 @@ abstract class BaseFile<F>
   }
 
   /** Constructor for Java serialization. */
-  BaseFile() {}
+  BaseFile() {
+    super(BASE_TYPE.fields().size());
+  }
 
   @Override
   public int specId() {
@@ -240,6 +255,10 @@ abstract class BaseFile<F>
     this.dataSequenceNumber = dataSequenceNumber;
   }
 
+  void setManifestLocation(String manifestLocation) {
+    this.manifestLocation = manifestLocation;
+  }
+
   @Override
   public Long fileSequenceNumber() {
     return fileSequenceNumber;
@@ -260,13 +279,12 @@ abstract class BaseFile<F>
   }
 
   @Override
-  @SuppressWarnings("unchecked")
   public void put(int i, Object value) {
-    int pos = i;
-    // if the schema was projected, map the incoming ordinal to the expected one
-    if (fromProjectionPos != null) {
-      pos = fromProjectionPos[i];
-    }
+    set(i, value);
+  }
+
+  @Override
+  protected <T> void internalSet(int pos, T value) {
     switch (pos) {
       case 0:
         this.content = value != null ? FILE_CONTENT_VALUES[(Integer) value] : FileContent.DATA;
@@ -329,18 +347,12 @@ abstract class BaseFile<F>
   }
 
   @Override
-  public <T> void set(int pos, T value) {
-    put(pos, value);
+  protected <T> T internalGet(int pos, Class<T> javaClass) {
+    return javaClass.cast(getByPos(pos));
   }
 
-  @Override
-  public Object get(int i) {
-    int pos = i;
-    // if the schema was projected, map the incoming ordinal to the expected one
-    if (fromProjectionPos != null) {
-      pos = fromProjectionPos[i];
-    }
-    switch (pos) {
+  private Object getByPos(int basePos) {
+    switch (basePos) {
       case 0:
         return content.id();
       case 1:
@@ -378,13 +390,13 @@ abstract class BaseFile<F>
       case 17:
         return fileOrdinal;
       default:
-        throw new UnsupportedOperationException("Unknown field ordinal: " + pos);
+        throw new UnsupportedOperationException("Unknown field ordinal: " + basePos);
     }
   }
 
   @Override
-  public <T> T get(int pos, Class<T> javaClass) {
-    return javaClass.cast(get(pos));
+  public Object get(int pos) {
+    return get(pos, Object.class);
   }
 
   @Override
@@ -397,6 +409,11 @@ abstract class BaseFile<F>
     return fileOrdinal;
   }
 
+  @Override
+  public String manifestLocation() {
+    return manifestLocation;
+  }
+
   @Override
   public FileContent content() {
     return content;
