@@ -109,6 +109,7 @@ public class TableMetadataParser {
   static final String METADATA_FILE = "metadata-file";
   static final String METADATA_LOG = "metadata-log";
   static final String STATISTICS = "statistics";
+  static final String PARTITION_STATISTICS = "partition-statistics";
 
   public static void overwrite(TableMetadata metadata, OutputFile outputFile) {
     internalWrite(metadata, outputFile, true);
@@ -121,9 +122,9 @@ public class TableMetadataParser {
   public static void internalWrite(
       TableMetadata metadata, OutputFile outputFile, boolean overwrite) {
     boolean isGzip = Codec.fromFileName(outputFile.location()) == Codec.GZIP;
-    OutputStream stream = overwrite ? outputFile.createOrOverwrite() : outputFile.create();
-    try (OutputStream ou = isGzip ? new GZIPOutputStream(stream) : stream;
-        OutputStreamWriter writer = new OutputStreamWriter(ou, StandardCharsets.UTF_8)) {
+    try (OutputStream os = overwrite ? outputFile.createOrOverwrite() : outputFile.create();
+        OutputStream gos = isGzip ? new GZIPOutputStream(os) : os;
+        OutputStreamWriter writer = new OutputStreamWriter(gos, StandardCharsets.UTF_8)) {
       JsonGenerator generator = JsonUtil.factory().createGenerator(writer);
       generator.useDefaultPrettyPrinter();
       toJson(metadata, generator);
@@ -231,6 +232,12 @@ public class TableMetadataParser {
     }
     generator.writeEndArray();
 
+    generator.writeArrayFieldStart(PARTITION_STATISTICS);
+    for (PartitionStatisticsFile partitionStatisticsFile : metadata.partitionStatisticsFiles()) {
+      PartitionStatisticsFileParser.toJson(partitionStatisticsFile, generator);
+    }
+    generator.writeEndArray();
+
     generator.writeArrayFieldStart(SNAPSHOT_LOG);
     for (HistoryEntry logEntry : metadata.snapshotLog()) {
       generator.writeStartObject();
@@ -268,9 +275,9 @@ public class TableMetadataParser {
 
   public static TableMetadata read(FileIO io, InputFile file) {
     Codec codec = Codec.fromFileName(file.location());
-    try (InputStream is =
-        codec == Codec.GZIP ? new GZIPInputStream(file.newStream()) : file.newStream()) {
-      return fromJson(file, JsonUtil.mapper().readValue(is, JsonNode.class));
+    try (InputStream is = file.newStream();
+        InputStream gis = codec == Codec.GZIP ? new GZIPInputStream(is) : is) {
+      return fromJson(file, JsonUtil.mapper().readValue(gis, JsonNode.class));
     } catch (IOException e) {
       throw new RuntimeIOException(e, "Failed to read file: %s", file);
     }
@@ -481,6 +488,13 @@ public class TableMetadataParser {
       statisticsFiles = ImmutableList.of();
     }
 
+    List<PartitionStatisticsFile> partitionStatisticsFiles;
+    if (node.has(PARTITION_STATISTICS)) {
+      partitionStatisticsFiles = partitionStatsFilesFromJson(node.get(PARTITION_STATISTICS));
+    } else {
+      partitionStatisticsFiles = ImmutableList.of();
+    }
+
     ImmutableList.Builder<HistoryEntry> entries = ImmutableList.builder();
     if (node.has(SNAPSHOT_LOG)) {
       Iterator<JsonNode> logIterator = node.get(SNAPSHOT_LOG).elements();
@@ -528,6 +542,7 @@ public class TableMetadataParser {
         metadataEntries.build(),
         refs,
         statisticsFiles,
+        partitionStatisticsFiles,
         ImmutableList.of() /* no changes from the file */);
   }
 
@@ -561,4 +576,18 @@ public class TableMetadataParser {
 
     return statisticsFilesBuilder.build();
   }
+
+  private static List<PartitionStatisticsFile> partitionStatsFilesFromJson(JsonNode filesList) {
+    Preconditions.checkArgument(
+        filesList.isArray(),
+        "Cannot parse partition statistics files from non-array: %s",
+        filesList);
+
+    ImmutableList.Builder<PartitionStatisticsFile> statsFileBuilder = ImmutableList.builder();
+    for (JsonNode partitionStatsFile : filesList) {
+      statsFileBuilder.add(PartitionStatisticsFileParser.fromJson(partitionStatsFile));
+    }
+
+    return statsFileBuilder.build();
+  }
 }
