@@ -28,7 +28,6 @@ import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentMap;
 import java.util.stream.Collectors;
-import org.apache.iceberg.BaseMetastoreCatalog;
 import org.apache.iceberg.BaseMetastoreTableOperations;
 import org.apache.iceberg.CatalogProperties;
 import org.apache.iceberg.CatalogUtil;
@@ -42,30 +41,40 @@ import org.apache.iceberg.exceptions.CommitFailedException;
 import org.apache.iceberg.exceptions.NamespaceNotEmptyException;
 import org.apache.iceberg.exceptions.NoSuchNamespaceException;
 import org.apache.iceberg.exceptions.NoSuchTableException;
+import org.apache.iceberg.exceptions.NoSuchViewException;
+import org.apache.iceberg.io.CloseableGroup;
 import org.apache.iceberg.io.FileIO;
 import org.apache.iceberg.relocated.com.google.common.base.Joiner;
 import org.apache.iceberg.relocated.com.google.common.base.Objects;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
+import org.apache.iceberg.view.BaseMetastoreViewCatalog;
+import org.apache.iceberg.view.BaseViewOperations;
+import org.apache.iceberg.view.ViewMetadata;
+import org.apache.iceberg.view.ViewUtil;
 
 /**
  * Catalog implementation that uses in-memory data-structures to store the namespaces and tables.
  * This class doesn't touch external resources and can be utilized to write unit tests without side
  * effects. It uses {@link InMemoryFileIO}.
  */
-public class InMemoryCatalog extends BaseMetastoreCatalog implements SupportsNamespaces, Closeable {
+public class InMemoryCatalog extends BaseMetastoreViewCatalog
+    implements SupportsNamespaces, Closeable {
   private static final Joiner SLASH = Joiner.on("/");
   private static final Joiner DOT = Joiner.on(".");
 
   private final ConcurrentMap<Namespace, Map<String, String>> namespaces;
   private final ConcurrentMap<TableIdentifier, String> tables;
+  private final ConcurrentMap<TableIdentifier, String> views;
   private FileIO io;
   private String catalogName;
   private String warehouseLocation;
+  private CloseableGroup closeableGroup;
 
   public InMemoryCatalog() {
     this.namespaces = Maps.newConcurrentMap();
     this.tables = Maps.newConcurrentMap();
+    this.views = Maps.newConcurrentMap();
   }
 
   @Override
@@ -80,6 +89,9 @@ public class InMemoryCatalog extends BaseMetastoreCatalog implements SupportsNam
     String warehouse = properties.getOrDefault(CatalogProperties.WAREHOUSE_LOCATION, "");
     this.warehouseLocation = warehouse.replaceAll("/*$", "");
     this.io = new InMemoryFileIO();
+    this.closeableGroup = new CloseableGroup();
+    closeableGroup.addCloseable(metricsReporter());
+    closeableGroup.setSuppressCloseFailure(true);
   }
 
   @Override
@@ -111,8 +123,10 @@ public class InMemoryCatalog extends BaseMetastoreCatalog implements SupportsNam
       lastMetadata = null;
     }
 
-    if (null == tables.remove(tableIdentifier)) {
-      return false;
+    synchronized (this) {
+      if (null == tables.remove(tableIdentifier)) {
+        return false;
+      }
     }
 
     if (purge && lastMetadata != null) {
@@ -136,27 +150,33 @@ public class InMemoryCatalog extends BaseMetastoreCatalog implements SupportsNam
   }
 
   @Override
-  public synchronized void renameTable(TableIdentifier from, TableIdentifier to) {
+  public void renameTable(TableIdentifier from, TableIdentifier to) {
     if (from.equals(to)) {
       return;
     }
 
-    if (!namespaceExists(to.namespace())) {
-      throw new NoSuchNamespaceException(
-          "Cannot rename %s to %s. Namespace does not exist: %s", from, to, to.namespace());
-    }
+    synchronized (this) {
+      if (!namespaceExists(to.namespace())) {
+        throw new NoSuchNamespaceException(
+            "Cannot rename %s to %s. Namespace does not exist: %s", from, to, to.namespace());
+      }
 
-    String fromLocation = tables.get(from);
-    if (null == fromLocation) {
-      throw new NoSuchTableException("Cannot rename %s to %s. Table does not exist", from, to);
-    }
+      String fromLocation = tables.get(from);
+      if (null == fromLocation) {
+        throw new NoSuchTableException("Cannot rename %s to %s. Table does not exist", from, to);
+      }
 
-    if (tables.containsKey(to)) {
-      throw new AlreadyExistsException("Cannot rename %s to %s. Table already exists", from, to);
-    }
+      if (tables.containsKey(to)) {
+        throw new AlreadyExistsException("Cannot rename %s to %s. Table already exists", from, to);
+      }
 
-    tables.put(to, fromLocation);
-    tables.remove(from);
+      if (views.containsKey(to)) {
+        throw new AlreadyExistsException("Cannot rename %s to %s. View already exists", from, to);
+      }
+
+      tables.put(to, fromLocation);
+      tables.remove(from);
+    }
   }
 
   @Override
@@ -166,12 +186,14 @@ public class InMemoryCatalog extends BaseMetastoreCatalog implements SupportsNam
 
   @Override
   public void createNamespace(Namespace namespace, Map<String, String> metadata) {
-    if (namespaceExists(namespace)) {
-      throw new AlreadyExistsException(
-          "Cannot create namespace %s. Namespace already exists", namespace);
-    }
+    synchronized (this) {
+      if (namespaceExists(namespace)) {
+        throw new AlreadyExistsException(
+            "Cannot create namespace %s. Namespace already exists", namespace);
+      }
 
-    namespaces.put(namespace, ImmutableMap.copyOf(metadata));
+      namespaces.put(namespace, ImmutableMap.copyOf(metadata));
+    }
   }
 
   @Override
@@ -181,50 +203,59 @@ public class InMemoryCatalog extends BaseMetastoreCatalog implements SupportsNam
 
   @Override
   public boolean dropNamespace(Namespace namespace) throws NamespaceNotEmptyException {
-    if (!namespaceExists(namespace)) {
-      return false;
-    }
+    synchronized (this) {
+      if (!namespaceExists(namespace)) {
+        return false;
+      }
 
-    List<TableIdentifier> tableIdentifiers = listTables(namespace);
-    if (!tableIdentifiers.isEmpty()) {
-      throw new NamespaceNotEmptyException(
-          "Namespace %s is not empty. Contains %d table(s).", namespace, tableIdentifiers.size());
-    }
+      List<TableIdentifier> tableIdentifiers = listTables(namespace);
+      if (!tableIdentifiers.isEmpty()) {
+        throw new NamespaceNotEmptyException(
+            "Namespace %s is not empty. Contains %d table(s).", namespace, tableIdentifiers.size());
+      }
 
-    return namespaces.remove(namespace) != null;
+      return namespaces.remove(namespace) != null;
+    }
   }
 
   @Override
   public boolean setProperties(Namespace namespace, Map<String, String> properties)
       throws NoSuchNamespaceException {
-    if (!namespaceExists(namespace)) {
-      throw new NoSuchNamespaceException("Namespace does not exist: %s", namespace);
+    synchronized (this) {
+      if (!namespaceExists(namespace)) {
+        throw new NoSuchNamespaceException("Namespace does not exist: %s", namespace);
+      }
+
+      namespaces.computeIfPresent(
+          namespace,
+          (k, v) ->
+              ImmutableMap.<String, String>builder()
+                  .putAll(v)
+                  .putAll(properties)
+                  .buildKeepingLast());
+
+      return true;
     }
-
-    namespaces.computeIfPresent(
-        namespace,
-        (k, v) ->
-            ImmutableMap.<String, String>builder().putAll(v).putAll(properties).buildKeepingLast());
-
-    return true;
   }
 
   @Override
   public boolean removeProperties(Namespace namespace, Set<String> properties)
       throws NoSuchNamespaceException {
-    if (!namespaceExists(namespace)) {
-      throw new NoSuchNamespaceException("Namespace does not exist: %s", namespace);
+    synchronized (this) {
+      if (!namespaceExists(namespace)) {
+        throw new NoSuchNamespaceException("Namespace does not exist: %s", namespace);
+      }
+
+      namespaces.computeIfPresent(
+          namespace,
+          (k, v) -> {
+            Map<String, String> newProperties = Maps.newHashMap(v);
+            properties.forEach(newProperties::remove);
+            return ImmutableMap.copyOf(newProperties);
+          });
+
+      return true;
     }
-
-    namespaces.computeIfPresent(
-        namespace,
-        (k, v) -> {
-          Map<String, String> newProperties = Maps.newHashMap(v);
-          properties.forEach(newProperties::remove);
-          return ImmutableMap.copyOf(newProperties);
-        });
-
-    return true;
   }
 
   @Override
@@ -276,17 +307,76 @@ public class InMemoryCatalog extends BaseMetastoreCatalog implements SupportsNam
 
   @Override
   public void close() throws IOException {
+    closeableGroup.close();
     namespaces.clear();
     tables.clear();
+    views.clear();
+  }
+
+  @Override
+  public List<TableIdentifier> listViews(Namespace namespace) {
+    if (!namespaceExists(namespace) && !namespace.isEmpty()) {
+      throw new NoSuchNamespaceException(
+          "Cannot list views for namespace. Namespace does not exist: %s", namespace);
+    }
+
+    return views.keySet().stream()
+        .filter(v -> namespace.isEmpty() || v.namespace().equals(namespace))
+        .sorted(Comparator.comparing(TableIdentifier::toString))
+        .collect(Collectors.toList());
+  }
+
+  @Override
+  protected InMemoryViewOperations newViewOps(TableIdentifier identifier) {
+    return new InMemoryViewOperations(io, identifier);
+  }
+
+  @Override
+  public boolean dropView(TableIdentifier identifier) {
+    synchronized (this) {
+      return null != views.remove(identifier);
+    }
+  }
+
+  @Override
+  public void renameView(TableIdentifier from, TableIdentifier to) {
+    if (from.equals(to)) {
+      return;
+    }
+
+    synchronized (this) {
+      if (!namespaceExists(to.namespace())) {
+        throw new NoSuchNamespaceException(
+            "Cannot rename %s to %s. Namespace does not exist: %s", from, to, to.namespace());
+      }
+
+      String fromViewLocation = views.get(from);
+      if (null == fromViewLocation) {
+        throw new NoSuchViewException("Cannot rename %s to %s. View does not exist", from, to);
+      }
+
+      if (tables.containsKey(to)) {
+        throw new AlreadyExistsException("Cannot rename %s to %s. Table already exists", from, to);
+      }
+
+      if (views.containsKey(to)) {
+        throw new AlreadyExistsException("Cannot rename %s to %s. View already exists", from, to);
+      }
+
+      views.put(to, fromViewLocation);
+      views.remove(from);
+    }
   }
 
   private class InMemoryTableOperations extends BaseMetastoreTableOperations {
     private final FileIO fileIO;
     private final TableIdentifier tableIdentifier;
+    private final String fullTableName;
 
     InMemoryTableOperations(FileIO fileIO, TableIdentifier tableIdentifier) {
       this.fileIO = fileIO;
       this.tableIdentifier = tableIdentifier;
+      this.fullTableName = fullTableName(catalogName, tableIdentifier);
     }
 
     @Override
@@ -301,30 +391,41 @@ public class InMemoryCatalog extends BaseMetastoreCatalog implements SupportsNam
 
     @Override
     public void doCommit(TableMetadata base, TableMetadata metadata) {
-      String newLocation = writeNewMetadata(metadata, currentVersion() + 1);
+      String newLocation = writeNewMetadataIfRequired(base == null, metadata);
       String oldLocation = base == null ? null : base.metadataFileLocation();
 
-      if (null == base && !namespaceExists(tableIdentifier.namespace())) {
-        throw new NoSuchNamespaceException(
-            "Cannot create table %s. Namespace does not exist: %s",
-            tableIdentifier, tableIdentifier.namespace());
-      }
+      synchronized (InMemoryCatalog.this) {
+        if (null == base && !namespaceExists(tableIdentifier.namespace())) {
+          throw new NoSuchNamespaceException(
+              "Cannot create table %s. Namespace does not exist: %s",
+              tableIdentifier, tableIdentifier.namespace());
+        }
 
-      tables.compute(
-          tableIdentifier,
-          (k, existingLocation) -> {
-            if (!Objects.equal(existingLocation, oldLocation)) {
-              if (null == base) {
-                throw new AlreadyExistsException("Table already exists: %s", tableName());
+        if (views.containsKey(tableIdentifier)) {
+          throw new AlreadyExistsException(
+              "View with same name already exists: %s", tableIdentifier);
+        }
+
+        tables.compute(
+            tableIdentifier,
+            (k, existingLocation) -> {
+              if (!Objects.equal(existingLocation, oldLocation)) {
+                if (null == base) {
+                  throw new AlreadyExistsException("Table already exists: %s", tableName());
+                }
+
+                if (null == existingLocation) {
+                  throw new NoSuchTableException("Table does not exist: %s", tableName());
+                }
+
+                throw new CommitFailedException(
+                    "Cannot commit to table %s metadata location from %s to %s "
+                        + "because it has been concurrently modified to %s",
+                    tableIdentifier, oldLocation, newLocation, existingLocation);
               }
-
-              throw new CommitFailedException(
-                  "Cannot commit to table %s metadata location from %s to %s "
-                      + "because it has been concurrently modified to %s",
-                  tableIdentifier, oldLocation, newLocation, existingLocation);
-            }
-            return newLocation;
-          });
+              return newLocation;
+            });
+      }
     }
 
     @Override
@@ -334,7 +435,78 @@ public class InMemoryCatalog extends BaseMetastoreCatalog implements SupportsNam
 
     @Override
     protected String tableName() {
-      return tableIdentifier.toString();
+      return fullTableName;
+    }
+  }
+
+  private class InMemoryViewOperations extends BaseViewOperations {
+    private final FileIO io;
+    private final TableIdentifier identifier;
+    private final String fullViewName;
+
+    InMemoryViewOperations(FileIO io, TableIdentifier identifier) {
+      this.io = io;
+      this.identifier = identifier;
+      this.fullViewName = ViewUtil.fullViewName(catalogName, identifier);
+    }
+
+    @Override
+    public void doRefresh() {
+      String latestLocation = views.get(identifier);
+      if (latestLocation == null) {
+        disableRefresh();
+      } else {
+        refreshFromMetadataLocation(latestLocation);
+      }
+    }
+
+    @Override
+    public void doCommit(ViewMetadata base, ViewMetadata metadata) {
+      String newLocation = writeNewMetadataIfRequired(metadata);
+      String oldLocation = base == null ? null : currentMetadataLocation();
+
+      synchronized (InMemoryCatalog.this) {
+        if (null == base && !namespaceExists(identifier.namespace())) {
+          throw new NoSuchNamespaceException(
+              "Cannot create view %s. Namespace does not exist: %s",
+              identifier, identifier.namespace());
+        }
+
+        if (tables.containsKey(identifier)) {
+          throw new AlreadyExistsException("Table with same name already exists: %s", identifier);
+        }
+
+        views.compute(
+            identifier,
+            (k, existingLocation) -> {
+              if (!Objects.equal(existingLocation, oldLocation)) {
+                if (null == base) {
+                  throw new AlreadyExistsException("View already exists: %s", identifier);
+                }
+
+                if (null == existingLocation) {
+                  throw new NoSuchViewException("View does not exist: %s", identifier);
+                }
+
+                throw new CommitFailedException(
+                    "Cannot commit to view %s metadata location from %s to %s "
+                        + "because it has been concurrently modified to %s",
+                    identifier, oldLocation, newLocation, existingLocation);
+              }
+
+              return newLocation;
+            });
+      }
+    }
+
+    @Override
+    public FileIO io() {
+      return io;
+    }
+
+    @Override
+    protected String viewName() {
+      return fullViewName;
     }
   }
 }
