@@ -47,7 +47,6 @@ import org.apache.iceberg.Schema;
 import org.apache.iceberg.SortOrder;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableMetadata;
-import org.apache.iceberg.TableOperations;
 import org.apache.iceberg.Transaction;
 import org.apache.iceberg.Transactions;
 import org.apache.iceberg.catalog.BaseViewSessionCatalog;
@@ -59,10 +58,10 @@ import org.apache.iceberg.exceptions.AlreadyExistsException;
 import org.apache.iceberg.exceptions.NoSuchNamespaceException;
 import org.apache.iceberg.exceptions.NoSuchTableException;
 import org.apache.iceberg.exceptions.NoSuchViewException;
-import org.apache.iceberg.exceptions.RESTException;
 import org.apache.iceberg.hadoop.Configurable;
 import org.apache.iceberg.io.CloseableGroup;
 import org.apache.iceberg.io.FileIO;
+import org.apache.iceberg.io.FileIOTracker;
 import org.apache.iceberg.metrics.MetricsReporter;
 import org.apache.iceberg.metrics.MetricsReporters;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
@@ -116,6 +115,9 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
   private static final String DEFAULT_FILE_IO_IMPL = "org.apache.iceberg.io.ResolvingFileIO";
   private static final String REST_METRICS_REPORTING_ENABLED = "rest-metrics-reporting-enabled";
   private static final String REST_SNAPSHOT_LOADING_MODE = "snapshot-loading-mode";
+  // for backwards compatibility with older REST servers where it can be assumed that a particular
+  // server supports view endpoints but doesn't send the "endpoints" field in the ConfigResponse
+  static final String VIEW_ENDPOINTS_SUPPORTED = "view-endpoints-supported";
   public static final String REST_PAGE_SIZE = "rest-page-size";
   private static final List<String> TOKEN_PREFERENCE_ORDER =
       ImmutableList.of(
@@ -132,11 +134,38 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
           .addAll(TOKEN_PREFERENCE_ORDER)
           .build();
 
+  private static final Set<Endpoint> DEFAULT_ENDPOINTS =
+      ImmutableSet.<Endpoint>builder()
+          .add(Endpoint.V1_LIST_NAMESPACES)
+          .add(Endpoint.V1_LOAD_NAMESPACE)
+          .add(Endpoint.V1_CREATE_NAMESPACE)
+          .add(Endpoint.V1_UPDATE_NAMESPACE)
+          .add(Endpoint.V1_DELETE_NAMESPACE)
+          .add(Endpoint.V1_LIST_TABLES)
+          .add(Endpoint.V1_LOAD_TABLE)
+          .add(Endpoint.V1_CREATE_TABLE)
+          .add(Endpoint.V1_UPDATE_TABLE)
+          .add(Endpoint.V1_DELETE_TABLE)
+          .add(Endpoint.V1_RENAME_TABLE)
+          .add(Endpoint.V1_REGISTER_TABLE)
+          .add(Endpoint.V1_REPORT_METRICS)
+          .build();
+
+  private static final Set<Endpoint> VIEW_ENDPOINTS =
+      ImmutableSet.<Endpoint>builder()
+          .add(Endpoint.V1_LIST_VIEWS)
+          .add(Endpoint.V1_LOAD_VIEW)
+          .add(Endpoint.V1_CREATE_VIEW)
+          .add(Endpoint.V1_UPDATE_VIEW)
+          .add(Endpoint.V1_DELETE_VIEW)
+          .add(Endpoint.V1_RENAME_VIEW)
+          .build();
+
   private final Function<Map<String, String>, RESTClient> clientBuilder;
   private final BiFunction<SessionContext, Map<String, String>, FileIO> ioBuilder;
   private Cache<String, AuthSession> sessions = null;
   private Cache<String, AuthSession> tableSessions = null;
-  private Cache<TableOperations, FileIO> fileIOCloser;
+  private FileIOTracker fileIOTracker = null;
   private AuthSession catalogAuth = null;
   private boolean keepTokenRefreshed = true;
   private RESTClient client = null;
@@ -148,6 +177,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
   private boolean reportingViaRestEnabled;
   private Integer pageSize = null;
   private CloseableGroup closeables = null;
+  private Set<Endpoint> endpoints;
 
   // a lazy thread pool for token refresh
   private volatile ScheduledExecutorService refreshExecutor = null;
@@ -173,6 +203,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
     this.ioBuilder = ioBuilder;
   }
 
+  @SuppressWarnings("checkstyle:CyclomaticComplexity")
   @Override
   public void initialize(String name, Map<String, String> unresolved) {
     Preconditions.checkArgument(unresolved != null, "Invalid configuration: null");
@@ -230,6 +261,18 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
     Map<String, String> mergedProps = config.merge(props);
     Map<String, String> baseHeaders = configHeaders(mergedProps);
 
+    if (config.endpoints().isEmpty()) {
+      this.endpoints =
+          PropertyUtil.propertyAsBoolean(mergedProps, VIEW_ENDPOINTS_SUPPORTED, false)
+              ? ImmutableSet.<Endpoint>builder()
+                  .addAll(DEFAULT_ENDPOINTS)
+                  .addAll(VIEW_ENDPOINTS)
+                  .build()
+              : DEFAULT_ENDPOINTS;
+    } else {
+      this.endpoints = ImmutableSet.copyOf(config.endpoints());
+    }
+
     this.sessions = newSessionCache(mergedProps);
     this.tableSessions = newSessionCache(mergedProps);
     this.keepTokenRefreshed =
@@ -268,10 +311,11 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
     this.io = newFileIO(SessionContext.createEmpty(), mergedProps);
 
-    this.fileIOCloser = newFileIOCloser();
+    this.fileIOTracker = new FileIOTracker();
     this.closeables = new CloseableGroup();
     this.closeables.addCloseable(this.io);
     this.closeables.addCloseable(this.client);
+    this.closeables.addCloseable(fileIOTracker);
     this.closeables.setSuppressCloseFailure(true);
 
     this.snapshotMode =
@@ -315,6 +359,10 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public List<TableIdentifier> listTables(SessionContext context, Namespace ns) {
+    if (!endpoints.contains(Endpoint.V1_LIST_TABLES)) {
+      return ImmutableList.of();
+    }
+
     checkNamespaceIsValid(ns);
     Map<String, String> queryParams = Maps.newHashMap();
     ImmutableList.Builder<TableIdentifier> tables = ImmutableList.builder();
@@ -341,6 +389,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public boolean dropTable(SessionContext context, TableIdentifier identifier) {
+    Endpoint.check(endpoints, Endpoint.V1_DELETE_TABLE);
     checkIdentifierIsValid(identifier);
 
     try {
@@ -354,6 +403,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public boolean purgeTable(SessionContext context, TableIdentifier identifier) {
+    Endpoint.check(endpoints, Endpoint.V1_DELETE_TABLE);
     checkIdentifierIsValid(identifier);
 
     try {
@@ -371,6 +421,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public void renameTable(SessionContext context, TableIdentifier from, TableIdentifier to) {
+    Endpoint.check(endpoints, Endpoint.V1_RENAME_TABLE);
     checkIdentifierIsValid(from);
     checkIdentifierIsValid(to);
 
@@ -383,6 +434,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   private LoadTableResponse loadInternal(
       SessionContext context, TableIdentifier identifier, SnapshotMode mode) {
+    Endpoint.check(endpoints, Endpoint.V1_LOAD_TABLE);
     return client.get(
         paths.table(identifier),
         mode.params(),
@@ -393,6 +445,14 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public Table loadTable(SessionContext context, TableIdentifier identifier) {
+    Endpoint.check(
+        endpoints,
+        Endpoint.V1_LOAD_TABLE,
+        () ->
+            new NoSuchTableException(
+                "Unable to load table %s.%s: Server does not support endpoint %s",
+                name(), identifier, Endpoint.V1_LOAD_TABLE));
+
     checkIdentifierIsValid(identifier);
 
     MetadataTableType metadataType;
@@ -447,7 +507,8 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
             paths.table(finalIdentifier),
             session::headers,
             tableFileIO(context, response.config()),
-            tableMetadata);
+            tableMetadata,
+            endpoints);
 
     trackFileIO(ops);
 
@@ -465,13 +526,13 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   private void trackFileIO(RESTTableOperations ops) {
     if (io != ops.io()) {
-      fileIOCloser.put(ops, ops.io());
+      fileIOTracker.track(ops);
     }
   }
 
   private MetricsReporter metricsReporter(
       String metricsEndpoint, Supplier<Map<String, String>> headers) {
-    if (reportingViaRestEnabled) {
+    if (reportingViaRestEnabled && endpoints.contains(Endpoint.V1_REPORT_METRICS)) {
       RESTMetricsReporter restMetricsReporter =
           new RESTMetricsReporter(client, metricsEndpoint, headers);
       return MetricsReporters.combine(reporter, restMetricsReporter);
@@ -492,6 +553,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
   @Override
   public Table registerTable(
       SessionContext context, TableIdentifier ident, String metadataFileLocation) {
+    Endpoint.check(endpoints, Endpoint.V1_REGISTER_TABLE);
     checkIdentifierIsValid(ident);
 
     Preconditions.checkArgument(
@@ -520,7 +582,8 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
             paths.table(ident),
             session::headers,
             tableFileIO(context, response.config()),
-            response.tableMetadata());
+            response.tableMetadata(),
+            endpoints);
 
     trackFileIO(ops);
 
@@ -531,6 +594,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
   @Override
   public void createNamespace(
       SessionContext context, Namespace namespace, Map<String, String> metadata) {
+    Endpoint.check(endpoints, Endpoint.V1_CREATE_NAMESPACE);
     CreateNamespaceRequest request =
         CreateNamespaceRequest.builder().withNamespace(namespace).setProperties(metadata).build();
 
@@ -545,9 +609,13 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public List<Namespace> listNamespaces(SessionContext context, Namespace namespace) {
+    if (!endpoints.contains(Endpoint.V1_LIST_NAMESPACES)) {
+      return ImmutableList.of();
+    }
+
     Map<String, String> queryParams = Maps.newHashMap();
     if (!namespace.isEmpty()) {
-      queryParams.put("parent", RESTUtil.NAMESPACE_JOINER.join(namespace.levels()));
+      queryParams.put("parent", RESTUtil.encodeNamespace(namespace));
     }
 
     ImmutableList.Builder<Namespace> namespaces = ImmutableList.builder();
@@ -574,6 +642,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public Map<String, String> loadNamespaceMetadata(SessionContext context, Namespace ns) {
+    Endpoint.check(endpoints, Endpoint.V1_LOAD_NAMESPACE);
     checkNamespaceIsValid(ns);
 
     // TODO: rename to LoadNamespaceResponse?
@@ -588,6 +657,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public boolean dropNamespace(SessionContext context, Namespace ns) {
+    Endpoint.check(endpoints, Endpoint.V1_DELETE_NAMESPACE);
     checkNamespaceIsValid(ns);
 
     try {
@@ -602,6 +672,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
   @Override
   public boolean updateNamespaceMetadata(
       SessionContext context, Namespace ns, Map<String, String> updates, Set<String> removals) {
+    Endpoint.check(endpoints, Endpoint.V1_UPDATE_NAMESPACE);
     checkNamespaceIsValid(ns);
 
     UpdateNamespacePropertiesRequest request =
@@ -641,11 +712,6 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
     if (closeables != null) {
       closeables.close();
     }
-
-    if (fileIOCloser != null) {
-      fileIOCloser.invalidateAll();
-      fileIOCloser.cleanUp();
-    }
   }
 
   private void shutdownRefreshExecutor() {
@@ -723,6 +789,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
     @Override
     public Table create() {
+      Endpoint.check(endpoints, Endpoint.V1_CREATE_TABLE);
       CreateTableRequest request =
           CreateTableRequest.builder()
               .withName(ident.name())
@@ -748,7 +815,8 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
               paths.table(ident),
               session::headers,
               tableFileIO(context, response.config()),
-              response.tableMetadata());
+              response.tableMetadata(),
+              endpoints);
 
       trackFileIO(ops);
 
@@ -758,6 +826,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
     @Override
     public Transaction createTransaction() {
+      Endpoint.check(endpoints, Endpoint.V1_CREATE_TABLE);
       LoadTableResponse response = stageCreate();
       String fullName = fullTableName(ident);
 
@@ -772,7 +841,8 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
               tableFileIO(context, response.config()),
               RESTTableOperations.UpdateType.CREATE,
               createChanges(meta),
-              meta);
+              meta,
+              endpoints);
 
       trackFileIO(ops);
 
@@ -782,15 +852,9 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
     @Override
     public Transaction replaceTransaction() {
-      try {
-        if (viewExists(context, ident)) {
-          throw new AlreadyExistsException("View with same name already exists: %s", ident);
-        }
-      } catch (RESTException | UnsupportedOperationException e) {
-        // don't fail if the server doesn't support views, which could be due to:
-        // 1. server or backing catalog doesn't support views
-        // 2. newer client talks to an older server that doesn't support views
-        LOG.debug("Failed to check whether view {} exists", ident, e);
+      Endpoint.check(endpoints, Endpoint.V1_UPDATE_TABLE);
+      if (viewExists(context, ident)) {
+        throw new AlreadyExistsException("View with same name already exists: %s", ident);
       }
 
       LoadTableResponse response = loadInternal(context, ident, snapshotMode);
@@ -836,7 +900,8 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
               tableFileIO(context, response.config()),
               RESTTableOperations.UpdateType.REPLACE,
               changes.build(),
-              base);
+              base,
+              endpoints);
 
       trackFileIO(ops);
 
@@ -1088,20 +1153,8 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
         .build();
   }
 
-  private Cache<TableOperations, FileIO> newFileIOCloser() {
-    return Caffeine.newBuilder()
-        .weakKeys()
-        .removalListener(
-            (RemovalListener<TableOperations, FileIO>)
-                (ops, fileIO, cause) -> {
-                  if (null != fileIO) {
-                    fileIO.close();
-                  }
-                })
-        .build();
-  }
-
   public void commitTransaction(SessionContext context, List<TableCommit> commits) {
+    Endpoint.check(endpoints, Endpoint.V1_COMMIT_TRANSACTION);
     List<UpdateTableRequest> tableChanges = Lists.newArrayListWithCapacity(commits.size());
 
     for (TableCommit commit : commits) {
@@ -1119,6 +1172,10 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public List<TableIdentifier> listViews(SessionContext context, Namespace namespace) {
+    if (!endpoints.contains(Endpoint.V1_LIST_VIEWS)) {
+      return ImmutableList.of();
+    }
+
     checkNamespaceIsValid(namespace);
     Map<String, String> queryParams = Maps.newHashMap();
     ImmutableList.Builder<TableIdentifier> views = ImmutableList.builder();
@@ -1145,30 +1202,29 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public View loadView(SessionContext context, TableIdentifier identifier) {
+    Endpoint.check(
+        endpoints,
+        Endpoint.V1_LOAD_VIEW,
+        () ->
+            new NoSuchViewException(
+                "Unable to load view %s.%s: Server does not support endpoint %s",
+                name(), identifier, Endpoint.V1_LOAD_VIEW));
+
     checkViewIdentifierIsValid(identifier);
 
-    LoadViewResponse response;
-    try {
-      response =
-          client.get(
-              paths.view(identifier),
-              LoadViewResponse.class,
-              headers(context),
-              ErrorHandlers.viewErrorHandler());
-    } catch (UnsupportedOperationException | RESTException e) {
-      // Normally, copying an exception message is a bad practice but engines may show just the
-      // message and suppress the exception cause when the view does not exist. Since 401 and 403
-      // responses can trigger this case, including the message increases the chances that the "Not
-      // authorized" or "Forbidden" message is preserved and shown.
-      throw new NoSuchViewException(
-          e, "Unable to load view %s.%s: %s", name(), identifier, e.getMessage());
-    }
+    LoadViewResponse response =
+        client.get(
+            paths.view(identifier),
+            LoadViewResponse.class,
+            headers(context),
+            ErrorHandlers.viewErrorHandler());
 
     AuthSession session = tableSession(response.config(), session(context));
     ViewMetadata metadata = response.metadata();
 
     RESTViewOperations ops =
-        new RESTViewOperations(client, paths.view(identifier), session::headers, metadata);
+        new RESTViewOperations(
+            client, paths.view(identifier), session::headers, metadata, endpoints);
 
     return new BaseView(ops, ViewUtil.fullViewName(name(), identifier));
   }
@@ -1180,6 +1236,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public boolean dropView(SessionContext context, TableIdentifier identifier) {
+    Endpoint.check(endpoints, Endpoint.V1_DELETE_VIEW);
     checkViewIdentifierIsValid(identifier);
 
     try {
@@ -1193,6 +1250,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
   @Override
   public void renameView(SessionContext context, TableIdentifier from, TableIdentifier to) {
+    Endpoint.check(endpoints, Endpoint.V1_RENAME_VIEW);
     checkViewIdentifierIsValid(from);
     checkViewIdentifierIsValid(to);
 
@@ -1264,6 +1322,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
     @Override
     public View create() {
+      Endpoint.check(endpoints, Endpoint.V1_CREATE_VIEW);
       Preconditions.checkState(
           !representations.isEmpty(), "Cannot create view without specifying a query");
       Preconditions.checkState(null != schema, "Cannot create view without specifying schema");
@@ -1301,7 +1360,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
       AuthSession session = tableSession(response.config(), session(context));
       RESTViewOperations ops =
           new RESTViewOperations(
-              client, paths.view(identifier), session::headers, response.metadata());
+              client, paths.view(identifier), session::headers, response.metadata(), endpoints);
 
       return new BaseView(ops, ViewUtil.fullViewName(name(), identifier));
     }
@@ -1325,6 +1384,14 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
     }
 
     private LoadViewResponse loadView() {
+      Endpoint.check(
+          endpoints,
+          Endpoint.V1_LOAD_VIEW,
+          () ->
+              new NoSuchViewException(
+                  "Unable to load view %s.%s: Server does not support endpoint %s",
+                  name(), identifier, Endpoint.V1_LOAD_VIEW));
+
       return client.get(
           paths.view(identifier),
           LoadViewResponse.class,
@@ -1333,6 +1400,7 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
     }
 
     private View replace(LoadViewResponse response) {
+      Endpoint.check(endpoints, Endpoint.V1_UPDATE_VIEW);
       Preconditions.checkState(
           !representations.isEmpty(), "Cannot replace view without specifying a query");
       Preconditions.checkState(null != schema, "Cannot replace view without specifying schema");
@@ -1371,7 +1439,8 @@ public class RESTSessionCatalog extends BaseViewSessionCatalog
 
       AuthSession session = tableSession(response.config(), session(context));
       RESTViewOperations ops =
-          new RESTViewOperations(client, paths.view(identifier), session::headers, metadata);
+          new RESTViewOperations(
+              client, paths.view(identifier), session::headers, metadata, endpoints);
 
       ops.commit(metadata, replacement);
 
