@@ -69,7 +69,7 @@ public abstract class TestMetrics {
 
   @Parameters(name = "formatVersion = {0}")
   public static List<Object> parameters() {
-    return Arrays.asList(1, 2);
+    return Arrays.asList(1, 2, 3);
   }
 
   @TempDir public Path temp;
