@@ -20,6 +20,8 @@ package org.apache.iceberg;
 
 import static org.apache.iceberg.types.Types.NestedField.optional;
 import static org.apache.iceberg.types.Types.NestedField.required;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.util.List;
 import java.util.concurrent.atomic.AtomicInteger;
@@ -42,7 +44,6 @@ import org.apache.iceberg.types.Types.StructType;
 import org.apache.iceberg.types.Types.TimeType;
 import org.apache.iceberg.types.Types.TimestampType;
 import org.apache.iceberg.types.Types.UUIDType;
-import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.Test;
 
 public class TestSchemaUnionByFieldName {
@@ -82,7 +83,7 @@ public class TestSchemaUnionByFieldName {
   public void testAddTopLevelPrimitives() {
     Schema newSchema = new Schema(primitiveFields(0, primitiveTypes()));
     Schema applied = new SchemaUpdate(new Schema(), 0).unionByNameWith(newSchema).apply();
-    Assertions.assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
+    assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
   }
 
   @Test
@@ -91,7 +92,7 @@ public class TestSchemaUnionByFieldName {
       Schema newSchema =
           new Schema(optional(1, "aList", Types.ListType.ofOptional(2, primitiveType)));
       Schema applied = new SchemaUpdate(new Schema(), 0).unionByNameWith(newSchema).apply();
-      Assertions.assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
+      assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
     }
   }
 
@@ -102,7 +103,7 @@ public class TestSchemaUnionByFieldName {
           new Schema(
               optional(1, "aMap", Types.MapType.ofOptional(2, 3, primitiveType, primitiveType)));
       Schema applied = new SchemaUpdate(new Schema(), 0).unionByNameWith(newSchema).apply();
-      Assertions.assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
+      assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
     }
   }
 
@@ -113,7 +114,7 @@ public class TestSchemaUnionByFieldName {
           new Schema(
               optional(1, "aStruct", Types.StructType.of(optional(2, "primitive", primitiveType))));
       Schema applied = new SchemaUpdate(new Schema(), 0).unionByNameWith(currentSchema).apply();
-      Assertions.assertThat(applied.asStruct()).isEqualTo(currentSchema.asStruct());
+      assertThat(applied.asStruct()).isEqualTo(currentSchema.asStruct());
     }
   }
 
@@ -125,7 +126,7 @@ public class TestSchemaUnionByFieldName {
           new Schema(
               optional(1, "aStruct", Types.StructType.of(optional(2, "primitive", primitiveType))));
       Schema applied = new SchemaUpdate(currentSchema, 1).unionByNameWith(newSchema).apply();
-      Assertions.assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
+      assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
     }
   }
 
@@ -136,7 +137,7 @@ public class TestSchemaUnionByFieldName {
         new Schema(
             optional(1, "aStruct", Types.StructType.of(primitiveFields(1, primitiveTypes()))));
     Schema applied = new SchemaUpdate(currentSchema, 1).unionByNameWith(newSchema).apply();
-    Assertions.assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
+    assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
   }
 
   @Test
@@ -165,7 +166,7 @@ public class TestSchemaUnionByFieldName {
                                                 Types.ListType.ofOptional(
                                                     10, DecimalType.of(11, 20))))))))))));
     Schema applied = new SchemaUpdate(new Schema(), 0).unionByNameWith(newSchema).apply();
-    Assertions.assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
+    assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
   }
 
   @Test
@@ -201,7 +202,7 @@ public class TestSchemaUnionByFieldName {
                                                                 "aString",
                                                                 StringType.get()))))))))))))));
     Schema applied = new SchemaUpdate(new Schema(), 0).unionByNameWith(newSchema).apply();
-    Assertions.assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
+    assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
   }
 
   @Test
@@ -234,7 +235,7 @@ public class TestSchemaUnionByFieldName {
                                     Types.MapType.ofOptional(
                                         12, 13, StringType.get(), StringType.get()))))))));
     Schema applied = new SchemaUpdate(new Schema(), 0).unionByNameWith(newSchema).apply();
-    Assertions.assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
+    assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
   }
 
   @Test
@@ -243,8 +244,7 @@ public class TestSchemaUnionByFieldName {
         new Schema(optional(1, "aList", Types.ListType.ofOptional(2, StringType.get())));
     Schema newSchema =
         new Schema(optional(1, "aList", Types.ListType.ofOptional(2, LongType.get())));
-    Assertions.assertThatThrownBy(
-            () -> new SchemaUpdate(currentSchema, 2).unionByNameWith(newSchema).apply())
+    assertThatThrownBy(() -> new SchemaUpdate(currentSchema, 2).unionByNameWith(newSchema).apply())
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Cannot change column type: aList.element: string -> long");
   }
@@ -260,8 +260,7 @@ public class TestSchemaUnionByFieldName {
         new Schema(
             optional(1, "aMap", Types.MapType.ofOptional(2, 3, StringType.get(), LongType.get())));
 
-    Assertions.assertThatThrownBy(
-            () -> new SchemaUpdate(currentSchema, 3).unionByNameWith(newSchema).apply())
+    assertThatThrownBy(() -> new SchemaUpdate(currentSchema, 3).unionByNameWith(newSchema).apply())
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Cannot change column type: aMap.value: string -> long");
   }
@@ -275,8 +274,7 @@ public class TestSchemaUnionByFieldName {
     Schema newSchema =
         new Schema(
             optional(1, "aMap", Types.MapType.ofOptional(2, 3, UUIDType.get(), StringType.get())));
-    Assertions.assertThatThrownBy(
-            () -> new SchemaUpdate(currentSchema, 3).unionByNameWith(newSchema).apply())
+    assertThatThrownBy(() -> new SchemaUpdate(currentSchema, 3).unionByNameWith(newSchema).apply())
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Cannot change column type: aMap.key: string -> uuid");
   }
@@ -288,8 +286,8 @@ public class TestSchemaUnionByFieldName {
     Schema newSchema = new Schema(required(1, "aCol", LongType.get()));
 
     Schema applied = new SchemaUpdate(currentSchema, 1).unionByNameWith(newSchema).apply();
-    Assertions.assertThat(applied.asStruct().fields()).hasSize(1);
-    Assertions.assertThat(applied.asStruct().fields().get(0).type()).isEqualTo(LongType.get());
+    assertThat(applied.asStruct().fields()).hasSize(1);
+    assertThat(applied.asStruct().fields().get(0).type()).isEqualTo(LongType.get());
   }
 
   @Test
@@ -299,9 +297,9 @@ public class TestSchemaUnionByFieldName {
     Schema newSchema = new Schema(required(1, "aCol", DoubleType.get()));
 
     Schema applied = new SchemaUpdate(currentSchema, 1).unionByNameWith(newSchema).apply();
-    Assertions.assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
-    Assertions.assertThat(applied.asStruct().fields()).hasSize(1);
-    Assertions.assertThat(applied.asStruct().fields().get(0).type()).isEqualTo(DoubleType.get());
+    assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
+    assertThat(applied.asStruct().fields()).hasSize(1);
+    assertThat(applied.asStruct().fields().get(0).type()).isEqualTo(DoubleType.get());
   }
 
   @Test
@@ -309,8 +307,7 @@ public class TestSchemaUnionByFieldName {
     Schema currentSchema = new Schema(required(1, "aCol", DoubleType.get()));
     Schema newSchema = new Schema(required(1, "aCol", FloatType.get()));
 
-    Assertions.assertThatThrownBy(
-            () -> new SchemaUpdate(currentSchema, 1).unionByNameWith(newSchema).apply())
+    assertThatThrownBy(() -> new SchemaUpdate(currentSchema, 1).unionByNameWith(newSchema).apply())
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Cannot change column type: aCol: double -> float");
   }
@@ -323,7 +320,7 @@ public class TestSchemaUnionByFieldName {
     Schema newSchema = new Schema(required(1, "aCol", DecimalType.of(22, 1)));
 
     Schema applied = new SchemaUpdate(currentSchema, 1).unionByNameWith(newSchema).apply();
-    Assertions.assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
+    assertThat(applied.asStruct()).isEqualTo(newSchema.asStruct());
   }
 
   @Test
@@ -384,7 +381,7 @@ public class TestSchemaUnionByFieldName {
                                         optional(5, "value", StringType.get()),
                                         optional(6, "time", TimeType.get())))))))));
 
-    Assertions.assertThat(applied.asStruct()).isEqualTo(expected.asStruct());
+    assertThat(applied.asStruct()).isEqualTo(expected.asStruct());
   }
 
   @Test
@@ -392,8 +389,7 @@ public class TestSchemaUnionByFieldName {
     Schema currentSchema =
         new Schema(optional(1, "aColumn", Types.ListType.ofOptional(2, StringType.get())));
     Schema newSchema = new Schema(optional(1, "aColumn", StringType.get()));
-    Assertions.assertThatThrownBy(
-            () -> new SchemaUpdate(currentSchema, 2).unionByNameWith(newSchema).apply())
+    assertThatThrownBy(() -> new SchemaUpdate(currentSchema, 2).unionByNameWith(newSchema).apply())
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Cannot change column type: aColumn: list<string> -> string");
   }
@@ -423,7 +419,7 @@ public class TestSchemaUnionByFieldName {
 
     Schema union = new SchemaUpdate(aSchema, 0).unionByNameWith(mirrored).apply();
     // We don't expect the original schema to have been altered.
-    Assertions.assertThat(union.asStruct()).isEqualTo(aSchema.asStruct());
+    assertThat(union.asStruct()).isEqualTo(aSchema.asStruct());
   }
 
   @Test
@@ -459,7 +455,7 @@ public class TestSchemaUnionByFieldName {
                         7, "d1", Types.StructType.of(optional(8, "d2", Types.StringType.get()))))));
 
     Schema union = new SchemaUpdate(schema, 5).unionByNameWith(observed).apply();
-    Assertions.assertThat(union.asStruct()).isEqualTo(observed.asStruct());
+    assertThat(union.asStruct()).isEqualTo(observed.asStruct());
   }
 
   @Test
@@ -510,7 +506,7 @@ public class TestSchemaUnionByFieldName {
                                                                 StringType.get()))))))))))))));
 
     Schema applied = new SchemaUpdate(schema, 4).unionByNameWith(observed).apply();
-    Assertions.assertThat(applied.asStruct()).isEqualTo(observed.asStruct());
+    assertThat(applied.asStruct()).isEqualTo(observed.asStruct());
   }
 
   @Test
@@ -575,6 +571,6 @@ public class TestSchemaUnionByFieldName {
                                         "list2",
                                         ListType.ofOptional(7, StringType.get())))))))));
 
-    Assertions.assertThat(union.asStruct()).isEqualTo(expected.asStruct());
+    assertThat(union.asStruct()).isEqualTo(expected.asStruct());
   }
 }
