@@ -76,7 +76,7 @@ public class TestSortOrder {
 
   @Parameters(name = "formatVersion = {0}")
   protected static List<Object> parameters() {
-    return Arrays.asList(1, 2);
+    return Arrays.asList(1, 2, 3);
   }
 
   @Parameter private int formatVersion;
