@@ -32,6 +32,7 @@ import static org.apache.iceberg.TestHelpers.assertSameSchemaList;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.assertj.core.api.Assertions.entry;
+import static org.junit.jupiter.params.provider.Arguments.arguments;
 
 import com.fasterxml.jackson.core.JsonGenerator;
 import java.io.File;
@@ -49,6 +50,8 @@ import java.util.Random;
 import java.util.Set;
 import java.util.SortedSet;
 import java.util.UUID;
+import java.util.stream.IntStream;
+import java.util.stream.Stream;
 import org.apache.iceberg.TableMetadata.MetadataLogEntry;
 import org.apache.iceberg.TableMetadata.SnapshotLogEntry;
 import org.apache.iceberg.exceptions.ValidationException;
@@ -63,6 +66,9 @@ import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.JsonUtil;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.io.TempDir;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.MethodSource;
 
 public class TestTableMetadata {
   private static final String TEST_LOCATION = "s3://bucket/test/location";
@@ -1451,8 +1457,20 @@ public class TestTableMetadata {
         .doesNotContainKey(TableProperties.FORMAT_VERSION);
   }
 
-  @Test
-  public void testReplaceV1MetadataToV2ThroughTableProperty() {
+  private static Stream<Arguments> upgradeFormatVersionProvider() {
+    // return a stream of all valid upgrade paths
+    return IntStream.range(1, TableMetadata.SUPPORTED_TABLE_FORMAT_VERSION)
+        .boxed()
+        .flatMap(
+            baseFormatVersion ->
+                IntStream.rangeClosed(
+                        baseFormatVersion + 1, TableMetadata.SUPPORTED_TABLE_FORMAT_VERSION)
+                    .mapToObj(newFormatVersion -> arguments(baseFormatVersion, newFormatVersion)));
+  }
+
+  @ParameterizedTest
+  @MethodSource("upgradeFormatVersionProvider")
+  public void testReplaceMetadataThroughTableProperty(int baseFormatVersion, int newFormatVersion) {
     Schema schema = new Schema(Types.NestedField.required(10, "x", Types.StringType.get()));
 
     TableMetadata meta =
@@ -1460,7 +1478,8 @@ public class TestTableMetadata {
             schema,
             PartitionSpec.unpartitioned(),
             null,
-            ImmutableMap.of(TableProperties.FORMAT_VERSION, "1", "key", "val"));
+            ImmutableMap.of(
+                TableProperties.FORMAT_VERSION, String.valueOf(baseFormatVersion), "key", "val"));
 
     meta =
         meta.buildReplacement(
@@ -1468,17 +1487,19 @@ public class TestTableMetadata {
             meta.spec(),
             meta.sortOrder(),
             meta.location(),
-            ImmutableMap.of(TableProperties.FORMAT_VERSION, "2", "key2", "val2"));
+            ImmutableMap.of(
+                TableProperties.FORMAT_VERSION, String.valueOf(newFormatVersion), "key2", "val2"));
 
-    assertThat(meta.formatVersion()).isEqualTo(2);
+    assertThat(meta.formatVersion()).isEqualTo(newFormatVersion);
     assertThat(meta.properties())
         .containsEntry("key", "val")
         .containsEntry("key2", "val2")
         .doesNotContainKey(TableProperties.FORMAT_VERSION);
   }
 
-  @Test
-  public void testUpgradeV1MetadataToV2ThroughTableProperty() {
+  @ParameterizedTest
+  @MethodSource("upgradeFormatVersionProvider")
+  public void testUpgradeMetadataThroughTableProperty(int baseFormatVersion, int newFormatVersion) {
     Schema schema = new Schema(Types.NestedField.required(10, "x", Types.StringType.get()));
 
     TableMetadata meta =
@@ -1486,15 +1507,17 @@ public class TestTableMetadata {
             schema,
             PartitionSpec.unpartitioned(),
             null,
-            ImmutableMap.of(TableProperties.FORMAT_VERSION, "1", "key", "val"));
+            ImmutableMap.of(
+                TableProperties.FORMAT_VERSION, String.valueOf(baseFormatVersion), "key", "val"));
 
     meta =
         meta.replaceProperties(
-            ImmutableMap.of(TableProperties.FORMAT_VERSION, "2", "key2", "val2"));
+            ImmutableMap.of(
+                TableProperties.FORMAT_VERSION, String.valueOf(newFormatVersion), "key2", "val2"));
 
     assertThat(meta.formatVersion())
         .as("format version should be configured based on the format-version key")
-        .isEqualTo(2);
+        .isEqualTo(newFormatVersion);
     assertThat(meta.properties())
         .as("should not contain format-version but should contain new properties")
         .containsExactly(entry("key2", "val2"));
@@ -1612,4 +1635,89 @@ public class TestTableMetadata {
         .hasSize(2)
         .containsExactlyElementsOf(metadata.snapshotLog());
   }
+
+  @Test
+  public void testConstructV3Metadata() {
+    TableMetadata.newTableMetadata(
+        TEST_SCHEMA,
+        PartitionSpec.unpartitioned(),
+        SortOrder.unsorted(),
+        TEST_LOCATION,
+        ImmutableMap.of(),
+        3);
+  }
+
+  @Test
+  public void testV3TimestampNanoTypeSupport() {
+    Schema v3Schema =
+        new Schema(
+            Types.NestedField.required(3, "id", Types.LongType.get()),
+            Types.NestedField.required(4, "data", Types.StringType.get()),
+            Types.NestedField.required(
+                5,
+                "struct",
+                Types.StructType.of(
+                    Types.NestedField.optional(
+                        6, "ts_nanos", Types.TimestampNanoType.withZone()))));
+
+    for (int unsupportedFormatVersion : ImmutableList.of(1, 2)) {
+      assertThatThrownBy(
+              () ->
+                  TableMetadata.newTableMetadata(
+                      v3Schema,
+                      PartitionSpec.unpartitioned(),
+                      SortOrder.unsorted(),
+                      TEST_LOCATION,
+                      ImmutableMap.of(),
+                      unsupportedFormatVersion))
+          .isInstanceOf(IllegalStateException.class)
+          .hasMessage(
+              "Invalid schema for v%s:\n"
+                  + "- Invalid type for struct.ts_nanos: timestamptz_ns is not supported until v3",
+              unsupportedFormatVersion);
+    }
+
+    // should be allowed in v3
+    TableMetadata.newTableMetadata(
+        v3Schema,
+        PartitionSpec.unpartitioned(),
+        SortOrder.unsorted(),
+        TEST_LOCATION,
+        ImmutableMap.of(),
+        3);
+  }
+
+  @Test
+  public void onlyMetadataLocationIsUpdatedWithoutTimestampAndMetadataLogEntry() {
+    String uuid = "386b9f01-002b-4d8c-b77f-42c3fd3b7c9b";
+    TableMetadata metadata =
+        TableMetadata.buildFromEmpty()
+            .assignUUID(uuid)
+            .setLocation("location")
+            .setCurrentSchema(TEST_SCHEMA, 3)
+            .addPartitionSpec(PartitionSpec.unpartitioned())
+            .addSortOrder(SortOrder.unsorted())
+            .discardChanges()
+            .withMetadataLocation("original-metadata-location")
+            .build();
+
+    assertThat(metadata.previousFiles()).isEmpty();
+    assertThat(metadata.metadataFileLocation()).isEqualTo("original-metadata-location");
+
+    // this will only update the metadata location without writing a new metadata log entry or
+    // updating lastUpdatedMillis
+    TableMetadata newMetadata =
+        TableMetadata.buildFrom(metadata).withMetadataLocation("new-metadata-location").build();
+    assertThat(newMetadata.lastUpdatedMillis()).isEqualTo(metadata.lastUpdatedMillis());
+    assertThat(newMetadata.metadataFileLocation()).isEqualTo("new-metadata-location");
+    assertThat(newMetadata.previousFiles()).isEmpty();
+
+    TableMetadata updatedMetadata =
+        TableMetadata.buildFrom(newMetadata)
+            .withMetadataLocation("updated-metadata-location")
+            .build();
+    assertThat(updatedMetadata.lastUpdatedMillis()).isEqualTo(newMetadata.lastUpdatedMillis());
+    assertThat(updatedMetadata.metadataFileLocation()).isEqualTo("updated-metadata-location");
+    assertThat(updatedMetadata.previousFiles()).isEmpty();
+  }
 }
