@@ -42,7 +42,7 @@ import org.junit.jupiter.api.extension.ExtendWith;
 public class TestTransaction extends TestBase {
   @Parameters(name = "formatVersion = {0}")
   protected static List<Object> parameters() {
-    return Arrays.asList(1, 2);
+    return Arrays.asList(1, 2, 3);
   }
 
   @TestTemplate
