@@ -18,6 +18,10 @@
  */
 package org.apache.iceberg.avro;
 
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assertions.within;
+
 import java.io.IOException;
 import java.nio.file.Path;
 import java.util.List;
@@ -31,7 +35,6 @@ import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.types.Comparators;
 import org.apache.iceberg.types.Types;
-import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.io.TempDir;
 
@@ -54,11 +57,9 @@ public abstract class TestReadProjection {
 
     Record projected = writeAndRead("full_projection", schema, schema, record);
 
-    Assertions.assertThat((Long) projected.get("id"))
-        .as("Should contain the correct id value")
-        .isEqualTo(34L);
+    assertThat((Long) projected.get("id")).as("Should contain the correct id value").isEqualTo(34L);
     int cmp = Comparators.charSequences().compare("test", (CharSequence) projected.get("data"));
-    Assertions.assertThat(cmp).as("Should contain the correct data value").isEqualTo(0);
+    assertThat(cmp).as("Should contain the correct data value").isEqualTo(0);
   }
 
   @Test
@@ -78,10 +79,10 @@ public abstract class TestReadProjection {
             Types.NestedField.required(0, "id", Types.LongType.get()));
 
     Record projected = writeAndRead("full_projection", schema, reordered, record);
-    Assertions.assertThat(projected.get(0).toString())
+    assertThat(projected.get(0).toString())
         .as("Should contain the correct 0 value")
         .isEqualTo("test");
-    Assertions.assertThat(projected.get(1)).as("Should contain the correct 1 value").isEqualTo(34L);
+    assertThat(projected.get(1)).as("Should contain the correct 1 value").isEqualTo(34L);
   }
 
   @Test
@@ -102,11 +103,11 @@ public abstract class TestReadProjection {
             Types.NestedField.optional(3, "missing_2", Types.LongType.get()));
 
     Record projected = writeAndRead("full_projection", schema, reordered, record);
-    Assertions.assertThat(projected.get(0)).as("Should contain the correct 0 value").isNull();
-    Assertions.assertThat(projected.get(1).toString())
+    assertThat(projected.get(0)).as("Should contain the correct 0 value").isNull();
+    assertThat(projected.get(1).toString())
         .as("Should contain the correct 1 value")
         .isEqualTo("test");
-    Assertions.assertThat(projected.get(2)).as("Should contain the correct 2 value").isNull();
+    assertThat(projected.get(2)).as("Should contain the correct 2 value").isNull();
   }
 
   @Test
@@ -122,10 +123,9 @@ public abstract class TestReadProjection {
 
     Record projected = writeAndRead("empty_projection", schema, schema.select(), record);
 
-    Assertions.assertThat(projected).as("Should read a non-null record").isNotNull();
+    assertThat(projected).as("Should read a non-null record").isNotNull();
     // this is expected because there are no values
-    Assertions.assertThatThrownBy(() -> projected.get(0))
-        .isInstanceOf(ArrayIndexOutOfBoundsException.class);
+    assertThatThrownBy(() -> projected.get(0)).isInstanceOf(ArrayIndexOutOfBoundsException.class);
   }
 
   @Test
@@ -143,9 +143,7 @@ public abstract class TestReadProjection {
 
     Record projected = writeAndRead("basic_projection_id", writeSchema, idOnly, record);
     assertEmptyAvroField(projected, "data");
-    Assertions.assertThat((Long) projected.get("id"))
-        .as("Should contain the correct id value")
-        .isEqualTo(34L);
+    assertThat((Long) projected.get("id")).as("Should contain the correct id value").isEqualTo(34L);
 
     Schema dataOnly = new Schema(Types.NestedField.optional(1, "data", Types.StringType.get()));
 
@@ -153,7 +151,7 @@ public abstract class TestReadProjection {
 
     assertEmptyAvroField(projected, "id");
     int cmp = Comparators.charSequences().compare("test", (CharSequence) projected.get("data"));
-    Assertions.assertThat(cmp).as("Should contain the correct data value").isEqualTo(0);
+    assertThat(cmp).as("Should contain the correct data value").isEqualTo(0);
   }
 
   @Test
@@ -174,11 +172,9 @@ public abstract class TestReadProjection {
 
     Record projected = writeAndRead("project_and_rename", writeSchema, readSchema, record);
 
-    Assertions.assertThat((Long) projected.get("id"))
-        .as("Should contain the correct id value")
-        .isEqualTo(34L);
+    assertThat((Long) projected.get("id")).as("Should contain the correct id value").isEqualTo(34L);
     int cmp = Comparators.charSequences().compare("test", (CharSequence) projected.get("renamed"));
-    Assertions.assertThat(cmp).as("Should contain the correct data/renamed value").isEqualTo(0);
+    assertThat(cmp).as("Should contain the correct data/renamed value").isEqualTo(0);
   }
 
   @Test
@@ -205,9 +201,7 @@ public abstract class TestReadProjection {
 
     Record projected = writeAndRead("id_only", writeSchema, idOnly, record);
     assertEmptyAvroField(projected, "location");
-    Assertions.assertThat((long) projected.get("id"))
-        .as("Should contain the correct id value")
-        .isEqualTo(34L);
+    assertThat((long) projected.get("id")).as("Should contain the correct id value").isEqualTo(34L);
 
     Schema latOnly =
         new Schema(
@@ -219,11 +213,11 @@ public abstract class TestReadProjection {
     projected = writeAndRead("latitude_only", writeSchema, latOnly, record);
     Record projectedLocation = (Record) projected.get("location");
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(projected.get("location")).as("Should project location").isNotNull();
+    assertThat(projected.get("location")).as("Should project location").isNotNull();
     assertEmptyAvroField(projectedLocation, "long");
-    Assertions.assertThat((Float) projectedLocation.get("lat"))
+    assertThat((Float) projectedLocation.get("lat"))
         .as("Should project latitude")
-        .isCloseTo(52.995143f, Assertions.within(0.000001f));
+        .isCloseTo(52.995143f, within(0.000001f));
 
     Schema longOnly =
         new Schema(
@@ -235,23 +229,23 @@ public abstract class TestReadProjection {
     projected = writeAndRead("longitude_only", writeSchema, longOnly, record);
     projectedLocation = (Record) projected.get("location");
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(projected.get("location")).as("Should project location").isNotNull();
+    assertThat(projected.get("location")).as("Should project location").isNotNull();
     assertEmptyAvroField(projectedLocation, "lat");
-    Assertions.assertThat((Float) projectedLocation.get("long"))
+    assertThat((Float) projectedLocation.get("long"))
         .as("Should project longitude")
-        .isCloseTo(-1.539054f, Assertions.within(0.000001f));
+        .isCloseTo(-1.539054f, within(0.000001f));
 
     Schema locationOnly = writeSchema.select("location");
     projected = writeAndRead("location_only", writeSchema, locationOnly, record);
     projectedLocation = (Record) projected.get("location");
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(projected.get("location")).as("Should project location").isNotNull();
-    Assertions.assertThat((Float) projectedLocation.get("lat"))
+    assertThat(projected.get("location")).as("Should project location").isNotNull();
+    assertThat((Float) projectedLocation.get("lat"))
         .as("Should project latitude")
-        .isCloseTo(52.995143f, Assertions.within(0.000001f));
-    Assertions.assertThat((Float) projectedLocation.get("long"))
+        .isCloseTo(52.995143f, within(0.000001f));
+    assertThat((Float) projectedLocation.get("long"))
         .as("Should project longitude")
-        .isCloseTo(-1.539054f, Assertions.within(0.000001f));
+        .isCloseTo(-1.539054f, within(0.000001f));
   }
 
   @Test
@@ -273,29 +267,27 @@ public abstract class TestReadProjection {
     Schema idOnly = new Schema(Types.NestedField.required(0, "id", Types.LongType.get()));
 
     Record projected = writeAndRead("id_only", writeSchema, idOnly, record);
-    Assertions.assertThat((long) projected.get("id"))
-        .as("Should contain the correct id value")
-        .isEqualTo(34L);
+    assertThat((long) projected.get("id")).as("Should contain the correct id value").isEqualTo(34L);
     assertEmptyAvroField(projected, "properties");
 
     Schema keyOnly = writeSchema.select("properties.key");
     projected = writeAndRead("key_only", writeSchema, keyOnly, record);
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(toStringMap((Map) projected.get("properties")))
+    assertThat(toStringMap((Map) projected.get("properties")))
         .as("Should project entire map")
         .isEqualTo(properties);
 
     Schema valueOnly = writeSchema.select("properties.value");
     projected = writeAndRead("value_only", writeSchema, valueOnly, record);
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(toStringMap((Map) projected.get("properties")))
+    assertThat(toStringMap((Map) projected.get("properties")))
         .as("Should project entire map")
         .isEqualTo(properties);
 
     Schema mapOnly = writeSchema.select("properties");
     projected = writeAndRead("map_only", writeSchema, mapOnly, record);
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(toStringMap((Map) projected.get("properties")))
+    assertThat(toStringMap((Map) projected.get("properties")))
         .as("Should project entire map")
         .isEqualTo(properties);
   }
@@ -345,57 +337,51 @@ public abstract class TestReadProjection {
     Schema idOnly = new Schema(Types.NestedField.required(0, "id", Types.LongType.get()));
 
     Record projected = writeAndRead("id_only", writeSchema, idOnly, record);
-    Assertions.assertThat((long) projected.get("id"))
-        .as("Should contain the correct id value")
-        .isEqualTo(34L);
+    assertThat((long) projected.get("id")).as("Should contain the correct id value").isEqualTo(34L);
     assertEmptyAvroField(projected, "locations");
 
     projected = writeAndRead("all_locations", writeSchema, writeSchema.select("locations"), record);
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(toStringMap((Map) projected.get("locations")))
+    assertThat(toStringMap((Map) projected.get("locations")))
         .as("Should project locations map")
         .isEqualTo(record.get("locations"));
 
     projected = writeAndRead("lat_only", writeSchema, writeSchema.select("locations.lat"), record);
     assertEmptyAvroField(projected, "id");
     Map<String, ?> locations = toStringMap((Map) projected.get("locations"));
-    Assertions.assertThat(locations).as("Should project locations map").isNotNull();
-    Assertions.assertThat(locations.keySet())
-        .as("Should contain L1 and L2")
-        .containsExactly("L1", "L2");
+    assertThat(locations).as("Should project locations map").isNotNull();
+    assertThat(locations.keySet()).as("Should contain L1 and L2").containsExactly("L1", "L2");
     Record projectedL1 = (Record) locations.get("L1");
-    Assertions.assertThat(projectedL1).as("L1 should not be null").isNotNull();
-    Assertions.assertThat((float) projectedL1.get("lat"))
+    assertThat(projectedL1).as("L1 should not be null").isNotNull();
+    assertThat((float) projectedL1.get("lat"))
         .as("L1 should contain lat")
-        .isCloseTo(53.992811f, Assertions.within(0.000001f));
+        .isCloseTo(53.992811f, within(0.000001f));
     assertEmptyAvroField(projectedL1, "long");
     Record projectedL2 = (Record) locations.get("L2");
-    Assertions.assertThat(projectedL2).as("L2 should not be null").isNotNull();
-    Assertions.assertThat((float) projectedL2.get("lat"))
+    assertThat(projectedL2).as("L2 should not be null").isNotNull();
+    assertThat((float) projectedL2.get("lat"))
         .as("L2 should contain lat")
-        .isCloseTo(52.995143f, Assertions.within(0.000001f));
+        .isCloseTo(52.995143f, within(0.000001f));
     assertEmptyAvroField(projectedL2, "y");
 
     projected =
         writeAndRead("long_only", writeSchema, writeSchema.select("locations.long"), record);
     assertEmptyAvroField(projected, "id");
     locations = toStringMap((Map) projected.get("locations"));
-    Assertions.assertThat(locations).as("Should project locations map").isNotNull();
-    Assertions.assertThat(locations.keySet())
-        .as("Should contain L1 and L2")
-        .containsExactly("L1", "L2");
+    assertThat(locations).as("Should project locations map").isNotNull();
+    assertThat(locations.keySet()).as("Should contain L1 and L2").containsExactly("L1", "L2");
     projectedL1 = (Record) locations.get("L1");
-    Assertions.assertThat(projectedL1).as("L1 should not be null").isNotNull();
+    assertThat(projectedL1).as("L1 should not be null").isNotNull();
     assertEmptyAvroField(projectedL1, "lat");
-    Assertions.assertThat((float) projectedL1.get("long"))
+    assertThat((float) projectedL1.get("long"))
         .as("L1 should contain long")
-        .isCloseTo(-1.542616f, Assertions.within(0.000001f));
+        .isCloseTo(-1.542616f, within(0.000001f));
     projectedL2 = (Record) locations.get("L2");
-    Assertions.assertThat(projectedL2).as("L2 should not be null").isNotNull();
+    assertThat(projectedL2).as("L2 should not be null").isNotNull();
     assertEmptyAvroField(projectedL2, "lat");
-    Assertions.assertThat((float) projectedL2.get("long"))
+    assertThat((float) projectedL2.get("long"))
         .as("L2 should contain long")
-        .isCloseTo(-1.539054f, Assertions.within(0.000001f));
+        .isCloseTo(-1.539054f, within(0.000001f));
 
     Schema latitiudeRenamed =
         new Schema(
@@ -412,22 +398,20 @@ public abstract class TestReadProjection {
     projected = writeAndRead("latitude_renamed", writeSchema, latitiudeRenamed, record);
     assertEmptyAvroField(projected, "id");
     locations = toStringMap((Map) projected.get("locations"));
-    Assertions.assertThat(locations).as("Should project locations map").isNotNull();
-    Assertions.assertThat(locations.keySet())
-        .as("Should contain L1 and L2")
-        .containsExactly("L1", "L2");
+    assertThat(locations).as("Should project locations map").isNotNull();
+    assertThat(locations.keySet()).as("Should contain L1 and L2").containsExactly("L1", "L2");
     projectedL1 = (Record) locations.get("L1");
-    Assertions.assertThat(projectedL1).as("L1 should not be null").isNotNull();
-    Assertions.assertThat((float) projectedL1.get("latitude"))
+    assertThat(projectedL1).as("L1 should not be null").isNotNull();
+    assertThat((float) projectedL1.get("latitude"))
         .as("L1 should contain latitude")
-        .isCloseTo(53.992811f, Assertions.within(0.000001f));
+        .isCloseTo(53.992811f, within(0.000001f));
     assertEmptyAvroField(projectedL1, "lat");
     assertEmptyAvroField(projectedL1, "long");
     projectedL2 = (Record) locations.get("L2");
-    Assertions.assertThat(projectedL2).as("L2 should not be null").isNotNull();
-    Assertions.assertThat((float) projectedL2.get("latitude"))
+    assertThat(projectedL2).as("L2 should not be null").isNotNull();
+    assertThat((float) projectedL2.get("latitude"))
         .as("L2 should contain latitude")
-        .isCloseTo(52.995143f, Assertions.within(0.000001f));
+        .isCloseTo(52.995143f, within(0.000001f));
     assertEmptyAvroField(projectedL2, "lat");
     assertEmptyAvroField(projectedL2, "long");
   }
@@ -449,24 +433,18 @@ public abstract class TestReadProjection {
     Schema idOnly = new Schema(Types.NestedField.required(0, "id", Types.LongType.get()));
 
     Record projected = writeAndRead("id_only", writeSchema, idOnly, record);
-    Assertions.assertThat((long) projected.get("id"))
-        .as("Should contain the correct id value")
-        .isEqualTo(34L);
+    assertThat((long) projected.get("id")).as("Should contain the correct id value").isEqualTo(34L);
     assertEmptyAvroField(projected, "values");
 
     Schema elementOnly = writeSchema.select("values.element");
     projected = writeAndRead("element_only", writeSchema, elementOnly, record);
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(projected.get("values"))
-        .as("Should project entire list")
-        .isEqualTo(values);
+    assertThat(projected.get("values")).as("Should project entire list").isEqualTo(values);
 
     Schema listOnly = writeSchema.select("values");
     projected = writeAndRead("list_only", writeSchema, listOnly, record);
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(projected.get("values"))
-        .as("Should project entire list")
-        .isEqualTo(values);
+    assertThat(projected.get("values")).as("Should project entire list").isEqualTo(values);
   }
 
   @Test
@@ -501,40 +479,38 @@ public abstract class TestReadProjection {
     Schema idOnly = new Schema(Types.NestedField.required(0, "id", Types.LongType.get()));
 
     Record projected = writeAndRead("id_only", writeSchema, idOnly, record);
-    Assertions.assertThat((long) projected.get("id"))
-        .as("Should contain the correct id value")
-        .isEqualTo(34L);
+    assertThat((long) projected.get("id")).as("Should contain the correct id value").isEqualTo(34L);
     assertEmptyAvroField(projected, "points");
 
     projected = writeAndRead("all_points", writeSchema, writeSchema.select("points"), record);
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(projected.get("points"))
+    assertThat(projected.get("points"))
         .as("Should project points list")
         .isEqualTo(record.get("points"));
 
     projected = writeAndRead("x_only", writeSchema, writeSchema.select("points.x"), record);
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(projected.get("points")).as("Should project points list").isNotNull();
+    assertThat(projected.get("points")).as("Should project points list").isNotNull();
     List<Record> points = (List<Record>) projected.get("points");
-    Assertions.assertThat(points).as("Should read 2 points").hasSize(2);
+    assertThat(points).as("Should read 2 points").hasSize(2);
     Record projectedP1 = points.get(0);
-    Assertions.assertThat((int) projectedP1.get("x")).as("Should project x").isEqualTo(1);
+    assertThat((int) projectedP1.get("x")).as("Should project x").isEqualTo(1);
     assertEmptyAvroField(projectedP1, "y");
     Record projectedP2 = points.get(1);
-    Assertions.assertThat((int) projectedP2.get("x")).as("Should project x").isEqualTo(3);
+    assertThat((int) projectedP2.get("x")).as("Should project x").isEqualTo(3);
     assertEmptyAvroField(projectedP2, "y");
 
     projected = writeAndRead("y_only", writeSchema, writeSchema.select("points.y"), record);
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(projected.get("points")).as("Should project points list").isNotNull();
+    assertThat(projected.get("points")).as("Should project points list").isNotNull();
     points = (List<Record>) projected.get("points");
-    Assertions.assertThat(points).as("Should read 2 points").hasSize(2);
+    assertThat(points).as("Should read 2 points").hasSize(2);
     projectedP1 = points.get(0);
     assertEmptyAvroField(projectedP1, "x");
-    Assertions.assertThat((int) projectedP1.get("y")).as("Should project y").isEqualTo(2);
+    assertThat((int) projectedP1.get("y")).as("Should project y").isEqualTo(2);
     projectedP2 = points.get(1);
     assertEmptyAvroField(projectedP2, "x");
-    Assertions.assertThat(projectedP2.get("y")).as("Should project null y").isNull();
+    assertThat(projectedP2.get("y")).as("Should project null y").isNull();
 
     Schema yRenamed =
         new Schema(
@@ -548,17 +524,17 @@ public abstract class TestReadProjection {
 
     projected = writeAndRead("y_renamed", writeSchema, yRenamed, record);
     assertEmptyAvroField(projected, "id");
-    Assertions.assertThat(projected.get("points")).as("Should project points list").isNotNull();
+    assertThat(projected.get("points")).as("Should project points list").isNotNull();
     points = (List<Record>) projected.get("points");
-    Assertions.assertThat(points).as("Should read 2 points").hasSize(2);
+    assertThat(points).as("Should read 2 points").hasSize(2);
     projectedP1 = points.get(0);
     assertEmptyAvroField(projectedP1, "x");
     assertEmptyAvroField(projectedP1, "y");
-    Assertions.assertThat((int) projectedP1.get("z")).as("Should project z").isEqualTo(2);
+    assertThat((int) projectedP1.get("z")).as("Should project z").isEqualTo(2);
     projectedP2 = points.get(1);
     assertEmptyAvroField(projectedP2, "x");
     assertEmptyAvroField(projectedP2, "y");
-    Assertions.assertThat(projectedP2.get("z")).as("Should project null z").isNull();
+    assertThat(projectedP2.get("z")).as("Should project null z").isNull();
   }
 
   @Test
@@ -588,10 +564,8 @@ public abstract class TestReadProjection {
     assertEmptyAvroField(projected, "id");
     Record result = (Record) projected.get("location");
 
-    Assertions.assertThat(projected.get(0))
-        .as("location should be in the 0th position")
-        .isEqualTo(result);
-    Assertions.assertThat(result).as("Should contain an empty record").isNotNull();
+    assertThat(projected.get(0)).as("location should be in the 0th position").isEqualTo(result);
+    assertThat(result).as("Should contain an empty record").isNotNull();
     assertEmptyAvroField(result, "lat");
     assertEmptyAvroField(result, "long");
   }
@@ -621,10 +595,8 @@ public abstract class TestReadProjection {
     Record projected = writeAndRead("empty_req_proj", writeSchema, emptyStruct, record);
     assertEmptyAvroField(projected, "id");
     Record result = (Record) projected.get("location");
-    Assertions.assertThat(projected.get(0))
-        .as("location should be in the 0th position")
-        .isEqualTo(result);
-    Assertions.assertThat(result).as("Should contain an empty record").isNotNull();
+    assertThat(projected.get(0)).as("location should be in the 0th position").isEqualTo(result);
+    assertThat(result).as("Should contain an empty record").isNotNull();
     assertEmptyAvroField(result, "lat");
     assertEmptyAvroField(result, "long");
   }
@@ -659,19 +631,15 @@ public abstract class TestReadProjection {
                     Types.NestedField.required(4, "empty", Types.StructType.of()))));
 
     Record projected = writeAndRead("req_empty_req_proj", writeSchema, emptyStruct, record);
-    Assertions.assertThat(projected.get("id")).as("Should project id").isEqualTo(34L);
+    assertThat(projected.get("id")).as("Should project id").isEqualTo(34L);
     Record result = (Record) projected.get("location");
-    Assertions.assertThat(projected.get(1))
-        .as("location should be in the 1st position")
-        .isEqualTo(result);
-    Assertions.assertThat(result).as("Should contain an empty record").isNotNull();
+    assertThat(projected.get(1)).as("location should be in the 1st position").isEqualTo(result);
+    assertThat(result).as("Should contain an empty record").isNotNull();
     assertEmptyAvroField(result, "lat");
     assertEmptyAvroField(result, "long");
-    Assertions.assertThat(result.getSchema().getField("empty"))
-        .as("Should project empty")
-        .isNotNull();
-    Assertions.assertThat(result.get("empty")).as("Empty should not be null").isNotNull();
-    Assertions.assertThat(((Record) result.get("empty")).getSchema().getFields())
+    assertThat(result.getSchema().getField("empty")).as("Should project empty").isNotNull();
+    assertThat(result.get("empty")).as("Empty should not be null").isNotNull();
+    assertThat(((Record) result.get("empty")).getSchema().getFields())
         .as("Empty should be empty")
         .isEmpty();
   }
@@ -714,16 +682,12 @@ public abstract class TestReadProjection {
     Record projected = writeAndRead("nested_empty_proj", writeSchema, emptyStruct, record);
     assertEmptyAvroField(projected, "id");
     Record outerResult = (Record) projected.get("outer");
-    Assertions.assertThat(projected.get(0))
-        .as("Outer should be in the 0th position")
-        .isEqualTo(outerResult);
-    Assertions.assertThat(outerResult).as("Should contain the outer record").isNotNull();
+    assertThat(projected.get(0)).as("Outer should be in the 0th position").isEqualTo(outerResult);
+    assertThat(outerResult).as("Should contain the outer record").isNotNull();
     assertEmptyAvroField(outerResult, "lat");
     Record innerResult = (Record) outerResult.get("inner");
-    Assertions.assertThat(outerResult.get(0))
-        .as("Inner should be in the 0th position")
-        .isEqualTo(innerResult);
-    Assertions.assertThat(innerResult).as("Should contain the inner record").isNotNull();
+    assertThat(outerResult.get(0)).as("Inner should be in the 0th position").isEqualTo(innerResult);
+    assertThat(innerResult).as("Should contain the inner record").isNotNull();
     assertEmptyAvroField(innerResult, "lon");
   }
 
@@ -763,21 +727,17 @@ public abstract class TestReadProjection {
     Record projected = writeAndRead("nested_empty_req_proj", writeSchema, emptyStruct, record);
     assertEmptyAvroField(projected, "id");
     Record outerResult = (Record) projected.get("outer");
-    Assertions.assertThat(projected.get(0))
-        .as("Outer should be in the 0th position")
-        .isEqualTo(outerResult);
-    Assertions.assertThat(outerResult).as("Should contain the outer record").isNotNull();
+    assertThat(projected.get(0)).as("Outer should be in the 0th position").isEqualTo(outerResult);
+    assertThat(outerResult).as("Should contain the outer record").isNotNull();
     assertEmptyAvroField(outerResult, "lat");
     Record innerResult = (Record) outerResult.get("inner");
-    Assertions.assertThat(outerResult.get(0))
-        .as("Inner should be in the 0th position")
-        .isEqualTo(innerResult);
-    Assertions.assertThat(innerResult).as("Should contain the inner record").isNotNull();
+    assertThat(outerResult.get(0)).as("Inner should be in the 0th position").isEqualTo(innerResult);
+    assertThat(innerResult).as("Should contain the inner record").isNotNull();
     assertEmptyAvroField(innerResult, "lon");
   }
 
   private void assertEmptyAvroField(GenericRecord record, String field) {
-    Assertions.assertThatThrownBy(() -> record.get(field))
+    assertThatThrownBy(() -> record.get(field))
         .isInstanceOf(AvroRuntimeException.class)
         .hasMessage("Not a valid schema field: " + field);
   }
