@@ -21,14 +21,21 @@ package org.apache.iceberg.io;
 import static org.apache.iceberg.MetadataColumns.DELETE_FILE_PATH;
 import static org.apache.iceberg.MetadataColumns.DELETE_FILE_POS;
 import static org.apache.iceberg.MetadataColumns.DELETE_FILE_ROW_FIELD_NAME;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.io.File;
 import java.io.IOException;
+import java.nio.file.Files;
+import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
 import org.apache.iceberg.DataFile;
 import org.apache.iceberg.DeleteFile;
 import org.apache.iceberg.FileFormat;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.StructLike;
@@ -50,43 +57,35 @@ import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.CharSequenceSet;
 import org.apache.iceberg.util.Pair;
 import org.apache.iceberg.util.StructLikeSet;
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-@RunWith(Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
-  @Parameterized.Parameters(name = "FileFormat={0}, Partitioned={1}")
-  public static Object[] parameters() {
-    return new Object[][] {
-      new Object[] {FileFormat.AVRO, false},
-      new Object[] {FileFormat.AVRO, true},
-      new Object[] {FileFormat.PARQUET, false},
-      new Object[] {FileFormat.PARQUET, true},
-      new Object[] {FileFormat.ORC, false},
-      new Object[] {FileFormat.ORC, true}
-    };
+  @Parameters(name = "formatVersion = {0}, fileFormat = {1}, Partitioned = {2}")
+  protected static List<Object> parameters() {
+    return Arrays.asList(
+        new Object[] {2, FileFormat.AVRO, false},
+        new Object[] {2, FileFormat.AVRO, true},
+        new Object[] {2, FileFormat.PARQUET, false},
+        new Object[] {2, FileFormat.PARQUET, true},
+        new Object[] {2, FileFormat.ORC, false},
+        new Object[] {2, FileFormat.ORC, true});
   }
 
-  private static final int TABLE_FORMAT_VERSION = 2;
   private static final String PARTITION_VALUE = "aaa";
 
-  private final FileFormat fileFormat;
-  private final boolean partitioned;
+  @Parameter(index = 1)
+  private FileFormat fileFormat;
+
+  @Parameter(index = 2)
+  private boolean partitioned;
 
   private StructLike partition = null;
   private OutputFileFactory fileFactory = null;
   private List<T> dataRows;
 
-  public TestFileWriterFactory(FileFormat fileFormat, boolean partitioned) {
-    super(TABLE_FORMAT_VERSION);
-    this.fileFormat = fileFormat;
-    this.partitioned = partitioned;
-  }
-
   protected abstract StructLikeSet toSet(Iterable<T> records);
 
   protected FileFormat format() {
@@ -94,10 +93,10 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
   }
 
   @Override
-  @Before
+  @BeforeEach
   public void setupTable() throws Exception {
-    this.tableDir = temp.newFolder();
-    Assert.assertTrue(tableDir.delete()); // created during table creation
+    this.tableDir = Files.createTempDirectory(temp, "junit").toFile();
+    assertThat(tableDir.delete()).isTrue(); // created during table creation
 
     this.metadataDir = new File(tableDir, "metadata");
 
@@ -116,7 +115,7 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
             toRow(1, "aaa"), toRow(2, "aaa"), toRow(3, "aaa"), toRow(4, "aaa"), toRow(5, "aaa"));
   }
 
-  @Test
+  @TestTemplate
   public void testDataWriter() throws IOException {
     FileWriterFactory<T> writerFactory = newWriterFactory(table.schema());
 
@@ -124,10 +123,10 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
 
     table.newRowDelta().addRows(dataFile).commit();
 
-    Assert.assertEquals("Records should match", toSet(dataRows), actualRowSet("*"));
+    assertThat(actualRowSet("*")).isEqualTo(toSet(dataRows));
   }
 
-  @Test
+  @TestTemplate
   public void testEqualityDeleteWriter() throws IOException {
     List<Integer> equalityFieldIds = ImmutableList.of(table.schema().findField("id").fieldId());
     Schema equalityDeleteRowSchema = table.schema().select("id");
@@ -151,19 +150,19 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
             deleteRecord.copy("id", 1), deleteRecord.copy("id", 3), deleteRecord.copy("id", 5));
     InputFile inputDeleteFile = table.io().newInputFile(deleteFile.path().toString());
     List<Record> actualDeletes = readFile(equalityDeleteRowSchema, inputDeleteFile);
-    Assert.assertEquals("Delete records must match", expectedDeletes, actualDeletes);
+    assertThat(actualDeletes).isEqualTo(expectedDeletes);
 
     // commit the written delete file
     table.newRowDelta().addDeletes(deleteFile).commit();
 
     // verify the delete file is applied correctly
     List<T> expectedRows = ImmutableList.of(toRow(2, "aaa"), toRow(4, "aaa"));
-    Assert.assertEquals("Records should match", toSet(expectedRows), actualRowSet("*"));
+    assertThat(actualRowSet("*")).isEqualTo(toSet(expectedRows));
   }
 
-  @Test
+  @TestTemplate
   public void testEqualityDeleteWriterWithMultipleSpecs() throws IOException {
-    Assume.assumeFalse("Table must start unpartitioned", partitioned);
+    assumeThat(partitioned).isFalse();
 
     List<Integer> equalityFieldIds = ImmutableList.of(table.schema().findField("id").fieldId());
     Schema equalityDeleteRowSchema = table.schema().select("id");
@@ -172,8 +171,9 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
 
     // write an unpartitioned data file
     DataFile firstDataFile = writeData(writerFactory, dataRows, table.spec(), partition);
-    Assert.assertEquals(
-        "First data file must be unpartitioned", 0, firstDataFile.partition().size());
+    assertThat(firstDataFile.partition().size())
+        .as("First data file must be unpartitioned")
+        .isEqualTo(0);
 
     List<T> deletes =
         ImmutableList.of(toRow(1, "aaa"), toRow(2, "aaa"), toRow(3, "aaa"), toRow(4, "aaa"));
@@ -181,8 +181,9 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
     // write an unpartitioned delete file
     DeleteFile firstDeleteFile =
         writeEqualityDeletes(writerFactory, deletes, table.spec(), partition);
-    Assert.assertEquals(
-        "First delete file must be unpartitioned", 0, firstDeleteFile.partition().size());
+    assertThat(firstDeleteFile.partition().size())
+        .as("First delete file must be unpartitioned")
+        .isEqualTo(0);
 
     // commit the first data and delete files
     table.newAppend().appendFile(firstDataFile).commit();
@@ -195,14 +196,16 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
 
     // write a partitioned data file
     DataFile secondDataFile = writeData(writerFactory, dataRows, table.spec(), partition);
-    Assert.assertEquals(
-        "Second data file must be partitioned", 1, secondDataFile.partition().size());
+    assertThat(secondDataFile.partition().size())
+        .as("Second data file must be partitioned")
+        .isEqualTo(1);
 
     // write a partitioned delete file
     DeleteFile secondDeleteFile =
         writeEqualityDeletes(writerFactory, deletes, table.spec(), partition);
-    Assert.assertEquals(
-        "Second delete file must be artitioned", 1, secondDeleteFile.partition().size());
+    assertThat(secondDeleteFile.partition().size())
+        .as("Second delete file must be partitioned")
+        .isEqualTo(1);
 
     // commit the second data and delete files
     table.newAppend().appendFile(secondDataFile).commit();
@@ -210,10 +213,10 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
 
     // verify both delete files are applied correctly
     List<T> expectedRows = ImmutableList.of(toRow(5, "aaa"), toRow(5, "aaa"));
-    Assert.assertEquals("Records should match", toSet(expectedRows), actualRowSet("*"));
+    assertThat(actualRowSet("*")).isEqualTo(toSet(expectedRows));
   }
 
-  @Test
+  @TestTemplate
   public void testPositionDeleteWriter() throws IOException {
     FileWriterFactory<T> writerFactory = newWriterFactory(table.schema());
 
@@ -232,21 +235,19 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
     CharSequenceSet referencedDataFiles = result.second();
 
     if (fileFormat == FileFormat.AVRO) {
-      Assert.assertNull(deleteFile.lowerBounds());
-      Assert.assertNull(deleteFile.upperBounds());
-      Assert.assertNull(deleteFile.columnSizes());
+      assertThat(deleteFile.lowerBounds()).isNull();
+      assertThat(deleteFile.upperBounds()).isNull();
+      assertThat(deleteFile.columnSizes()).isNull();
     } else {
-      Assert.assertEquals(1, referencedDataFiles.size());
-      Assert.assertEquals(2, deleteFile.lowerBounds().size());
-      Assert.assertTrue(deleteFile.lowerBounds().containsKey(DELETE_FILE_PATH.fieldId()));
-      Assert.assertEquals(2, deleteFile.upperBounds().size());
-      Assert.assertTrue(deleteFile.upperBounds().containsKey(DELETE_FILE_PATH.fieldId()));
-      Assert.assertEquals(2, deleteFile.columnSizes().size());
+      assertThat(referencedDataFiles).hasSize(1);
+      assertThat(deleteFile.lowerBounds()).hasSize(2).containsKey(DELETE_FILE_PATH.fieldId());
+      assertThat(deleteFile.upperBounds()).hasSize(2).containsKey(DELETE_FILE_PATH.fieldId());
+      assertThat(deleteFile.columnSizes()).hasSize(2);
     }
 
-    Assert.assertNull(deleteFile.valueCounts());
-    Assert.assertNull(deleteFile.nullValueCounts());
-    Assert.assertNull(deleteFile.nanValueCounts());
+    assertThat(deleteFile.valueCounts()).isNull();
+    assertThat(deleteFile.nullValueCounts()).isNull();
+    assertThat(deleteFile.nanValueCounts()).isNull();
 
     // verify the written delete file
     GenericRecord deleteRecord = GenericRecord.create(DeleteSchemaUtil.pathPosSchema());
@@ -258,7 +259,7 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
                 DELETE_FILE_PATH.name(), dataFile.path(), DELETE_FILE_POS.name(), 4L));
     InputFile inputDeleteFile = table.io().newInputFile(deleteFile.path().toString());
     List<Record> actualDeletes = readFile(DeleteSchemaUtil.pathPosSchema(), inputDeleteFile);
-    Assert.assertEquals("Delete records must match", expectedDeletes, actualDeletes);
+    assertThat(actualDeletes).isEqualTo(expectedDeletes);
 
     // commit the data and delete files
     table
@@ -271,10 +272,10 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
 
     // verify the delete file is applied correctly
     List<T> expectedRows = ImmutableList.of(toRow(2, "aaa"), toRow(4, "aaa"));
-    Assert.assertEquals("Records should match", toSet(expectedRows), actualRowSet("*"));
+    assertThat(actualRowSet("*")).isEqualTo(toSet(expectedRows));
   }
 
-  @Test
+  @TestTemplate
   public void testPositionDeleteWriterWithRow() throws IOException {
     FileWriterFactory<T> writerFactory = newWriterFactory(table.schema(), table.schema());
 
@@ -290,31 +291,33 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
     CharSequenceSet referencedDataFiles = result.second();
 
     if (fileFormat == FileFormat.AVRO) {
-      Assert.assertNull(deleteFile.lowerBounds());
-      Assert.assertNull(deleteFile.upperBounds());
-      Assert.assertNull(deleteFile.columnSizes());
-      Assert.assertNull(deleteFile.valueCounts());
-      Assert.assertNull(deleteFile.nullValueCounts());
-      Assert.assertNull(deleteFile.nanValueCounts());
+      assertThat(deleteFile.lowerBounds()).isNull();
+      assertThat(deleteFile.upperBounds()).isNull();
+      assertThat(deleteFile.columnSizes()).isNull();
+      assertThat(deleteFile.valueCounts()).isNull();
+      assertThat(deleteFile.nullValueCounts()).isNull();
+      assertThat(deleteFile.nanValueCounts()).isNull();
     } else {
-      Assert.assertEquals(1, referencedDataFiles.size());
-      Assert.assertEquals(4, deleteFile.lowerBounds().size());
-      Assert.assertTrue(deleteFile.lowerBounds().containsKey(DELETE_FILE_PATH.fieldId()));
-      Assert.assertTrue(deleteFile.lowerBounds().containsKey(DELETE_FILE_POS.fieldId()));
+      assertThat(referencedDataFiles).hasSize(1);
+      assertThat(deleteFile.lowerBounds())
+          .hasSize(4)
+          .containsKey(DELETE_FILE_PATH.fieldId())
+          .containsKey(DELETE_FILE_POS.fieldId());
       for (Types.NestedField column : table.schema().columns()) {
-        Assert.assertTrue(deleteFile.lowerBounds().containsKey(column.fieldId()));
+        assertThat(deleteFile.lowerBounds()).containsKey(column.fieldId());
       }
-      Assert.assertEquals(4, deleteFile.upperBounds().size());
-      Assert.assertTrue(deleteFile.upperBounds().containsKey(DELETE_FILE_PATH.fieldId()));
-      Assert.assertTrue(deleteFile.upperBounds().containsKey(DELETE_FILE_POS.fieldId()));
+      assertThat(deleteFile.upperBounds())
+          .hasSize(4)
+          .containsKey(DELETE_FILE_PATH.fieldId())
+          .containsKey(DELETE_FILE_POS.fieldId());
       for (Types.NestedField column : table.schema().columns()) {
-        Assert.assertTrue(deleteFile.upperBounds().containsKey(column.fieldId()));
+        assertThat(deleteFile.upperBounds()).containsKey(column.fieldId());
       }
       // ORC also contains metrics for the deleted row struct, not just actual data fields
-      Assert.assertTrue(deleteFile.columnSizes().size() >= 4);
-      Assert.assertTrue(deleteFile.valueCounts().size() >= 2);
-      Assert.assertTrue(deleteFile.nullValueCounts().size() >= 2);
-      Assert.assertNull(deleteFile.nanValueCounts());
+      assertThat(deleteFile.columnSizes()).hasSizeGreaterThanOrEqualTo(4);
+      assertThat(deleteFile.valueCounts()).hasSizeGreaterThanOrEqualTo(2);
+      assertThat(deleteFile.nullValueCounts()).hasSizeGreaterThanOrEqualTo(2);
+      assertThat(deleteFile.nanValueCounts()).isNull();
     }
 
     // verify the written delete file
@@ -332,7 +335,7 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
     List<Record> expectedDeletes = ImmutableList.of(deleteRecord.copy(deleteRecordColumns));
     InputFile inputDeleteFile = table.io().newInputFile(deleteFile.path().toString());
     List<Record> actualDeletes = readFile(positionDeleteSchema, inputDeleteFile);
-    Assert.assertEquals("Delete records must match", expectedDeletes, actualDeletes);
+    assertThat(actualDeletes).isEqualTo(expectedDeletes);
 
     // commit the data and delete files
     table
@@ -346,10 +349,10 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
     // verify the delete file is applied correctly
     List<T> expectedRows =
         ImmutableList.of(toRow(2, "aaa"), toRow(3, "aaa"), toRow(4, "aaa"), toRow(5, "aaa"));
-    Assert.assertEquals("Records should match", toSet(expectedRows), actualRowSet("*"));
+    assertThat(actualRowSet("*")).isEqualTo(toSet(expectedRows));
   }
 
-  @Test
+  @TestTemplate
   public void testPositionDeleteWriterMultipleDataFiles() throws IOException {
     FileWriterFactory<T> writerFactory = newWriterFactory(table.schema());
 
@@ -369,17 +372,17 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
     CharSequenceSet referencedDataFiles = result.second();
 
     // verify the written delete file has NO lower and upper bounds
-    Assert.assertEquals(2, referencedDataFiles.size());
-    Assert.assertNull(deleteFile.lowerBounds());
-    Assert.assertNull(deleteFile.upperBounds());
-    Assert.assertNull(deleteFile.valueCounts());
-    Assert.assertNull(deleteFile.nullValueCounts());
-    Assert.assertNull(deleteFile.nanValueCounts());
+    assertThat(referencedDataFiles).hasSize(2);
+    assertThat(deleteFile.lowerBounds()).isNull();
+    assertThat(deleteFile.upperBounds()).isNull();
+    assertThat(deleteFile.valueCounts()).isNull();
+    assertThat(deleteFile.nullValueCounts()).isNull();
+    assertThat(deleteFile.nanValueCounts()).isNull();
 
     if (fileFormat == FileFormat.AVRO) {
-      Assert.assertNull(deleteFile.columnSizes());
+      assertThat(deleteFile.columnSizes()).isNull();
     } else {
-      Assert.assertEquals(2, deleteFile.columnSizes().size());
+      assertThat(deleteFile.columnSizes()).hasSize(2);
     }
 
     // commit the data and delete files
@@ -402,7 +405,7 @@ public abstract class TestFileWriterFactory<T> extends WriterTestBase<T> {
             toRow(2, "aaa"),
             toRow(3, "aaa"),
             toRow(4, "aaa"));
-    Assert.assertEquals("Records should match", toSet(expectedRows), actualRowSet("*"));
+    assertThat(actualRowSet("*")).isEqualTo(toSet(expectedRows));
   }
 
   private DataFile writeData(
