@@ -18,15 +18,16 @@
  */
 package org.apache.iceberg.flink.source.assigner;
 
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+
 import java.util.List;
 import org.apache.iceberg.ContentFile;
 import org.apache.iceberg.flink.source.split.IcebergSourceSplit;
 import org.apache.iceberg.flink.source.split.SerializableComparator;
 import org.apache.iceberg.flink.source.split.SplitComparators;
 import org.apache.iceberg.util.SerializationUtil;
-import org.assertj.core.api.Assertions;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class TestFileSequenceNumberBasedSplitAssigner extends SplitAssignerTestBase {
   @Override
@@ -38,7 +39,7 @@ public class TestFileSequenceNumberBasedSplitAssigner extends SplitAssignerTestB
   @Test
   public void testMultipleFilesInAnIcebergSplit() {
     SplitAssigner assigner = splitAssigner();
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () -> assigner.onDiscoveredSplits(createSplits(4, 2, "2")),
             "Multiple files in a split is not allowed")
         .isInstanceOf(IllegalArgumentException.class)
@@ -69,12 +70,12 @@ public class TestFileSequenceNumberBasedSplitAssigner extends SplitAssignerTestB
     byte[] bytes = SerializationUtil.serializeToBytes(SplitComparators.fileSequenceNumber());
     SerializableComparator<IcebergSourceSplit> comparator =
         SerializationUtil.deserializeFromBytes(bytes);
-    Assert.assertNotNull(comparator);
+    assertThat(comparator).isNotNull();
   }
 
   private void assertGetNext(SplitAssigner assigner, Long expectedSequenceNumber) {
     GetSplitResult result = assigner.getNext(null);
     ContentFile file = result.split().task().files().iterator().next().file();
-    Assert.assertEquals(expectedSequenceNumber, file.fileSequenceNumber());
+    assertThat(file.fileSequenceNumber()).isEqualTo(expectedSequenceNumber);
   }
 }
