@@ -19,31 +19,35 @@
 package org.apache.iceberg.spark.extensions;
 
 import static org.apache.iceberg.TableProperties.WRITE_AUDIT_PUBLISH_ENABLED;
-import static org.assertj.core.api.Assumptions.assumeThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.util.List;
-import org.apache.iceberg.ParameterizedTestExtension;
+import java.util.Map;
 import org.apache.iceberg.Snapshot;
 import org.apache.iceberg.Table;
+import org.apache.iceberg.catalog.Namespace;
 import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 import org.apache.spark.sql.AnalysisException;
 import org.apache.spark.sql.catalyst.analysis.NoSuchProcedureException;
-import org.assertj.core.api.Assertions;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.TestTemplate;
-import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.After;
+import org.junit.Assume;
+import org.junit.Test;
 
-@ExtendWith(ParameterizedTestExtension.class)
-public class TestSetCurrentSnapshotProcedure extends ExtensionsTestBase {
+public class TestSetCurrentSnapshotProcedure extends SparkExtensionsTestBase {
 
-  @AfterEach
+  public TestSetCurrentSnapshotProcedure(
+      String catalogName, String implementation, Map<String, String> config) {
+    super(catalogName, implementation, config);
+  }
+
+  @After
   public void removeTables() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testSetCurrentSnapshotUsingPositionalArgs() {
     sql("CREATE TABLE %s (id bigint NOT NULL, data string) USING iceberg", tableName);
     sql("INSERT INTO TABLE %s VALUES (1, 'a')", tableName);
@@ -78,7 +82,7 @@ public class TestSetCurrentSnapshotProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testSetCurrentSnapshotUsingNamedArgs() {
     sql("CREATE TABLE %s (id bigint NOT NULL, data string) USING iceberg", tableName);
     sql("INSERT INTO TABLE %s VALUES (1, 'a')", tableName);
@@ -113,7 +117,7 @@ public class TestSetCurrentSnapshotProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testSetCurrentSnapshotWap() {
     sql("CREATE TABLE %s (id bigint NOT NULL, data string) USING iceberg", tableName);
     sql("ALTER TABLE %s SET TBLPROPERTIES ('%s' 'true')", tableName, WRITE_AUDIT_PUBLISH_ENABLED);
@@ -146,9 +150,9 @@ public class TestSetCurrentSnapshotProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void tesSetCurrentSnapshotWithoutExplicitCatalog() {
-    assumeThat(catalogName).as("Working only with the session catalog").isEqualTo("spark_catalog");
+    Assume.assumeTrue("Working only with the session catalog", "spark_catalog".equals(catalogName));
 
     sql("CREATE TABLE %s (id bigint NOT NULL, data string) USING iceberg", tableName);
     sql("INSERT INTO TABLE %s VALUES (1, 'a')", tableName);
@@ -182,111 +186,65 @@ public class TestSetCurrentSnapshotProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testSetCurrentSnapshotToInvalidSnapshot() {
     sql("CREATE TABLE %s (id bigint NOT NULL, data string) USING iceberg", tableName);
 
-    Assertions.assertThatThrownBy(
+    Namespace namespace = tableIdent.namespace();
+    String tableName = tableIdent.name();
+
+    assertThatThrownBy(
             () -> sql("CALL %s.system.set_current_snapshot('%s', -1L)", catalogName, tableIdent))
+        .as("Should reject invalid snapshot id")
         .isInstanceOf(ValidationException.class)
-        .hasMessage("Cannot roll back to unknown snapshot id: -1");
+        .hasMessageContaining("Cannot roll back to unknown snapshot id");
   }
 
-  @TestTemplate
+  @Test
   public void testInvalidRollbackToSnapshotCases() {
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.set_current_snapshot(namespace => 'n1', table => 't', 1L)",
                     catalogName))
+        .as("Should not allow mixed args")
         .isInstanceOf(AnalysisException.class)
-        .hasMessage("Named and positional arguments cannot be mixed");
+        .hasMessageContaining("Named and positional arguments cannot be mixed");
 
-    Assertions.assertThatThrownBy(
-            () -> sql("CALL %s.custom.set_current_snapshot('n', 't', 1L)", catalogName))
+    assertThatThrownBy(() -> sql("CALL %s.custom.set_current_snapshot('n', 't', 1L)", catalogName))
+        .as("Should not resolve procedures in arbitrary namespaces")
         .isInstanceOf(NoSuchProcedureException.class)
-        .hasMessage("Procedure custom.set_current_snapshot not found");
+        .hasMessageContaining("not found");
 
-    Assertions.assertThatThrownBy(
-            () -> sql("CALL %s.system.set_current_snapshot('t')", catalogName))
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Either snapshot_id or ref must be provided, not both");
+    assertThatThrownBy(() -> sql("CALL %s.system.set_current_snapshot('t')", catalogName))
+        .as("Should reject calls without all required args")
+        .isInstanceOf(AnalysisException.class)
+        .hasMessageContaining("Missing required parameters");
 
-    Assertions.assertThatThrownBy(() -> sql("CALL %s.system.set_current_snapshot(1L)", catalogName))
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Cannot parse identifier for arg table: 1");
+    assertThatThrownBy(() -> sql("CALL %s.system.set_current_snapshot(1L)", catalogName))
+        .as("Should reject calls without all required args")
+        .isInstanceOf(AnalysisException.class)
+        .hasMessageContaining("Missing required parameters");
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () -> sql("CALL %s.system.set_current_snapshot(snapshot_id => 1L)", catalogName))
+        .as("Should reject calls without all required args")
         .isInstanceOf(AnalysisException.class)
-        .hasMessage("Missing required parameters: [table]");
+        .hasMessageContaining("Missing required parameters");
 
-    Assertions.assertThatThrownBy(
-            () -> sql("CALL %s.system.set_current_snapshot(table => 't')", catalogName))
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Either snapshot_id or ref must be provided, not both");
-
-    Assertions.assertThatThrownBy(
-            () -> sql("CALL %s.system.set_current_snapshot('t', 2.2)", catalogName))
+    assertThatThrownBy(() -> sql("CALL %s.system.set_current_snapshot(table => 't')", catalogName))
+        .as("Should reject calls without all required args")
         .isInstanceOf(AnalysisException.class)
-        .hasMessage("Wrong arg type for snapshot_id: cannot cast DecimalType(2,1) to LongType");
+        .hasMessageContaining("Missing required parameters");
 
-    Assertions.assertThatThrownBy(
-            () -> sql("CALL %s.system.set_current_snapshot('', 1L)", catalogName))
+    assertThatThrownBy(() -> sql("CALL %s.system.set_current_snapshot('t', 2.2)", catalogName))
+        .as("Should reject calls with invalid arg types")
+        .isInstanceOf(AnalysisException.class)
+        .hasMessageContaining("Wrong arg type for snapshot_id: cannot cast");
+
+    assertThatThrownBy(() -> sql("CALL %s.system.set_current_snapshot('', 1L)", catalogName))
+        .as("Should reject calls with empty table identifier")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Cannot handle an empty identifier for argument table");
-
-    Assertions.assertThatThrownBy(
-            () ->
-                sql(
-                    "CALL %s.system.set_current_snapshot(table => 't', snapshot_id => 1L, ref => 's1')",
-                    catalogName))
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Either snapshot_id or ref must be provided, not both");
-  }
-
-  @TestTemplate
-  public void testSetCurrentSnapshotToRef() {
-    sql("CREATE TABLE %s (id bigint NOT NULL, data string) USING iceberg", tableName);
-    sql("INSERT INTO TABLE %s VALUES (1, 'a')", tableName);
-
-    Table table = validationCatalog.loadTable(tableIdent);
-    Snapshot firstSnapshot = table.currentSnapshot();
-    String ref = "s1";
-    sql("ALTER TABLE %s CREATE TAG %s", tableName, ref);
-
-    sql("INSERT INTO TABLE %s VALUES (1, 'a')", tableName);
-    assertEquals(
-        "Should have expected rows",
-        ImmutableList.of(row(1L, "a"), row(1L, "a")),
-        sql("SELECT * FROM %s ORDER BY id", tableName));
-
-    table.refresh();
-
-    Snapshot secondSnapshot = table.currentSnapshot();
-
-    List<Object[]> output =
-        sql(
-            "CALL %s.system.set_current_snapshot(table => '%s', ref => '%s')",
-            catalogName, tableIdent, ref);
-
-    assertEquals(
-        "Procedure output must match",
-        ImmutableList.of(row(secondSnapshot.snapshotId(), firstSnapshot.snapshotId())),
-        output);
-
-    assertEquals(
-        "Set must be successful",
-        ImmutableList.of(row(1L, "a")),
-        sql("SELECT * FROM %s ORDER BY id", tableName));
-
-    String notExistRef = "s2";
-    Assertions.assertThatThrownBy(
-            () ->
-                sql(
-                    "CALL %s.system.set_current_snapshot(table => '%s', ref => '%s')",
-                    catalogName, tableIdent, notExistRef))
-        .isInstanceOf(ValidationException.class)
-        .hasMessage("Cannot find matching snapshot ID for ref " + notExistRef);
+        .hasMessageContaining("Cannot handle an empty identifier");
   }
 }
