@@ -21,7 +21,6 @@ package org.apache.iceberg.spark.actions;
 import java.io.IOException;
 import java.math.RoundingMode;
 import java.util.Arrays;
-import java.util.Collection;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -83,7 +82,6 @@ public class RewriteDataFilesSparkAction
           USE_STARTING_SEQUENCE_NUMBER,
           REWRITE_JOB_ORDER,
           OUTPUT_SPEC_ID);
-
   private static final RewriteDataFilesSparkAction.Result EMPTY_RESULT =
       ImmutableRewriteDataFiles.Result.builder().rewriteResults(ImmutableList.of()).build();
 
@@ -338,21 +336,14 @@ public class RewriteDataFilesSparkAction
         commitManager.service(groupsPerCommit);
     commitService.start();
 
-    Collection<FileGroupFailureResult> rewriteFailures = new ConcurrentLinkedQueue<>();
     // start rewrite tasks
     Tasks.foreach(groupStream)
         .suppressFailureWhenFinished()
         .executeWith(rewriteService)
         .noRetry()
         .onFailure(
-            (fileGroup, exception) -> {
-              LOG.error("Failure during rewrite group {}", fileGroup.info(), exception);
-              rewriteFailures.add(
-                  ImmutableRewriteDataFiles.FileGroupFailureResult.builder()
-                      .info(fileGroup.info())
-                      .dataFilesCount(fileGroup.numFiles())
-                      .build());
-            })
+            (fileGroup, exception) ->
+                LOG.error("Failure during rewrite group {}", fileGroup.info(), exception))
         .run(fileGroup -> commitService.offer(rewriteFiles(ctx, fileGroup)));
     rewriteService.shutdown();
 
@@ -370,10 +361,7 @@ public class RewriteDataFilesSparkAction
 
     List<FileGroupRewriteResult> rewriteResults =
         commitResults.stream().map(RewriteFileGroup::asResult).collect(Collectors.toList());
-    return ImmutableRewriteDataFiles.Result.builder()
-        .rewriteResults(rewriteResults)
-        .rewriteFailures(rewriteFailures)
-        .build();
+    return ImmutableRewriteDataFiles.Result.builder().rewriteResults(rewriteResults).build();
   }
 
   Stream<RewriteFileGroup> toGroupStream(
