@@ -36,10 +36,10 @@ import org.apache.iceberg.MetricsModes;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.Snapshot;
-import org.apache.iceberg.SparkDistributedDataScan;
 import org.apache.iceberg.StructLike;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
+import org.apache.iceberg.TableScan;
 import org.apache.iceberg.expressions.AggregateEvaluator;
 import org.apache.iceberg.expressions.Binder;
 import org.apache.iceberg.expressions.BoundAggregate;
@@ -47,17 +47,15 @@ import org.apache.iceberg.expressions.Expression;
 import org.apache.iceberg.expressions.ExpressionUtil;
 import org.apache.iceberg.expressions.Expressions;
 import org.apache.iceberg.io.CloseableIterable;
-import org.apache.iceberg.metrics.InMemoryMetricsReporter;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
-import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.spark.Spark3Util;
 import org.apache.iceberg.spark.SparkAggregates;
+import org.apache.iceberg.spark.SparkFilters;
 import org.apache.iceberg.spark.SparkReadConf;
 import org.apache.iceberg.spark.SparkReadOptions;
 import org.apache.iceberg.spark.SparkSchemaUtil;
-import org.apache.iceberg.spark.SparkV2Filters;
 import org.apache.iceberg.types.Type;
 import org.apache.iceberg.types.TypeUtil;
 import org.apache.iceberg.types.Types;
@@ -66,14 +64,14 @@ import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.InternalRow;
 import org.apache.spark.sql.connector.expressions.aggregate.AggregateFunc;
 import org.apache.spark.sql.connector.expressions.aggregate.Aggregation;
-import org.apache.spark.sql.connector.expressions.filter.Predicate;
 import org.apache.spark.sql.connector.read.Scan;
 import org.apache.spark.sql.connector.read.ScanBuilder;
 import org.apache.spark.sql.connector.read.Statistics;
 import org.apache.spark.sql.connector.read.SupportsPushDownAggregates;
+import org.apache.spark.sql.connector.read.SupportsPushDownFilters;
 import org.apache.spark.sql.connector.read.SupportsPushDownRequiredColumns;
-import org.apache.spark.sql.connector.read.SupportsPushDownV2Filters;
 import org.apache.spark.sql.connector.read.SupportsReportStatistics;
+import org.apache.spark.sql.sources.Filter;
 import org.apache.spark.sql.types.StructField;
 import org.apache.spark.sql.types.StructType;
 import org.apache.spark.sql.util.CaseInsensitiveStringMap;
@@ -83,12 +81,12 @@ import org.slf4j.LoggerFactory;
 public class SparkScanBuilder
     implements ScanBuilder,
         SupportsPushDownAggregates,
-        SupportsPushDownV2Filters,
+        SupportsPushDownFilters,
         SupportsPushDownRequiredColumns,
         SupportsReportStatistics {
 
   private static final Logger LOG = LoggerFactory.getLogger(SparkScanBuilder.class);
-  private static final Predicate[] NO_PREDICATES = new Predicate[0];
+  private static final Filter[] NO_FILTERS = new Filter[0];
   private StructType pushedAggregateSchema;
   private Scan localScan;
 
@@ -97,12 +95,11 @@ public class SparkScanBuilder
   private final CaseInsensitiveStringMap options;
   private final SparkReadConf readConf;
   private final List<String> metaColumns = Lists.newArrayList();
-  private final InMemoryMetricsReporter metricsReporter;
 
   private Schema schema;
   private boolean caseSensitive;
   private List<Expression> filterExpressions = null;
-  private Predicate[] pushedPredicates = NO_PREDICATES;
+  private Filter[] pushedFilters = NO_FILTERS;
 
   SparkScanBuilder(
       SparkSession spark,
@@ -116,7 +113,6 @@ public class SparkScanBuilder
     this.options = options;
     this.readConf = new SparkReadConf(spark, table, branch, options);
     this.caseSensitive = readConf.caseSensitive();
-    this.metricsReporter = new InMemoryMetricsReporter();
   }
 
   SparkScanBuilder(SparkSession spark, Table table, CaseInsensitiveStringMap options) {
@@ -146,7 +142,7 @@ public class SparkScanBuilder
   }
 
   @Override
-  public Predicate[] pushPredicates(Predicate[] predicates) {
+  public Filter[] pushFilters(Filter[] filters) {
     // there are 3 kinds of filters:
     // (1) filters that can be pushed down completely and don't have to evaluated by Spark
     //     (e.g. filters that select entire partitions)
@@ -157,39 +153,39 @@ public class SparkScanBuilder
     // filters (1) and (2) are used prune files during job planning in Iceberg
     // filters (2) and (3) form a set of post scan filters and must be evaluated by Spark
 
-    List<Expression> expressions = Lists.newArrayListWithExpectedSize(predicates.length);
-    List<Predicate> pushableFilters = Lists.newArrayListWithExpectedSize(predicates.length);
-    List<Predicate> postScanFilters = Lists.newArrayListWithExpectedSize(predicates.length);
+    List<Expression> expressions = Lists.newArrayListWithExpectedSize(filters.length);
+    List<Filter> pushableFilters = Lists.newArrayListWithExpectedSize(filters.length);
+    List<Filter> postScanFilters = Lists.newArrayListWithExpectedSize(filters.length);
 
-    for (Predicate predicate : predicates) {
+    for (Filter filter : filters) {
       try {
-        Expression expr = SparkV2Filters.convert(predicate);
+        Expression expr = SparkFilters.convert(filter);
 
         if (expr != null) {
           // try binding the expression to ensure it can be pushed down
           Binder.bind(schema.asStruct(), expr, caseSensitive);
           expressions.add(expr);
-          pushableFilters.add(predicate);
+          pushableFilters.add(filter);
         }
 
         if (expr == null
             || unpartitioned()
             || !ExpressionUtil.selectsPartitions(expr, table, caseSensitive)) {
-          postScanFilters.add(predicate);
+          postScanFilters.add(filter);
         } else {
-          LOG.info("Evaluating completely on Iceberg side: {}", predicate);
+          LOG.info("Evaluating completely on Iceberg side: {}", filter);
         }
 
       } catch (Exception e) {
-        LOG.warn("Failed to check if {} can be pushed down: {}", predicate, e.getMessage());
-        postScanFilters.add(predicate);
+        LOG.warn("Failed to check if {} can be pushed down: {}", filter, e.getMessage());
+        postScanFilters.add(filter);
       }
     }
 
     this.filterExpressions = expressions;
-    this.pushedPredicates = pushableFilters.toArray(new Predicate[0]);
+    this.pushedFilters = pushableFilters.toArray(new Filter[0]);
 
-    return postScanFilters.toArray(new Predicate[0]);
+    return postScanFilters.toArray(new Filter[0]);
   }
 
   private boolean unpartitioned() {
@@ -197,8 +193,8 @@ public class SparkScanBuilder
   }
 
   @Override
-  public Predicate[] pushedPredicates() {
-    return pushedPredicates;
+  public Filter[] pushedFilters() {
+    return pushedFilters;
   }
 
   @Override
@@ -235,12 +231,18 @@ public class SparkScanBuilder
       return false;
     }
 
-    org.apache.iceberg.Scan scan =
-        buildIcebergBatchScan(true /* include Column Stats */, schemaWithMetadataColumns());
+    TableScan scan = table.newScan().includeColumnStats();
+    Snapshot snapshot = readSnapshot();
+    if (snapshot == null) {
+      LOG.info("Skipping aggregate pushdown: table snapshot is null");
+      return false;
+    }
+    scan = scan.useSnapshot(snapshot.snapshotId());
+    scan = configureSplitPlanning(scan);
+    scan = scan.filter(filterExpression());
 
     try (CloseableIterable<FileScanTask> fileScanTasks = scan.planFiles()) {
-      List<FileScanTask> tasks = ImmutableList.copyOf(fileScanTasks);
-      for (FileScanTask task : tasks) {
+      for (FileScanTask task : fileScanTasks) {
         if (!task.deletes().isEmpty()) {
           LOG.info("Skipping aggregate pushdown: detected row level deletes");
           return false;
@@ -278,6 +280,11 @@ public class SparkScanBuilder
       return false;
     }
 
+    if (readConf.startSnapshotId() != null) {
+      LOG.info("Skipping aggregate pushdown: incremental scan is not supported");
+      return false;
+    }
+
     // If group by expression is the same as the partition, the statistics information can still
     // be used to calculate min/max/count, will enable aggregate push down in next phase.
     // TODO: enable aggregate push down for partition col group by expression
@@ -289,6 +296,17 @@ public class SparkScanBuilder
     return true;
   }
 
+  private Snapshot readSnapshot() {
+    Snapshot snapshot;
+    if (readConf.snapshotId() != null) {
+      snapshot = table.snapshot(readConf.snapshotId());
+    } else {
+      snapshot = SnapshotUtil.latestSnapshot(table, readConf.branch());
+    }
+
+    return snapshot;
+  }
+
   private boolean metricsModeSupportsAggregatePushDown(List<BoundAggregate<?, ?>> aggregates) {
     MetricsConfig config = MetricsConfig.forTable(table);
     for (BoundAggregate aggregate : aggregates) {
@@ -406,18 +424,6 @@ public class SparkScanBuilder
   }
 
   private Scan buildBatchScan() {
-    Schema expectedSchema = schemaWithMetadataColumns();
-    return new SparkBatchQueryScan(
-        spark,
-        table,
-        buildIcebergBatchScan(false /* not include Column Stats */, expectedSchema),
-        readConf,
-        expectedSchema,
-        filterExpressions,
-        metricsReporter::scanReport);
-  }
-
-  private org.apache.iceberg.Scan buildIcebergBatchScan(boolean withStats, Schema expectedSchema) {
     Long snapshotId = readConf.snapshotId();
     Long asOfTimestamp = readConf.asOfTimestamp();
     String branch = readConf.branch();
@@ -458,29 +464,21 @@ public class SparkScanBuilder
         SparkReadOptions.END_TIMESTAMP);
 
     if (startSnapshotId != null) {
-      return buildIncrementalAppendScan(startSnapshotId, endSnapshotId, withStats, expectedSchema);
+      return buildIncrementalAppendScan(startSnapshotId, endSnapshotId);
     } else {
-      return buildBatchScan(snapshotId, asOfTimestamp, branch, tag, withStats, expectedSchema);
+      return buildBatchScan(snapshotId, asOfTimestamp, branch, tag);
     }
   }
 
-  private org.apache.iceberg.Scan buildBatchScan(
-      Long snapshotId,
-      Long asOfTimestamp,
-      String branch,
-      String tag,
-      boolean withStats,
-      Schema expectedSchema) {
+  private Scan buildBatchScan(Long snapshotId, Long asOfTimestamp, String branch, String tag) {
+    Schema expectedSchema = schemaWithMetadataColumns();
+
     BatchScan scan =
-        newBatchScan()
+        table
+            .newBatchScan()
             .caseSensitive(caseSensitive)
             .filter(filterExpression())
-            .project(expectedSchema)
-            .metricsReporter(metricsReporter);
-
-    if (withStats) {
-      scan = scan.includeColumnStats();
-    }
+            .project(expectedSchema);
 
     if (snapshotId != null) {
       scan = scan.useSnapshot(snapshotId);
@@ -498,29 +496,29 @@ public class SparkScanBuilder
       scan = scan.useRef(tag);
     }
 
-    return configureSplitPlanning(scan);
+    scan = configureSplitPlanning(scan);
+
+    return new SparkBatchQueryScan(spark, table, scan, readConf, expectedSchema, filterExpressions);
   }
 
-  private org.apache.iceberg.Scan buildIncrementalAppendScan(
-      long startSnapshotId, Long endSnapshotId, boolean withStats, Schema expectedSchema) {
+  private Scan buildIncrementalAppendScan(long startSnapshotId, Long endSnapshotId) {
+    Schema expectedSchema = schemaWithMetadataColumns();
+
     IncrementalAppendScan scan =
         table
             .newIncrementalAppendScan()
             .fromSnapshotExclusive(startSnapshotId)
             .caseSensitive(caseSensitive)
             .filter(filterExpression())
-            .project(expectedSchema)
-            .metricsReporter(metricsReporter);
-
-    if (withStats) {
-      scan = scan.includeColumnStats();
-    }
+            .project(expectedSchema);
 
     if (endSnapshotId != null) {
       scan = scan.toSnapshot(endSnapshotId);
     }
 
-    return configureSplitPlanning(scan);
+    scan = configureSplitPlanning(scan);
+
+    return new SparkBatchQueryScan(spark, table, scan, readConf, expectedSchema, filterExpressions);
   }
 
   @SuppressWarnings("CyclomaticComplexity")
@@ -570,7 +568,7 @@ public class SparkScanBuilder
     }
 
     if (endTimestamp != null) {
-      endSnapshotId = getEndSnapshotId(endTimestamp);
+      endSnapshotId = SnapshotUtil.nullableSnapshotIdAsOfTime(table, endTimestamp);
       if ((startSnapshotId == null && endSnapshotId == null)
           || (startSnapshotId != null && startSnapshotId.equals(endSnapshotId))) {
         emptyScan = true;
@@ -584,8 +582,7 @@ public class SparkScanBuilder
             .newIncrementalChangelogScan()
             .caseSensitive(caseSensitive)
             .filter(filterExpression())
-            .project(expectedSchema)
-            .metricsReporter(metricsReporter);
+            .project(expectedSchema);
 
     if (startSnapshotId != null) {
       scan = scan.fromSnapshotExclusive(startSnapshotId);
@@ -613,17 +610,6 @@ public class SparkScanBuilder
     }
   }
 
-  private Long getEndSnapshotId(Long endTimestamp) {
-    Long endSnapshotId = null;
-    for (Snapshot snapshot : SnapshotUtil.currentAncestors(table)) {
-      if (snapshot.timestampMillis() <= endTimestamp) {
-        endSnapshotId = snapshot.snapshotId();
-        break;
-      }
-    }
-    return endSnapshotId;
-  }
-
   public Scan buildMergeOnReadScan() {
     Preconditions.checkArgument(
         readConf.snapshotId() == null && readConf.asOfTimestamp() == null && readConf.tag() == null,
@@ -642,13 +628,7 @@ public class SparkScanBuilder
 
     if (snapshot == null) {
       return new SparkBatchQueryScan(
-          spark,
-          table,
-          null,
-          readConf,
-          schemaWithMetadataColumns(),
-          filterExpressions,
-          metricsReporter::scanReport);
+          spark, table, null, readConf, schemaWithMetadataColumns(), filterExpressions);
     }
 
     // remember the current snapshot ID for commit validation
@@ -662,23 +642,17 @@ public class SparkScanBuilder
     Schema expectedSchema = schemaWithMetadataColumns();
 
     BatchScan scan =
-        newBatchScan()
+        table
+            .newBatchScan()
             .useSnapshot(snapshotId)
             .caseSensitive(caseSensitive)
             .filter(filterExpression())
-            .project(expectedSchema)
-            .metricsReporter(metricsReporter);
+            .project(expectedSchema);
 
     scan = configureSplitPlanning(scan);
 
     return new SparkBatchQueryScan(
-        spark,
-        table,
-        scan,
-        adjustedReadConf,
-        expectedSchema,
-        filterExpressions,
-        metricsReporter::scanReport);
+        spark, table, scan, adjustedReadConf, expectedSchema, filterExpressions);
   }
 
   public Scan buildCopyOnWriteScan() {
@@ -686,12 +660,7 @@ public class SparkScanBuilder
 
     if (snapshot == null) {
       return new SparkCopyOnWriteScan(
-          spark,
-          table,
-          readConf,
-          schemaWithMetadataColumns(),
-          filterExpressions,
-          metricsReporter::scanReport);
+          spark, table, readConf, schemaWithMetadataColumns(), filterExpressions);
     }
 
     Schema expectedSchema = schemaWithMetadataColumns();
@@ -703,20 +672,12 @@ public class SparkScanBuilder
             .ignoreResiduals()
             .caseSensitive(caseSensitive)
             .filter(filterExpression())
-            .project(expectedSchema)
-            .metricsReporter(metricsReporter);
+            .project(expectedSchema);
 
     scan = configureSplitPlanning(scan);
 
     return new SparkCopyOnWriteScan(
-        spark,
-        table,
-        scan,
-        snapshot,
-        readConf,
-        expectedSchema,
-        filterExpressions,
-        metricsReporter::scanReport);
+        spark, table, scan, snapshot, readConf, expectedSchema, filterExpressions);
   }
 
   private <T extends org.apache.iceberg.Scan<T, ?, ?>> T configureSplitPlanning(T scan) {
@@ -752,12 +713,4 @@ public class SparkScanBuilder
   public StructType readSchema() {
     return build().readSchema();
   }
-
-  private BatchScan newBatchScan() {
-    if (table instanceof BaseTable && readConf.distributedPlanningEnabled()) {
-      return new SparkDistributedDataScan(spark, table, readConf);
-    } else {
-      return table.newBatchScan();
-    }
-  }
 }
