@@ -86,9 +86,8 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
     Assert.assertEquals(TimeUnit.DAYS.toMillis(maxRefAge), ref.maxRefAgeMs().longValue());
 
     assertThatThrownBy(() -> sql("ALTER TABLE %s CREATE BRANCH %s", tableName, branchName))
-        .as("Cannot create an existing branch")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Ref b1 already exists");
+        .hasMessage("Ref b1 already exists");
   }
 
   @Test
@@ -199,7 +198,6 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
                 sql(
                     "ALTER TABLE %s CREATE BRANCH %s WITH SNAPSHOT RETENTION",
                     tableName, branchName))
-        .as("Illegal statement")
         .isInstanceOf(IcebergParseException.class)
         .hasMessageContaining("no viable alternative at input 'WITH SNAPSHOT RETENTION'");
   }
@@ -218,14 +216,12 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
     Assert.assertEquals(TimeUnit.DAYS.toMillis(maxRefAge), ref.maxRefAgeMs().longValue());
 
     assertThatThrownBy(() -> sql("ALTER TABLE %s CREATE BRANCH %s RETAIN", tableName, branchName))
-        .as("Illegal statement")
         .isInstanceOf(IcebergParseException.class)
         .hasMessageContaining("mismatched input");
 
     assertThatThrownBy(
             () ->
                 sql("ALTER TABLE %s CREATE BRANCH %s RETAIN %s DAYS", tableName, branchName, "abc"))
-        .as("Illegal statement")
         .isInstanceOf(IcebergParseException.class)
         .hasMessageContaining("mismatched input");
 
@@ -234,7 +230,6 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
                 sql(
                     "ALTER TABLE %s CREATE BRANCH %s RETAIN %d SECONDS",
                     tableName, branchName, maxRefAge))
-        .as("Illegal statement")
         .isInstanceOf(IcebergParseException.class)
         .hasMessageContaining("mismatched input 'SECONDS' expecting {'DAYS', 'HOURS', 'MINUTES'}");
   }
@@ -259,9 +254,8 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
   @Test
   public void testDropBranchDoesNotExist() {
     assertThatThrownBy(() -> sql("ALTER TABLE %s DROP BRANCH %s", tableName, "nonExistingBranch"))
-        .as("Cannot perform drop branch on branch which does not exist")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Branch does not exist: nonExistingBranch");
+        .hasMessage("Branch does not exist: nonExistingBranch");
   }
 
   @Test
@@ -271,15 +265,13 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
     table.manageSnapshots().createTag(tagName, table.currentSnapshot().snapshotId()).commit();
 
     assertThatThrownBy(() -> sql("ALTER TABLE %s DROP BRANCH %s", tableName, tagName))
-        .as("Cannot perform drop branch on tag")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Ref b1 is a tag not a branch");
+        .hasMessage("Ref b1 is a tag not a branch");
   }
 
   @Test
   public void testDropBranchNonConformingName() {
     assertThatThrownBy(() -> sql("ALTER TABLE %s DROP BRANCH %s", tableName, "123"))
-        .as("Non-conforming branch name")
         .isInstanceOf(IcebergParseException.class)
         .hasMessageContaining("mismatched input '123'");
   }
@@ -287,9 +279,8 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
   @Test
   public void testDropMainBranchFails() {
     assertThatThrownBy(() -> sql("ALTER TABLE %s DROP BRANCH main", tableName))
-        .as("Cannot drop the main branch")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Cannot remove main branch");
+        .hasMessage("Cannot remove main branch");
   }
 
   @Test
@@ -305,6 +296,14 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
     Assert.assertNull(ref);
   }
 
+  private Table insertRows() throws NoSuchTableException {
+    List<SimpleRecord> records =
+        ImmutableList.of(new SimpleRecord(1, "a"), new SimpleRecord(2, "b"));
+    Dataset<Row> df = spark.createDataFrame(records, SimpleRecord.class);
+    df.writeTo(tableName).append();
+    return validationCatalog.loadTable(tableIdent);
+  }
+
   @Test
   public void createOrReplace() throws NoSuchTableException {
     Table table = insertRows();
@@ -392,12 +391,4 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Branch does not exist: someBranch");
   }
-
-  private Table insertRows() throws NoSuchTableException {
-    List<SimpleRecord> records =
-        ImmutableList.of(new SimpleRecord(1, "a"), new SimpleRecord(2, "b"));
-    Dataset<Row> df = spark.createDataFrame(records, SimpleRecord.class);
-    df.writeTo(tableName).append();
-    return validationCatalog.loadTable(tableIdent);
-  }
 }
