@@ -21,11 +21,8 @@ package org.apache.iceberg.spark.actions;
 import static org.apache.iceberg.types.Types.NestedField.optional;
 import static org.apache.spark.sql.functions.expr;
 import static org.assertj.core.api.Assertions.assertThat;
-import static org.assertj.core.api.Assertions.fail;
 
-import java.io.File;
 import java.io.IOException;
-import java.nio.file.Path;
 import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
@@ -41,8 +38,6 @@ import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.Files;
 import org.apache.iceberg.MetadataTableType;
 import org.apache.iceberg.MetadataTableUtils;
-import org.apache.iceberg.Parameter;
-import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionData;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Partitioning;
@@ -50,7 +45,6 @@ import org.apache.iceberg.PositionDeletesScanTask;
 import org.apache.iceberg.RowDelta;
 import org.apache.iceberg.ScanTask;
 import org.apache.iceberg.Schema;
-import org.apache.iceberg.SnapshotSummary;
 import org.apache.iceberg.StructLike;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
@@ -68,8 +62,8 @@ import org.apache.iceberg.io.OutputFile;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
-import org.apache.iceberg.spark.CatalogTestBase;
 import org.apache.iceberg.spark.SparkCatalogConfig;
+import org.apache.iceberg.spark.SparkCatalogTestBase;
 import org.apache.iceberg.spark.data.TestHelpers;
 import org.apache.iceberg.spark.source.FourColumnRecord;
 import org.apache.iceberg.spark.source.ThreeColumnRecord;
@@ -79,11 +73,14 @@ import org.apache.iceberg.util.StructLikeMap;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.types.StructType;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.TestTemplate;
-import org.junit.jupiter.api.io.TempDir;
+import org.junit.After;
+import org.junit.Assert;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
+import org.junit.runners.Parameterized;
 
-public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
+public class TestRewritePositionDeleteFilesAction extends SparkCatalogTestBase {
 
   private static final String TABLE_NAME = "test_table";
   private static final Schema SCHEMA =
@@ -101,7 +98,9 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
   private static final int SCALE = 4000;
   private static final int DELETES_SCALE = 1000;
 
-  @Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}, fileFormat = {3}")
+  @Parameterized.Parameters(
+      name =
+          "formatVersion = {0}, catalogName = {1}, implementation = {2}, config = {3}, fileFormat = {4}")
   public static Object[][] parameters() {
     return new Object[][] {
       {
@@ -113,17 +112,22 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     };
   }
 
-  @TempDir private Path temp;
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
 
-  @Parameter(index = 3)
-  private FileFormat format;
+  private final FileFormat format;
 
-  @AfterEach
+  public TestRewritePositionDeleteFilesAction(
+      String catalogName, String implementation, Map<String, String> config, FileFormat format) {
+    super(catalogName, implementation, config);
+    this.format = format;
+  }
+
+  @After
   public void cleanup() {
     validationCatalog.dropTable(TableIdentifier.of("default", TABLE_NAME));
   }
 
-  @TestTemplate
+  @Test
   public void testEmptyTable() {
     PartitionSpec spec = PartitionSpec.builderFor(SCHEMA).identity("c1").build();
     Table table =
@@ -131,16 +135,16 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
             TableIdentifier.of("default", TABLE_NAME), SCHEMA, spec, tableProperties());
 
     Result result = SparkActions.get(spark).rewritePositionDeletes(table).execute();
-    assertThat(result.rewrittenDeleteFilesCount()).as("No rewritten delete files").isZero();
-    assertThat(result.addedDeleteFilesCount()).as("No added delete files").isZero();
+    Assert.assertEquals("No rewritten delete files", 0, result.rewrittenDeleteFilesCount());
+    Assert.assertEquals("No added delete files", 0, result.addedDeleteFilesCount());
   }
 
-  @TestTemplate
+  @Test
   public void testFileGranularity() throws Exception {
     checkDeleteGranularity(DeleteGranularity.FILE);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionGranularity() throws Exception {
     checkDeleteGranularity(DeleteGranularity.PARTITION);
   }
@@ -171,20 +175,20 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     assertThat(result.addedDeleteFilesCount()).isEqualTo(expectedDeleteFilesCount);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitioned() throws Exception {
     Table table = createTableUnpartitioned(2, SCALE);
     List<DataFile> dataFiles = TestHelpers.dataFiles(table);
     writePosDeletesForFiles(table, 2, DELETES_SCALE, dataFiles);
-    assertThat(dataFiles).hasSize(2);
+    Assert.assertEquals(2, dataFiles.size());
 
     List<DeleteFile> deleteFiles = deleteFiles(table);
-    assertThat(deleteFiles).hasSize(2);
+    Assert.assertEquals(2, deleteFiles.size());
 
     List<Object[]> expectedRecords = records(table);
     List<Object[]> expectedDeletes = deleteRecords(table);
-    assertThat(expectedRecords).hasSize(2000);
-    assertThat(expectedDeletes).hasSize(2000);
+    Assert.assertEquals(2000, expectedRecords.size());
+    Assert.assertEquals(2000, expectedDeletes.size());
 
     Result result =
         SparkActions.get(spark)
@@ -192,7 +196,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
             .option(SizeBasedFileRewriter.REWRITE_ALL, "true")
             .execute();
     List<DeleteFile> newDeleteFiles = deleteFiles(table);
-    assertThat(newDeleteFiles).as("Expected 1 new delete file").hasSize(1);
+    Assert.assertEquals("Expected 1 new delete file", 1, newDeleteFiles.size());
     assertLocallySorted(newDeleteFiles);
     assertNotContains(deleteFiles, newDeleteFiles);
     checkResult(result, deleteFiles, newDeleteFiles, 1);
@@ -204,21 +208,21 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     assertEquals("Position deletes must match", expectedDeletes, actualDeletes);
   }
 
-  @TestTemplate
+  @Test
   public void testRewriteAll() throws Exception {
     Table table = createTablePartitioned(4, 2, SCALE);
 
     List<DataFile> dataFiles = TestHelpers.dataFiles(table);
     writePosDeletesForFiles(table, 2, DELETES_SCALE, dataFiles);
-    assertThat(dataFiles).hasSize(4);
+    Assert.assertEquals(4, dataFiles.size());
 
     List<DeleteFile> deleteFiles = deleteFiles(table);
-    assertThat(deleteFiles).hasSize(8);
+    Assert.assertEquals(8, deleteFiles.size());
 
     List<Object[]> expectedRecords = records(table);
     List<Object[]> expectedDeletes = deleteRecords(table);
-    assertThat(expectedRecords).hasSize(12000);
-    assertThat(expectedDeletes).hasSize(4000);
+    Assert.assertEquals(12000, expectedRecords.size());
+    Assert.assertEquals(4000, expectedDeletes.size());
 
     Result result =
         SparkActions.get(spark)
@@ -228,7 +232,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
             .execute();
 
     List<DeleteFile> newDeleteFiles = deleteFiles(table);
-    assertThat(newDeleteFiles).hasSize(4);
+    Assert.assertEquals("Should have 4 delete files", 4, newDeleteFiles.size());
     assertNotContains(deleteFiles, newDeleteFiles);
     assertLocallySorted(newDeleteFiles);
     checkResult(result, deleteFiles, newDeleteFiles, 4);
@@ -240,23 +244,23 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     assertEquals("Position deletes must match", expectedDeletes, actualDeletes);
   }
 
-  @TestTemplate
+  @Test
   public void testRewriteFilter() throws Exception {
     Table table = createTablePartitioned(4, 2, SCALE);
     table.refresh();
 
     List<DataFile> dataFiles = TestHelpers.dataFiles(table);
     writePosDeletesForFiles(table, 2, DELETES_SCALE, dataFiles);
-    assertThat(dataFiles).hasSize(4);
+    Assert.assertEquals(4, dataFiles.size());
 
     List<DeleteFile> deleteFiles = deleteFiles(table);
-    assertThat(deleteFiles).hasSize(8);
+    Assert.assertEquals(8, deleteFiles.size());
 
     table.refresh();
     List<Object[]> expectedRecords = records(table);
     List<Object[]> expectedDeletes = deleteRecords(table);
-    assertThat(expectedRecords).hasSize(12000);
-    assertThat(expectedDeletes).hasSize(4000);
+    Assert.assertEquals(12000, expectedRecords.size()); // 16000 data - 4000 delete rows
+    Assert.assertEquals(4000, expectedDeletes.size());
 
     Expression filter =
         Expressions.and(
@@ -272,7 +276,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
             .execute();
 
     List<DeleteFile> newDeleteFiles = except(deleteFiles(table), deleteFiles);
-    assertThat(newDeleteFiles).as("Should have 4 delete files").hasSize(2);
+    Assert.assertEquals("Should have 4 delete files", 2, newDeleteFiles.size());
 
     List<DeleteFile> expectedRewrittenFiles =
         filterFiles(table, deleteFiles, ImmutableList.of(1), ImmutableList.of(2));
@@ -285,21 +289,21 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     assertEquals("Position deletes must match", expectedDeletes, actualDeletes);
   }
 
-  @TestTemplate
+  @Test
   public void testRewriteToSmallerTarget() throws Exception {
     Table table = createTablePartitioned(4, 2, SCALE);
 
     List<DataFile> dataFiles = TestHelpers.dataFiles(table);
     writePosDeletesForFiles(table, 2, DELETES_SCALE, dataFiles);
-    assertThat(dataFiles).hasSize(4);
+    Assert.assertEquals(4, dataFiles.size());
 
     List<Object[]> expectedRecords = records(table);
     List<Object[]> expectedDeletes = deleteRecords(table);
-    assertThat(expectedRecords).hasSize(12000);
-    assertThat(expectedDeletes).hasSize(4000);
+    Assert.assertEquals(12000, expectedRecords.size());
+    Assert.assertEquals(4000, expectedDeletes.size());
 
     List<DeleteFile> deleteFiles = deleteFiles(table);
-    assertThat(deleteFiles).hasSize(8);
+    Assert.assertEquals(8, deleteFiles.size());
 
     long avgSize = size(deleteFiles) / deleteFiles.size();
 
@@ -310,7 +314,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
             .option(SizeBasedFileRewriter.TARGET_FILE_SIZE_BYTES, String.valueOf(avgSize / 2))
             .execute();
     List<DeleteFile> newDeleteFiles = deleteFiles(table);
-    assertThat(newDeleteFiles).as("Should have 8 new delete files").hasSize(8);
+    Assert.assertEquals("Should have 8 new delete files", 8, newDeleteFiles.size());
     assertNotContains(deleteFiles, newDeleteFiles);
     assertLocallySorted(newDeleteFiles);
     checkResult(result, deleteFiles, newDeleteFiles, 4);
@@ -322,7 +326,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     assertEquals("Position deletes must match", expectedDeletes, actualDeletes);
   }
 
-  @TestTemplate
+  @Test
   public void testRemoveDanglingDeletes() throws Exception {
     Table table = createTablePartitioned(4, 2, SCALE);
 
@@ -334,15 +338,15 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
         dataFiles,
         true /* Disable commit-time ManifestFilterManager removal of dangling deletes */);
 
-    assertThat(dataFiles).hasSize(4);
+    Assert.assertEquals(4, dataFiles.size());
 
     List<DeleteFile> deleteFiles = deleteFiles(table);
-    assertThat(deleteFiles).hasSize(8);
+    Assert.assertEquals(8, deleteFiles.size());
 
     List<Object[]> expectedRecords = records(table);
     List<Object[]> expectedDeletes = deleteRecords(table);
-    assertThat(expectedRecords).hasSize(12000);
-    assertThat(expectedDeletes).hasSize(4000);
+    Assert.assertEquals(12000, expectedRecords.size());
+    Assert.assertEquals(4000, expectedDeletes.size());
 
     SparkActions.get(spark)
         .rewriteDataFiles(table)
@@ -355,7 +359,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
             .option(SizeBasedFileRewriter.REWRITE_ALL, "true")
             .execute();
     List<DeleteFile> newDeleteFiles = deleteFiles(table);
-    assertThat(newDeleteFiles).as("Should have 0 new delete files").hasSize(0);
+    Assert.assertEquals("Should have 0 new delete files", 0, newDeleteFiles.size());
     assertNotContains(deleteFiles, newDeleteFiles);
     assertLocallySorted(newDeleteFiles);
     checkResult(result, deleteFiles, newDeleteFiles, 4);
@@ -364,24 +368,24 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     List<Object[]> actualRecords = records(table);
     List<Object[]> actualDeletes = deleteRecords(table);
     assertEquals("Rows must match", expectedRecords, actualRecords);
-    assertThat(actualDeletes).as("Should be no new position deletes").hasSize(0);
+    Assert.assertEquals("Should be no new position deletes", 0, actualDeletes.size());
   }
 
-  @TestTemplate
+  @Test
   public void testSomePartitionsDanglingDeletes() throws Exception {
     Table table = createTablePartitioned(4, 2, SCALE);
 
     List<DataFile> dataFiles = TestHelpers.dataFiles(table);
     writePosDeletesForFiles(table, 2, DELETES_SCALE, dataFiles);
-    assertThat(dataFiles).hasSize(4);
+    Assert.assertEquals(4, dataFiles.size());
 
     List<DeleteFile> deleteFiles = deleteFiles(table);
-    assertThat(deleteFiles).hasSize(8);
+    Assert.assertEquals(8, deleteFiles.size());
 
     List<Object[]> expectedRecords = records(table);
     List<Object[]> expectedDeletes = deleteRecords(table);
-    assertThat(expectedRecords).hasSize(12000);
-    assertThat(expectedDeletes).hasSize(4000);
+    Assert.assertEquals(12000, expectedRecords.size());
+    Assert.assertEquals(4000, expectedDeletes.size());
 
     // Rewrite half the data files
     Expression filter = Expressions.or(Expressions.equal("c1", 0), Expressions.equal("c1", 1));
@@ -397,7 +401,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
             .option(SizeBasedFileRewriter.REWRITE_ALL, "true")
             .execute();
     List<DeleteFile> newDeleteFiles = deleteFiles(table);
-    assertThat(newDeleteFiles).as("Should have 2 new delete files").hasSize(2);
+    Assert.assertEquals("Should have 2 new delete files", 2, newDeleteFiles.size());
     assertNotContains(deleteFiles, newDeleteFiles);
     assertLocallySorted(newDeleteFiles);
     checkResult(result, deleteFiles, newDeleteFiles, 4);
@@ -420,23 +424,23 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     assertEquals("Position deletes must match", expectedDeletes, actualDeletes);
   }
 
-  @TestTemplate
+  @Test
   public void testRewriteFilterRemoveDangling() throws Exception {
     Table table = createTablePartitioned(4, 2, SCALE);
     table.refresh();
 
     List<DataFile> dataFiles = TestHelpers.dataFiles(table);
     writePosDeletesForFiles(table, 2, DELETES_SCALE, dataFiles, true);
-    assertThat(dataFiles).hasSize(4);
+    Assert.assertEquals(4, dataFiles.size());
 
     List<DeleteFile> deleteFiles = deleteFiles(table);
-    assertThat(deleteFiles).hasSize(8);
+    Assert.assertEquals(8, deleteFiles.size());
 
     table.refresh();
     List<Object[]> expectedRecords = records(table);
     List<Object[]> expectedDeletes = deleteRecords(table);
-    assertThat(expectedRecords).hasSize(12000); // 16000 data - 4000 delete rows
-    assertThat(expectedDeletes).hasSize(4000);
+    Assert.assertEquals(12000, expectedRecords.size()); // 16000 data - 4000 delete rows
+    Assert.assertEquals(4000, expectedDeletes.size());
 
     SparkActions.get(spark)
         .rewriteDataFiles(table)
@@ -453,7 +457,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
             .execute();
 
     List<DeleteFile> newDeleteFiles = except(deleteFiles(table), deleteFiles);
-    assertThat(newDeleteFiles).as("Should have 2 new delete files").hasSize(0);
+    Assert.assertEquals("Should have 2 new delete files", 0, newDeleteFiles.size());
 
     List<DeleteFile> expectedRewrittenFiles =
         filterFiles(table, deleteFiles, ImmutableList.of(0), ImmutableList.of(1));
@@ -468,35 +472,35 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     assertEquals("Position deletes must match", expectedDeletesFiltered, allDeletes);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionEvolutionAdd() throws Exception {
     Table table = createTableUnpartitioned(2, SCALE);
     List<DataFile> unpartitionedDataFiles = TestHelpers.dataFiles(table);
     writePosDeletesForFiles(table, 2, DELETES_SCALE, unpartitionedDataFiles);
-    assertThat(unpartitionedDataFiles).hasSize(2);
+    Assert.assertEquals(2, unpartitionedDataFiles.size());
 
     List<DeleteFile> unpartitionedDeleteFiles = deleteFiles(table);
-    assertThat(unpartitionedDeleteFiles).hasSize(2);
+    Assert.assertEquals(2, unpartitionedDeleteFiles.size());
 
     List<Object[]> expectedUnpartitionedDeletes = deleteRecords(table);
     List<Object[]> expectedUnpartitionedRecords = records(table);
-    assertThat(expectedUnpartitionedRecords).hasSize(2000);
-    assertThat(expectedUnpartitionedDeletes).hasSize(2000);
+    Assert.assertEquals(2000, expectedUnpartitionedRecords.size());
+    Assert.assertEquals(2000, expectedUnpartitionedDeletes.size());
 
     table.updateSpec().addField("c1").commit();
     writeRecords(table, 2, SCALE, 2);
     List<DataFile> partitionedDataFiles =
         except(TestHelpers.dataFiles(table), unpartitionedDataFiles);
     writePosDeletesForFiles(table, 2, DELETES_SCALE, partitionedDataFiles);
-    assertThat(partitionedDataFiles).hasSize(2);
+    Assert.assertEquals(2, partitionedDataFiles.size());
 
     List<DeleteFile> partitionedDeleteFiles = except(deleteFiles(table), unpartitionedDeleteFiles);
-    assertThat(partitionedDeleteFiles).hasSize(4);
+    Assert.assertEquals(4, partitionedDeleteFiles.size());
 
     List<Object[]> expectedDeletes = deleteRecords(table);
     List<Object[]> expectedRecords = records(table);
-    assertThat(expectedDeletes).hasSize(4000);
-    assertThat(expectedRecords).hasSize(8000);
+    Assert.assertEquals(4000, expectedDeletes.size());
+    Assert.assertEquals(8000, expectedRecords.size());
 
     Result result =
         SparkActions.get(spark)
@@ -508,7 +512,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
         Stream.concat(unpartitionedDeleteFiles.stream(), partitionedDeleteFiles.stream())
             .collect(Collectors.toList());
     List<DeleteFile> newDeleteFiles = deleteFiles(table);
-    assertThat(newDeleteFiles).as("Should have 3 new delete files").hasSize(3);
+    Assert.assertEquals("Should have 3 new delete files", 3, newDeleteFiles.size());
     assertNotContains(rewrittenDeleteFiles, newDeleteFiles);
     assertLocallySorted(newDeleteFiles);
     checkResult(result, rewrittenDeleteFiles, newDeleteFiles, 3);
@@ -520,15 +524,15 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     assertEquals("Position deletes must match", expectedDeletes, actualDeletes);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionEvolutionRemove() throws Exception {
     Table table = createTablePartitioned(2, 2, SCALE);
     List<DataFile> dataFilesUnpartitioned = TestHelpers.dataFiles(table);
     writePosDeletesForFiles(table, 2, DELETES_SCALE, dataFilesUnpartitioned);
-    assertThat(dataFilesUnpartitioned).hasSize(2);
+    Assert.assertEquals(2, dataFilesUnpartitioned.size());
 
     List<DeleteFile> deleteFilesUnpartitioned = deleteFiles(table);
-    assertThat(deleteFilesUnpartitioned).hasSize(4);
+    Assert.assertEquals(4, deleteFilesUnpartitioned.size());
 
     table.updateSpec().removeField("c1").commit();
 
@@ -536,18 +540,18 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     List<DataFile> dataFilesPartitioned =
         except(TestHelpers.dataFiles(table), dataFilesUnpartitioned);
     writePosDeletesForFiles(table, 2, DELETES_SCALE, dataFilesPartitioned);
-    assertThat(dataFilesPartitioned).hasSize(2);
+    Assert.assertEquals(2, dataFilesPartitioned.size());
 
     List<DeleteFile> deleteFilesPartitioned = except(deleteFiles(table), deleteFilesUnpartitioned);
-    assertThat(deleteFilesPartitioned).hasSize(2);
+    Assert.assertEquals(2, deleteFilesPartitioned.size());
 
     List<Object[]> expectedRecords = records(table);
     List<Object[]> expectedDeletes = deleteRecords(table);
-    assertThat(expectedDeletes).hasSize(4000);
-    assertThat(expectedRecords).hasSize(8000);
+    Assert.assertEquals(4000, expectedDeletes.size());
+    Assert.assertEquals(8000, expectedRecords.size());
 
     List<DeleteFile> expectedRewritten = deleteFiles(table);
-    assertThat(expectedRewritten).hasSize(6);
+    Assert.assertEquals(6, expectedRewritten.size());
 
     Result result =
         SparkActions.get(spark)
@@ -555,7 +559,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
             .option(SizeBasedFileRewriter.REWRITE_ALL, "true")
             .execute();
     List<DeleteFile> newDeleteFiles = deleteFiles(table);
-    assertThat(newDeleteFiles).as("Should have 3 new delete files").hasSize(3);
+    Assert.assertEquals("Should have 3 new delete files", 3, newDeleteFiles.size());
     assertNotContains(expectedRewritten, newDeleteFiles);
     assertLocallySorted(newDeleteFiles);
     checkResult(result, expectedRewritten, newDeleteFiles, 3);
@@ -567,15 +571,15 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     assertEquals("Position deletes must match", expectedDeletes, actualDeletes);
   }
 
-  @TestTemplate
+  @Test
   public void testSchemaEvolution() throws Exception {
     Table table = createTablePartitioned(2, 2, SCALE);
     List<DataFile> dataFiles = TestHelpers.dataFiles(table);
     writePosDeletesForFiles(table, 2, DELETES_SCALE, dataFiles);
-    assertThat(dataFiles).hasSize(2);
+    Assert.assertEquals(2, dataFiles.size());
 
     List<DeleteFile> deleteFiles = deleteFiles(table);
-    assertThat(deleteFiles).hasSize(4);
+    Assert.assertEquals(4, deleteFiles.size());
 
     table.updateSchema().addColumn("c4", Types.StringType.get()).commit();
     writeNewSchemaRecords(table, 2, SCALE, 2, 2);
@@ -588,13 +592,13 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     writePosDeletesForFiles(table, 2, DELETES_SCALE, newSchemaDataFiles);
 
     List<DeleteFile> newSchemaDeleteFiles = except(deleteFiles(table), deleteFiles);
-    assertThat(newSchemaDeleteFiles).hasSize(4);
+    Assert.assertEquals(4, newSchemaDeleteFiles.size());
 
     table.refresh();
     List<Object[]> expectedDeletes = deleteRecords(table);
     List<Object[]> expectedRecords = records(table);
-    assertThat(expectedDeletes).hasSize(4000); // 4 files * 1000 per file
-    assertThat(expectedRecords).hasSize(12000); // 4 * 4000 - 4000
+    Assert.assertEquals(4000, expectedDeletes.size()); // 4 files * 1000 per file
+    Assert.assertEquals(12000, expectedRecords.size()); // 4 * 4000 - 4000
 
     Result result =
         SparkActions.get(spark)
@@ -606,7 +610,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
         Stream.concat(deleteFiles.stream(), newSchemaDeleteFiles.stream())
             .collect(Collectors.toList());
     List<DeleteFile> newDeleteFiles = deleteFiles(table);
-    assertThat(newDeleteFiles).as("Should have 2 new delete files").hasSize(4);
+    Assert.assertEquals("Should have 2 new delete files", 4, newDeleteFiles.size());
     assertNotContains(rewrittenDeleteFiles, newDeleteFiles);
     assertLocallySorted(newDeleteFiles);
     checkResult(result, rewrittenDeleteFiles, newDeleteFiles, 4);
@@ -616,43 +620,10 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     assertEquals("Rows must match", expectedRecords, actualRecords);
   }
 
-  @TestTemplate
-  public void testSnapshotProperty() throws Exception {
-    Table table = createTableUnpartitioned(2, SCALE);
-    List<DataFile> dataFiles = TestHelpers.dataFiles(table);
-    writePosDeletesForFiles(table, 2, DELETES_SCALE, dataFiles);
-    assertThat(dataFiles).hasSize(2);
-
-    List<DeleteFile> deleteFiles = deleteFiles(table);
-    assertThat(deleteFiles).hasSize(2);
-
-    Result ignored =
-        SparkActions.get(spark)
-            .rewritePositionDeletes(table)
-            .snapshotProperty("key", "value")
-            .option(SizeBasedFileRewriter.REWRITE_ALL, "true")
-            .execute();
-    assertThat(table.currentSnapshot().summary())
-        .containsAllEntriesOf(ImmutableMap.of("key", "value"));
-
-    // make sure internal produced properties are not lost
-    String[] commitMetricsKeys =
-        new String[] {
-          SnapshotSummary.ADDED_DELETE_FILES_PROP,
-          SnapshotSummary.ADDED_POS_DELETES_PROP,
-          SnapshotSummary.CHANGED_PARTITION_COUNT_PROP,
-          SnapshotSummary.REMOVED_DELETE_FILES_PROP,
-          SnapshotSummary.REMOVED_POS_DELETES_PROP,
-          SnapshotSummary.TOTAL_DATA_FILES_PROP,
-          SnapshotSummary.TOTAL_DELETE_FILES_PROP,
-        };
-    assertThat(table.currentSnapshot().summary()).containsKeys(commitMetricsKeys);
-  }
-
-  @TestTemplate
+  @Test
   public void testRewriteManyColumns() throws Exception {
     List<Types.NestedField> fields =
-        Lists.newArrayList(Types.NestedField.required(0, "id", Types.LongType.get()));
+        Lists.newArrayList(Types.NestedField.optional(0, "id", Types.LongType.get()));
     List<Types.NestedField> additionalCols =
         IntStream.range(1, 1010)
             .mapToObj(i -> Types.NestedField.optional(i, "c" + i, Types.StringType.get()))
@@ -759,10 +730,9 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
   private void writeRecordsWithPartitions(
       Table table, int files, int numRecords, List<List<Integer>> partitions) {
     int partitionTypeSize = table.spec().partitionType().fields().size();
-    assertThat(partitionTypeSize)
-        .as("This method currently supports only two columns as partition columns")
-        .isLessThanOrEqualTo(2);
-
+    Assert.assertTrue(
+        "This method currently supports only two columns as partition columns",
+        partitionTypeSize <= 2);
     BiFunction<Integer, List<Integer>, ThreeColumnRecord> recordFunction =
         (i, partValues) -> {
           switch (partitionTypeSize) {
@@ -870,13 +840,13 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
       List<DataFile> partitionFiles = filesByPartitionEntry.getValue();
 
       int deletesForPartition = partitionFiles.size() * deletesPerDataFile;
-      assertThat(deletesForPartition % deleteFilesPerPartition)
-          .as(
-              "Number of delete files per partition should be "
-                  + "evenly divisible by requested deletes per data file times number of data files in this partition")
-          .isZero();
-
+      Assert.assertEquals(
+          "Number of delete files per partition should be "
+              + "evenly divisible by requested deletes per data file times number of data files in this partition",
+          0,
+          deletesForPartition % deleteFilesPerPartition);
       int deleteFileSize = deletesForPartition / deleteFilesPerPartition;
+
       int counter = 0;
       List<Pair<CharSequence, Long>> deletes = Lists.newArrayList();
       for (DataFile partitionFile : partitionFiles) {
@@ -885,8 +855,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
           counter++;
           if (counter == deleteFileSize) {
             // Dump to file and reset variables
-            OutputFile output =
-                Files.localOutput(File.createTempFile("junit", null, temp.toFile()));
+            OutputFile output = Files.localOutput(temp.newFile());
             deleteFiles.add(FileHelpers.writeDeleteFile(table, output, partition, deletes).first());
             counter = 0;
             deletes.clear();
@@ -931,7 +900,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
     Set<String> rewrittenPaths =
         rewritten.stream().map(f -> f.path().toString()).collect(Collectors.toSet());
     rewrittenPaths.retainAll(originalPaths);
-    assertThat(rewrittenPaths).hasSize(0);
+    Assert.assertEquals(0, rewrittenPaths.size());
   }
 
   private void assertLocallySorted(List<DeleteFile> deleteFiles) {
@@ -940,16 +909,16 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
           spark.read().format("iceberg").load("default." + TABLE_NAME + ".position_deletes");
       deletes.filter(deletes.col("delete_file_path").equalTo(deleteFile.path().toString()));
       List<Row> rows = deletes.collectAsList();
-      assertThat(rows).as("Empty delete file found").isNotEmpty();
+      Assert.assertFalse("Empty delete file found", rows.isEmpty());
       int lastPos = 0;
       String lastPath = "";
       for (Row row : rows) {
         String path = row.getAs("file_path");
         long pos = row.getAs("pos");
         if (path.compareTo(lastPath) < 0) {
-          fail(String.format("File_path not sorted, Found %s after %s", path, lastPath));
+          Assert.fail(String.format("File_path not sorted, Found %s after %s", path, lastPath));
         } else if (path.equals(lastPath)) {
-          assertThat(pos).as("Pos not sorted").isGreaterThanOrEqualTo(lastPos);
+          Assert.assertTrue("Pos not sorted", pos >= lastPos);
         }
       }
     }
@@ -957,8 +926,7 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
 
   private String name(Table table) {
     String[] splits = table.name().split("\\.");
-
-    assertThat(splits).hasSize(3);
+    Assert.assertEquals(3, splits.length);
     return String.format("%s.%s", splits[1], splits[2]);
   }
 
@@ -1036,53 +1004,49 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
       List<DeleteFile> rewrittenDeletes,
       List<DeleteFile> newDeletes,
       int expectedGroups) {
-    assertThat(rewrittenDeletes.size())
-        .as("Expected rewritten delete file count does not match")
-        .isEqualTo(result.rewrittenDeleteFilesCount());
+    Assert.assertEquals(
+        "Expected rewritten delete file count does not match",
+        rewrittenDeletes.size(),
+        result.rewrittenDeleteFilesCount());
+    Assert.assertEquals(
+        "Expected new delete file count does not match",
+        newDeletes.size(),
+        result.addedDeleteFilesCount());
+    Assert.assertEquals(
+        "Expected rewritten delete byte count does not match",
+        size(rewrittenDeletes),
+        result.rewrittenBytesCount());
+    Assert.assertEquals(
+        "Expected new delete byte count does not match",
+        size(newDeletes),
+        result.addedBytesCount());
 
-    assertThat(newDeletes.size())
-        .as("Expected new delete file count does not match")
-        .isEqualTo(result.addedDeleteFilesCount());
-
-    assertThat(size(rewrittenDeletes))
-        .as("Expected rewritten delete byte count does not match")
-        .isEqualTo(result.rewrittenBytesCount());
-
-    assertThat(size(newDeletes))
-        .as("Expected new delete byte count does not match")
-        .isEqualTo(result.addedBytesCount());
-
-    assertThat(expectedGroups)
-        .as("Expected rewrite group count does not match")
-        .isEqualTo(result.rewriteResults().size());
-
-    assertThat(rewrittenDeletes.size())
-        .as("Expected rewritten delete file count in all groups to match")
-        .isEqualTo(
-            result.rewriteResults().stream()
-                .mapToInt(FileGroupRewriteResult::rewrittenDeleteFilesCount)
-                .sum());
-
-    assertThat(newDeletes.size())
-        .as("Expected added delete file count in all groups to match")
-        .isEqualTo(
-            result.rewriteResults().stream()
-                .mapToInt(FileGroupRewriteResult::addedDeleteFilesCount)
-                .sum());
-
-    assertThat(size(rewrittenDeletes))
-        .as("Expected rewritten delete bytes in all groups to match")
-        .isEqualTo(
-            result.rewriteResults().stream()
-                .mapToLong(FileGroupRewriteResult::rewrittenBytesCount)
-                .sum());
-
-    assertThat(size(newDeletes))
-        .as("Expected added delete bytes in all groups to match")
-        .isEqualTo(
-            result.rewriteResults().stream()
-                .mapToLong(FileGroupRewriteResult::addedBytesCount)
-                .sum());
+    Assert.assertEquals(
+        "Expected rewrite group count does not match",
+        expectedGroups,
+        result.rewriteResults().size());
+    Assert.assertEquals(
+        "Expected rewritten delete file count in all groups to match",
+        rewrittenDeletes.size(),
+        result.rewriteResults().stream()
+            .mapToInt(FileGroupRewriteResult::rewrittenDeleteFilesCount)
+            .sum());
+    Assert.assertEquals(
+        "Expected added delete file count in all groups to match",
+        newDeletes.size(),
+        result.rewriteResults().stream()
+            .mapToInt(FileGroupRewriteResult::addedDeleteFilesCount)
+            .sum());
+    Assert.assertEquals(
+        "Expected rewritten delete bytes in all groups to match",
+        size(rewrittenDeletes),
+        result.rewriteResults().stream()
+            .mapToLong(FileGroupRewriteResult::rewrittenBytesCount)
+            .sum());
+    Assert.assertEquals(
+        "Expected added delete bytes in all groups to match",
+        size(newDeletes),
+        result.rewriteResults().stream().mapToLong(FileGroupRewriteResult::addedBytesCount).sum());
   }
 
   private void checkSequenceNumbers(
@@ -1100,9 +1064,10 @@ public class TestRewritePositionDeleteFilesAction extends CatalogTestBase {
       if (addedPartitionFiles != null) {
         addedPartitionFiles.forEach(
             d ->
-                assertThat(d.dataSequenceNumber())
-                    .as("Sequence number should be max of rewritten set")
-                    .isEqualTo(maxRewrittenSeq));
+                Assert.assertEquals(
+                    "Sequence number should be max of rewritten set",
+                    d.dataSequenceNumber(),
+                    maxRewrittenSeq));
       }
     }
   }
