@@ -24,7 +24,6 @@ import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.io.IOException;
 import java.math.RoundingMode;
-import java.nio.file.Path;
 import java.util.List;
 import java.util.Map;
 import org.apache.hadoop.conf.Configuration;
@@ -46,8 +45,8 @@ import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.relocated.com.google.common.math.LongMath;
 import org.apache.iceberg.spark.CommitMetadata;
 import org.apache.iceberg.spark.SparkReadOptions;
+import org.apache.iceberg.spark.SparkTestBaseWithCatalog;
 import org.apache.iceberg.spark.SparkWriteOptions;
-import org.apache.iceberg.spark.TestBaseWithCatalog;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.SnapshotUtil;
 import org.apache.spark.sql.Column;
@@ -57,12 +56,15 @@ import org.apache.spark.sql.Row;
 import org.apache.spark.sql.SaveMode;
 import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
-import org.junit.jupiter.api.AfterAll;
-import org.junit.jupiter.api.BeforeAll;
-import org.junit.jupiter.api.TestTemplate;
-import org.junit.jupiter.api.io.TempDir;
+import org.apache.spark.sql.functions;
+import org.junit.AfterClass;
+import org.junit.Assert;
+import org.junit.BeforeClass;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
 
-public class TestDataSourceOptions extends TestBaseWithCatalog {
+public class TestDataSourceOptions extends SparkTestBaseWithCatalog {
 
   private static final Configuration CONF = new Configuration();
   private static final Schema SCHEMA =
@@ -70,23 +72,23 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
           optional(1, "id", Types.IntegerType.get()), optional(2, "data", Types.StringType.get()));
   private static SparkSession spark = null;
 
-  @TempDir private Path temp;
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
 
-  @BeforeAll
+  @BeforeClass
   public static void startSpark() {
     TestDataSourceOptions.spark = SparkSession.builder().master("local[2]").getOrCreate();
   }
 
-  @AfterAll
+  @AfterClass
   public static void stopSpark() {
     SparkSession currentSpark = TestDataSourceOptions.spark;
     TestDataSourceOptions.spark = null;
     currentSpark.stop();
   }
 
-  @TestTemplate
+  @Test
   public void testWriteFormatOptionOverridesTableProperties() throws IOException {
-    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
+    String tableLocation = temp.newFolder("iceberg-table").toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -109,14 +111,14 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
       tasks.forEach(
           task -> {
             FileFormat fileFormat = FileFormat.fromFileName(task.file().path());
-            assertThat(fileFormat).isEqualTo(FileFormat.PARQUET);
+            Assert.assertEquals(FileFormat.PARQUET, fileFormat);
           });
     }
   }
 
-  @TestTemplate
+  @Test
   public void testNoWriteFormatOption() throws IOException {
-    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
+    String tableLocation = temp.newFolder("iceberg-table").toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -134,14 +136,14 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
       tasks.forEach(
           task -> {
             FileFormat fileFormat = FileFormat.fromFileName(task.file().path());
-            assertThat(fileFormat).isEqualTo(FileFormat.AVRO);
+            Assert.assertEquals(FileFormat.AVRO, fileFormat);
           });
     }
   }
 
-  @TestTemplate
+  @Test
   public void testHadoopOptions() throws IOException {
-    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
+    String tableLocation = temp.newFolder("iceberg-table").toString();
     Configuration sparkHadoopConf = spark.sessionState().newHadoopConf();
     String originalDefaultFS = sparkHadoopConf.get("fs.default.name");
 
@@ -175,15 +177,15 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
       List<SimpleRecord> resultRecords =
           resultDf.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
 
-      assertThat(resultRecords).as("Records should match").isEqualTo(expectedRecords);
+      Assert.assertEquals("Records should match", expectedRecords, resultRecords);
     } finally {
       sparkHadoopConf.set("fs.default.name", originalDefaultFS);
     }
   }
 
-  @TestTemplate
+  @Test
   public void testSplitOptionsOverridesTableProperties() throws IOException {
-    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
+    String tableLocation = temp.newFolder("iceberg-table").toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -207,7 +209,7 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
 
     List<DataFile> files =
         Lists.newArrayList(icebergTable.currentSnapshot().addedDataFiles(icebergTable.io()));
-    assertThat(files).as("Should have written 1 file").hasSize(1);
+    Assert.assertEquals("Should have written 1 file", 1, files.size());
 
     long fileSize = files.get(0).fileSizeInBytes();
     long splitSize = LongMath.divide(fileSize, 2, RoundingMode.CEILING);
@@ -219,14 +221,12 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
             .option(SparkReadOptions.SPLIT_SIZE, String.valueOf(splitSize))
             .load(tableLocation);
 
-    assertThat(resultDf.javaRDD().getNumPartitions())
-        .as("Spark partitions should match")
-        .isEqualTo(2);
+    Assert.assertEquals("Spark partitions should match", 2, resultDf.javaRDD().getNumPartitions());
   }
 
-  @TestTemplate
+  @Test
   public void testIncrementalScanOptions() throws IOException {
-    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
+    String tableLocation = temp.newFolder("iceberg-table").toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -290,34 +290,49 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
             "Cannot set only end-snapshot-id for incremental scans. Please, set start-snapshot-id too.");
 
     // test (1st snapshot, current snapshot] incremental scan.
-    List<SimpleRecord> result =
+    Dataset<Row> unboundedIncrementalResult =
         spark
             .read()
             .format("iceberg")
             .option("start-snapshot-id", snapshotIds.get(3).toString())
-            .load(tableLocation)
+            .load(tableLocation);
+    List<SimpleRecord> result1 =
+        unboundedIncrementalResult
             .orderBy("id")
             .as(Encoders.bean(SimpleRecord.class))
             .collectAsList();
-    assertThat(result).as("Records should match").isEqualTo(expectedRecords.subList(1, 4));
+    assertThat(result1).as("Records should match").isEqualTo(expectedRecords.subList(1, 4));
+    assertThat(unboundedIncrementalResult.count())
+        .as("Unprocessed count should match record count")
+        .isEqualTo(3);
+
+    Row row1 = unboundedIncrementalResult.agg(functions.min("id"), functions.max("id")).head();
+    assertThat(row1.getInt(0)).as("min value should match").isEqualTo(2);
+    assertThat(row1.getInt(1)).as("max value should match").isEqualTo(4);
 
     // test (2nd snapshot, 3rd snapshot] incremental scan.
-    Dataset<Row> resultDf =
+    Dataset<Row> incrementalResult =
         spark
             .read()
             .format("iceberg")
             .option("start-snapshot-id", snapshotIds.get(2).toString())
             .option("end-snapshot-id", snapshotIds.get(1).toString())
             .load(tableLocation);
-    List<SimpleRecord> result1 =
-        resultDf.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    assertThat(result1).as("Records should match").isEqualTo(expectedRecords.subList(2, 3));
-    assertThat(resultDf.count()).as("Unprocessed count should match record count").isEqualTo(1);
+    List<SimpleRecord> result2 =
+        incrementalResult.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
+    assertThat(result2).as("Records should match").isEqualTo(expectedRecords.subList(2, 3));
+    assertThat(incrementalResult.count())
+        .as("Unprocessed count should match record count")
+        .isEqualTo(1);
+
+    Row row2 = incrementalResult.agg(functions.min("id"), functions.max("id")).head();
+    assertThat(row2.getInt(0)).as("min value should match").isEqualTo(3);
+    assertThat(row2.getInt(1)).as("max value should match").isEqualTo(3);
   }
 
-  @TestTemplate
+  @Test
   public void testMetadataSplitSizeOptionOverrideTableProperties() throws IOException {
-    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
+    String tableLocation = temp.newFolder("iceberg-table").toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -334,7 +349,7 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
 
     List<ManifestFile> manifests = table.currentSnapshot().allManifests(table.io());
 
-    assertThat(manifests).as("Must be 2 manifests").hasSize(2);
+    Assert.assertEquals("Must be 2 manifests", 2, manifests.size());
 
     // set the target metadata split size so each manifest ends up in a separate split
     table
@@ -343,7 +358,7 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
         .commit();
 
     Dataset<Row> entriesDf = spark.read().format("iceberg").load(tableLocation + "#entries");
-    assertThat(entriesDf.javaRDD().getNumPartitions()).as("Num partitions must match").isEqualTo(2);
+    Assert.assertEquals("Num partitions must match", 2, entriesDf.javaRDD().getNumPartitions());
 
     // override the table property using options
     entriesDf =
@@ -352,12 +367,12 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
             .format("iceberg")
             .option(SparkReadOptions.SPLIT_SIZE, String.valueOf(128 * 1024 * 1024))
             .load(tableLocation + "#entries");
-    assertThat(entriesDf.javaRDD().getNumPartitions()).as("Num partitions must match").isEqualTo(1);
+    Assert.assertEquals("Num partitions must match", 1, entriesDf.javaRDD().getNumPartitions());
   }
 
-  @TestTemplate
+  @Test
   public void testDefaultMetadataSplitSize() throws IOException {
-    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
+    String tableLocation = temp.newFolder("iceberg-table").toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -386,12 +401,12 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
     Dataset<Row> metadataDf = spark.read().format("iceberg").load(tableLocation + "#entries");
 
     int partitionNum = metadataDf.javaRDD().getNumPartitions();
-    assertThat(partitionNum).as("Spark partitions should match").isEqualTo(expectedSplits);
+    Assert.assertEquals("Spark partitions should match", expectedSplits, partitionNum);
   }
 
-  @TestTemplate
+  @Test
   public void testExtraSnapshotMetadata() throws IOException {
-    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
+    String tableLocation = temp.newFolder("iceberg-table").toString();
     HadoopTables tables = new HadoopTables(CONF);
     tables.create(SCHEMA, PartitionSpec.unpartitioned(), Maps.newHashMap(), tableLocation);
 
@@ -409,14 +424,13 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
 
     Table table = tables.load(tableLocation);
 
-    assertThat(table.currentSnapshot().summary())
-        .containsEntry("extra-key", "someValue")
-        .containsEntry("another-key", "anotherValue");
+    Assert.assertTrue(table.currentSnapshot().summary().get("extra-key").equals("someValue"));
+    Assert.assertTrue(table.currentSnapshot().summary().get("another-key").equals("anotherValue"));
   }
 
-  @TestTemplate
+  @Test
   public void testExtraSnapshotMetadataWithSQL() throws InterruptedException, IOException {
-    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
+    String tableLocation = temp.newFolder("iceberg-table").toString();
     HadoopTables tables = new HadoopTables(CONF);
 
     Table table =
@@ -451,15 +465,15 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
     writerThread.join();
 
     List<Snapshot> snapshots = Lists.newArrayList(table.snapshots());
-    assertThat(snapshots).hasSize(2);
-    assertThat(snapshots.get(0).summary().get("writer-thread")).isNull();
+    Assert.assertEquals(2, snapshots.size());
+    Assert.assertNull(snapshots.get(0).summary().get("writer-thread"));
     assertThat(snapshots.get(1).summary())
         .containsEntry("writer-thread", "test-extra-commit-message-writer-thread")
         .containsEntry("extra-key", "someValue")
         .containsEntry("another-key", "anotherValue");
   }
 
-  @TestTemplate
+  @Test
   public void testExtraSnapshotMetadataWithDelete()
       throws InterruptedException, NoSuchTableException {
     spark.sessionState().conf().setConfString("spark.sql.shuffle.partitions", "1");
@@ -494,9 +508,8 @@ public class TestDataSourceOptions extends TestBaseWithCatalog {
 
     Table table = validationCatalog.loadTable(tableIdent);
     List<Snapshot> snapshots = Lists.newArrayList(table.snapshots());
-
-    assertThat(snapshots).hasSize(2);
-    assertThat(snapshots.get(0).summary().get("writer-thread")).isNull();
+    Assert.assertEquals(2, snapshots.size());
+    Assert.assertNull(snapshots.get(0).summary().get("writer-thread"));
     assertThat(snapshots.get(1).summary())
         .containsEntry("writer-thread", "test-extra-commit-message-delete-thread")
         .containsEntry("extra-key", "someValue")
