@@ -20,11 +20,15 @@ package org.apache.iceberg.spark.extensions;
 
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
 import java.util.stream.IntStream;
+import org.apache.iceberg.CatalogProperties;
+import org.apache.iceberg.EnvironmentContext;
+import org.apache.iceberg.ParameterizedTestExtension;
 import org.apache.iceberg.SnapshotSummary;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.catalog.TableIdentifier;
@@ -36,49 +40,54 @@ import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.spark.ExtendedParser;
 import org.apache.iceberg.spark.SparkCatalogConfig;
 import org.apache.iceberg.spark.SparkTableCache;
+import org.apache.iceberg.spark.SystemFunctionPushDownHelper;
 import org.apache.iceberg.spark.source.ThreeColumnRecord;
 import org.apache.spark.sql.AnalysisException;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.catalyst.analysis.NoSuchProcedureException;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.Test;
+import org.apache.spark.sql.internal.SQLConf;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestRewriteDataFilesProcedure extends ExtensionsTestBase {
 
   private static final String QUOTED_SPECIAL_CHARS_TABLE_NAME = "`table:with.special:chars`";
 
-  public TestRewriteDataFilesProcedure(
-      String catalogName, String implementation, Map<String, String> config) {
-    super(catalogName, implementation, config);
+  @BeforeAll
+  public static void setupSpark() {
+    // disable AQE as tests assume that writes generate a particular number of files
+    spark.conf().set(SQLConf.ADAPTIVE_EXECUTION_ENABLED().key(), "false");
   }
 
-  @After
+  @AfterEach
   public void removeTable() {
     sql("DROP TABLE IF EXISTS %s", tableName);
     sql("DROP TABLE IF EXISTS %s", tableName(QUOTED_SPECIAL_CHARS_TABLE_NAME));
   }
 
-  @Test
+  @TestTemplate
   public void testZOrderSortExpression() {
     List<ExtendedParser.RawOrderField> order =
         ExtendedParser.parseSortOrder(spark, "c1, zorder(c2, c3)");
-    Assert.assertEquals("Should parse 2 order fields", 2, order.size());
-    Assert.assertEquals(
-        "First field should be a ref", "c1", ((NamedReference<?>) order.get(0).term()).name());
-    Assert.assertTrue("Second field should be zorder", order.get(1).term() instanceof Zorder);
+    assertThat(order).as("Should parse 2 order fields").hasSize(2);
+    assertThat(((NamedReference<?>) order.get(0).term()).name())
+        .as("First field should be a ref")
+        .isEqualTo("c1");
+    assertThat(order.get(1).term()).as("Second field should be zorder").isInstanceOf(Zorder.class);
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteDataFilesInEmptyTable() {
     createTable();
     List<Object[]> output = sql("CALL %s.system.rewrite_data_files('%s')", catalogName, tableIdent);
-    assertEquals("Procedure output must match", ImmutableList.of(row(0, 0, 0L)), output);
+    assertEquals("Procedure output must match", ImmutableList.of(row(0, 0, 0L, 0)), output);
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteDataFilesOnPartitionTable() {
     createPartitionTable();
     // create 5 files for each partition (c2 = 'foo' and c2 = 'bar')
@@ -93,7 +102,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 2),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -102,7 +111,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteDataFilesOnNonPartitionTable() {
     createTable();
     // create 10 files under non-partitioned table
@@ -117,7 +126,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -126,7 +135,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteDataFilesWithOptions() {
     createTable();
     // create 10 files under non-partitioned table
@@ -141,14 +150,14 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
 
     assertEquals(
         "Action should rewrite 0 data files and add 0 data files",
-        ImmutableList.of(row(0, 0, 0L)),
+        ImmutableList.of(row(0, 0, 0L, 0)),
         output);
 
     List<Object[]> actualRecords = currentData();
     assertEquals("Data should not change", expectedRecords, actualRecords);
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteDataFilesWithSortStrategy() {
     createTable();
     // create 10 files under non-partitioned table
@@ -167,7 +176,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -176,7 +185,42 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
   }
 
-  @Test
+  @TestTemplate
+  public void testRewriteDataFilesWithSortStrategyAndMultipleShufflePartitionsPerFile() {
+    createTable();
+    insertData(10 /* file count */);
+
+    List<Object[]> output =
+        sql(
+            "CALL %s.system.rewrite_data_files("
+                + " table => '%s', "
+                + " strategy => 'sort', "
+                + " sort_order => 'c1', "
+                + " options => map('shuffle-partitions-per-file', '2'))",
+            catalogName, tableIdent);
+
+    assertEquals(
+        "Action should rewrite 10 data files and add 1 data files",
+        row(10, 1),
+        Arrays.copyOf(output.get(0), 2));
+
+    // as there is only one small output file, validate the query ordering (it will not change)
+    ImmutableList<Object[]> expectedRows =
+        ImmutableList.of(
+            row(1, "foo", null),
+            row(1, "foo", null),
+            row(1, "foo", null),
+            row(1, "foo", null),
+            row(1, "foo", null),
+            row(2, "bar", null),
+            row(2, "bar", null),
+            row(2, "bar", null),
+            row(2, "bar", null),
+            row(2, "bar", null));
+    assertEquals("Should have expected rows", expectedRows, sql("SELECT * FROM %s", tableName));
+  }
+
+  @TestTemplate
   public void testRewriteDataFilesWithZOrder() {
     createTable();
     // create 10 files under non-partitioned table
@@ -194,7 +238,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -217,7 +261,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertEquals("Should have expected rows", expectedRows, sql("SELECT * FROM %s", tableName));
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteDataFilesWithZOrderNullBinaryColumn() {
     sql("CREATE TABLE %s (c1 int, c2 string, c3 binary) USING iceberg", tableName);
 
@@ -235,7 +279,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         "Action should rewrite 10 data files and add 1 data files",
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(snapshotSummary())
         .containsEntry(SnapshotSummary.REMOVED_FILE_SIZE_PROP, String.valueOf(output.get(0)[2]));
     assertThat(sql("SELECT * FROM %s", tableName))
@@ -252,7 +296,43 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
             row(1, "foo", null));
   }
 
-  @Test
+  @TestTemplate
+  public void testRewriteDataFilesWithZOrderAndMultipleShufflePartitionsPerFile() {
+    createTable();
+    insertData(10 /* file count */);
+
+    List<Object[]> output =
+        sql(
+            "CALL %s.system.rewrite_data_files("
+                + " table => '%s', "
+                + "strategy => 'sort', "
+                + " sort_order => 'zorder(c1, c2)', "
+                + " options => map('shuffle-partitions-per-file', '2'))",
+            catalogName, tableIdent);
+
+    assertEquals(
+        "Action should rewrite 10 data files and add 1 data files",
+        row(10, 1),
+        Arrays.copyOf(output.get(0), 2));
+
+    // due to z-ordering, the data will be written in the below order
+    // as there is only one small output file, validate the query ordering (it will not change)
+    ImmutableList<Object[]> expectedRows =
+        ImmutableList.of(
+            row(2, "bar", null),
+            row(2, "bar", null),
+            row(2, "bar", null),
+            row(2, "bar", null),
+            row(2, "bar", null),
+            row(1, "foo", null),
+            row(1, "foo", null),
+            row(1, "foo", null),
+            row(1, "foo", null),
+            row(1, "foo", null));
+    assertEquals("Should have expected rows", expectedRows, sql("SELECT * FROM %s", tableName));
+  }
+
+  @TestTemplate
   public void testRewriteDataFilesWithFilter() {
     createTable();
     // create 10 files under non-partitioned table
@@ -271,7 +351,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(5, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -280,7 +360,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteDataFilesWithDeterministicTrueFilter() {
     createTable();
     // create 10 files under non-partitioned table
@@ -296,7 +376,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -304,7 +384,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteDataFilesWithDeterministicFalseFilter() {
     createTable();
     // create 10 files under non-partitioned table
@@ -323,7 +403,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteDataFilesWithFilterOnPartitionTable() {
     createPartitionTable();
     // create 5 files for each partition (c2 = 'foo' and c2 = 'bar')
@@ -342,7 +422,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(5, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -351,7 +431,39 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
   }
 
-  @Test
+  @TestTemplate
+  public void testRewriteDataFilesWithFilterOnOnBucketExpression() {
+    // currently spark session catalog only resolve to v1 functions instead of desired v2 functions
+    // https://github.com/apache/spark/blob/branch-3.4/sql/catalyst/src/main/scala/org/apache/spark/sql/catalyst/analysis/Analyzer.scala#L2070-L2083
+    assumeThat(catalogName).isNotEqualTo(SparkCatalogConfig.SPARK.catalogName());
+    createBucketPartitionTable();
+    // create 5 files for each partition (c2 = 'foo' and c2 = 'bar')
+    insertData(10);
+    List<Object[]> expectedRecords = currentData();
+
+    // select only 5 files for compaction (files in the partition c2 = 'bar')
+    List<Object[]> output =
+        sql(
+            "CALL %s.system.rewrite_data_files(table => '%s',"
+                + " where => '%s.system.bucket(2, c2) = 0')",
+            catalogName, tableIdent, catalogName);
+
+    assertEquals(
+        "Action should rewrite 5 data files from single matching partition"
+            + "(containing bucket(c2) = 0) and add 1 data files",
+        row(5, 1),
+        row(output.get(0)[0], output.get(0)[1]));
+    // verify rewritten bytes separately
+    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)[2])
+        .isInstanceOf(Long.class)
+        .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
+
+    List<Object[]> actualRecords = currentData();
+    assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
+  }
+
+  @TestTemplate
   public void testRewriteDataFilesWithInFilterOnPartitionTable() {
     createPartitionTable();
     // create 5 files for each partition (c2 = 'foo' and c2 = 'bar')
@@ -370,7 +482,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(5, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -379,7 +491,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteDataFilesWithAllPossibleFilters() {
     createPartitionTable();
     // create 5 files for each partition (c2 = 'foo' and c2 = 'bar')
@@ -436,7 +548,6 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     sql(
         "CALL %s.system.rewrite_data_files(table => '%s'," + " where => 'c2 like \"%s\"')",
         catalogName, tableIdent, "car%");
-
     // TODO: Enable when org.apache.iceberg.spark.SparkFilters have implementations for
     // StringEndsWith & StringContains
     // StringEndsWith
@@ -447,7 +558,40 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     //     " where => 'c2 like \"%s\"')", catalogName, tableIdent, "%car%");
   }
 
-  @Test
+  @TestTemplate
+  public void testRewriteDataFilesWithPossibleV2Filters() {
+    // currently spark session catalog only resolve to v1 functions instead of desired v2 functions
+    // https://github.com/apache/spark/blob/branch-3.4/sql/catalyst/src/main/scala/org/apache/spark/sql/catalyst/analysis/Analyzer.scala#L2070-L2083
+    assumeThat(catalogName).isNotEqualTo(SparkCatalogConfig.SPARK.catalogName());
+
+    SystemFunctionPushDownHelper.createPartitionedTable(spark, tableName, "id");
+    sql(
+        "CALL %s.system.rewrite_data_files(table => '%s',"
+            + " where => '%s.system.bucket(2, data) >= 0')",
+        catalogName, tableIdent, catalogName);
+    sql(
+        "CALL %s.system.rewrite_data_files(table => '%s',"
+            + " where => '%s.system.truncate(4, id) >= 1')",
+        catalogName, tableIdent, catalogName);
+    sql(
+        "CALL %s.system.rewrite_data_files(table => '%s',"
+            + " where => '%s.system.years(ts) >= 1')",
+        catalogName, tableIdent, catalogName);
+    sql(
+        "CALL %s.system.rewrite_data_files(table => '%s',"
+            + " where => '%s.system.months(ts) >= 1')",
+        catalogName, tableIdent, catalogName);
+    sql(
+        "CALL %s.system.rewrite_data_files(table => '%s',"
+            + " where => '%s.system.days(ts) >= date(\"2023-01-01\")')",
+        catalogName, tableIdent, catalogName);
+    sql(
+        "CALL %s.system.rewrite_data_files(table => '%s',"
+            + " where => '%s.system.hours(ts) >= 1')",
+        catalogName, tableIdent, catalogName);
+  }
+
+  @TestTemplate
   public void testRewriteDataFilesWithInvalidInputs() {
     createTable();
     // create 2 files under non-partitioned table
@@ -460,9 +604,8 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
                     "CALL %s.system.rewrite_data_files(table => '%s', options => map('min-input-files','2'), "
                         + "strategy => 'temp')",
                     catalogName, tableIdent))
-        .as("Should reject calls with unsupported strategy error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("unsupported strategy: temp. Only binpack or sort is supported");
+        .hasMessage("unsupported strategy: temp. Only binpack or sort is supported");
 
     // Test for sort_order with binpack strategy
     assertThatThrownBy(
@@ -471,9 +614,8 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'binpack', "
                         + "sort_order => 'c1 ASC NULLS FIRST')",
                     catalogName, tableIdent))
-        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Must use only one rewriter type (bin-pack, sort, zorder)");
+        .hasMessage("Must use only one rewriter type (bin-pack, sort, zorder)");
 
     // Test for sort strategy without any (default/user defined) sort_order
     assertThatThrownBy(
@@ -481,9 +623,8 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
                 sql(
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort')",
                     catalogName, tableIdent))
-        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Cannot sort data without a valid sort order");
+        .hasMessageStartingWith("Cannot sort data without a valid sort order");
 
     // Test for sort_order with invalid null order
     assertThatThrownBy(
@@ -492,9 +633,8 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort', "
                         + "sort_order => 'c1 ASC none')",
                     catalogName, tableIdent))
-        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Unable to parse sortOrder:");
+        .hasMessage("Unable to parse sortOrder: c1 ASC none");
 
     // Test for sort_order with invalid sort direction
     assertThatThrownBy(
@@ -503,9 +643,8 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort', "
                         + "sort_order => 'c1 none NULLS FIRST')",
                     catalogName, tableIdent))
-        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Unable to parse sortOrder:");
+        .hasMessage("Unable to parse sortOrder: c1 none NULLS FIRST");
 
     // Test for sort_order with invalid column name
     assertThatThrownBy(
@@ -514,11 +653,8 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort', "
                         + "sort_order => 'col1 DESC NULLS FIRST')",
                     catalogName, tableIdent))
-        .as("Should reject calls with error message")
         .isInstanceOf(ValidationException.class)
-        .hasMessageContaining(
-            "Cannot find field 'col1' in struct:"
-                + " struct<1: c1: optional int, 2: c2: optional string, 3: c3: optional string>");
+        .hasMessageStartingWith("Cannot find field 'col1' in struct:");
 
     // Test with invalid filter column col1
     assertThatThrownBy(
@@ -526,9 +662,8 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
                 sql(
                     "CALL %s.system.rewrite_data_files(table => '%s', " + "where => 'col1 = 3')",
                     catalogName, tableIdent))
-        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Cannot parse predicates in where option: col1 = 3");
+        .hasMessage("Cannot parse predicates in where option: col1 = 3");
 
     // Test for z_order with invalid column name
     assertThatThrownBy(
@@ -537,9 +672,8 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort', "
                         + "sort_order => 'zorder(col1)')",
                     catalogName, tableIdent))
-        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining(
+        .hasMessage(
             "Cannot find column 'col1' in table schema (case sensitive = false): "
                 + "struct<1: c1: optional int, 2: c2: optional string, 3: c3: optional string>");
 
@@ -550,45 +684,39 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort', "
                         + "sort_order => 'c1,zorder(c2,c3)')",
                     catalogName, tableIdent))
-        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining(
+        .hasMessage(
             "Cannot mix identity sort columns and a Zorder sort expression:" + " c1,zorder(c2,c3)");
   }
 
-  @Test
+  @TestTemplate
   public void testInvalidCasesForRewriteDataFiles() {
     assertThatThrownBy(
             () -> sql("CALL %s.system.rewrite_data_files('n', table => 't')", catalogName))
-        .as("Should not allow mixed args")
         .isInstanceOf(AnalysisException.class)
-        .hasMessageContaining("Named and positional arguments cannot be mixed");
+        .hasMessage("Named and positional arguments cannot be mixed");
 
     assertThatThrownBy(() -> sql("CALL %s.custom.rewrite_data_files('n', 't')", catalogName))
-        .as("Should not resolve procedures in arbitrary namespaces")
         .isInstanceOf(NoSuchProcedureException.class)
-        .hasMessageContaining("not found");
+        .hasMessage("Procedure custom.rewrite_data_files not found");
 
     assertThatThrownBy(() -> sql("CALL %s.system.rewrite_data_files()", catalogName))
-        .as("Should reject calls without all required args")
         .isInstanceOf(AnalysisException.class)
-        .hasMessageContaining("Missing required parameters");
+        .hasMessage("Missing required parameters: [table]");
 
     assertThatThrownBy(
             () -> sql("CALL %s.system.rewrite_data_files(table => 't', table => 't')", catalogName))
-        .as("Should reject duplicate arg names name")
         .isInstanceOf(AnalysisException.class)
-        .hasMessageContaining("Duplicate procedure argument: table");
+        .hasMessageEndingWith("Duplicate procedure argument: table");
 
     assertThatThrownBy(() -> sql("CALL %s.system.rewrite_data_files('')", catalogName))
-        .as("Should reject calls with empty table identifier")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageContaining("Cannot handle an empty identifier");
+        .hasMessage("Cannot handle an empty identifier for parameter 'table'");
   }
 
-  @Test
+  @TestTemplate
   public void testBinPackTableWithSpecialChars() {
-    Assume.assumeTrue(catalogName.equals(SparkCatalogConfig.HADOOP.catalogName()));
+    assumeThat(catalogName).isEqualTo(SparkCatalogConfig.HADOOP.catalogName());
 
     TableIdentifier identifier =
         TableIdentifier.of("default", QUOTED_SPECIAL_CHARS_TABLE_NAME.replaceAll("`", ""));
@@ -610,7 +738,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isEqualTo(
             Long.valueOf(snapshotSummary(identifier).get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -618,12 +746,12 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     List<Object[]> actualRecords = currentData(tableName(QUOTED_SPECIAL_CHARS_TABLE_NAME));
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
 
-    Assert.assertEquals("Table cache must be empty", 0, SparkTableCache.get().size());
+    assertThat(SparkTableCache.get().size()).as("Table cache must be empty").isEqualTo(0);
   }
 
-  @Test
+  @TestTemplate
   public void testSortTableWithSpecialChars() {
-    Assume.assumeTrue(catalogName.equals(SparkCatalogConfig.HADOOP.catalogName()));
+    assumeThat(catalogName).isEqualTo(SparkCatalogConfig.HADOOP.catalogName());
 
     TableIdentifier identifier =
         TableIdentifier.of("default", QUOTED_SPECIAL_CHARS_TABLE_NAME.replaceAll("`", ""));
@@ -649,7 +777,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(
@@ -658,12 +786,12 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     List<Object[]> actualRecords = currentData(tableName(QUOTED_SPECIAL_CHARS_TABLE_NAME));
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
 
-    Assert.assertEquals("Table cache must be empty", 0, SparkTableCache.get().size());
+    assertThat(SparkTableCache.get().size()).as("Table cache must be empty").isEqualTo(0);
   }
 
-  @Test
+  @TestTemplate
   public void testZOrderTableWithSpecialChars() {
-    Assume.assumeTrue(catalogName.equals(SparkCatalogConfig.HADOOP.catalogName()));
+    assumeThat(catalogName).isEqualTo(SparkCatalogConfig.HADOOP.catalogName());
 
     TableIdentifier identifier =
         TableIdentifier.of("default", QUOTED_SPECIAL_CHARS_TABLE_NAME.replaceAll("`", ""));
@@ -689,7 +817,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(
@@ -698,10 +826,10 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     List<Object[]> actualRecords = currentData(tableName(QUOTED_SPECIAL_CHARS_TABLE_NAME));
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
 
-    Assert.assertEquals("Table cache must be empty", 0, SparkTableCache.get().size());
+    assertThat(SparkTableCache.get().size()).as("Table cache must be empty").isEqualTo(0);
   }
 
-  @Test
+  @TestTemplate
   public void testDefaultSortOrder() {
     createTable();
     // add a default sort order for a table
@@ -725,7 +853,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(2, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(3);
+    assertThat(output.get(0)).hasSize(4);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -734,13 +862,13 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteWithUntranslatedOrUnconvertedFilter() {
     createTable();
     assertThatThrownBy(
             () ->
                 sql(
-                    "CALL %s.system.rewrite_data_files(table => '%s', where => 'lower(c2) = \"fo\"')",
+                    "CALL %s.system.rewrite_data_files(table => '%s', where => 'substr(encode(c2, \"utf-8\"), 2) = \"fo\"')",
                     catalogName, tableIdent))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessageContaining("Cannot translate Spark expression");
@@ -748,12 +876,27 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertThatThrownBy(
             () ->
                 sql(
-                    "CALL %s.system.rewrite_data_files(table => '%s', where => 'c2 like \"%%fo\"')",
+                    "CALL %s.system.rewrite_data_files(table => '%s', where => 'substr(c2, 2) = \"fo\"')",
                     catalogName, tableIdent))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessageContaining("Cannot convert Spark filter");
   }
 
+  @TestTemplate
+  public void testRewriteDataFilesSummary() {
+    createTable();
+    // create 10 files under non-partitioned table
+    insertData(10);
+    sql("CALL %s.system.rewrite_data_files(table => '%s')", catalogName, tableIdent);
+
+    Map<String, String> summary = snapshotSummary();
+    assertThat(summary)
+        .containsKey(CatalogProperties.APP_ID)
+        .containsEntry(EnvironmentContext.ENGINE_NAME, "spark")
+        .hasEntrySatisfying(
+            EnvironmentContext.ENGINE_VERSION, v -> assertThat(v).startsWith("3.5"));
+  }
+
   private void createTable() {
     sql("CREATE TABLE %s (c1 int, c2 string, c3 string) USING iceberg", tableName);
   }
@@ -769,6 +912,17 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         TableProperties.WRITE_DISTRIBUTION_MODE_NONE);
   }
 
+  private void createBucketPartitionTable() {
+    sql(
+        "CREATE TABLE %s (c1 int, c2 string, c3 string) "
+            + "USING iceberg "
+            + "PARTITIONED BY (bucket(2, c2)) "
+            + "TBLPROPERTIES ('%s' '%s')",
+        tableName,
+        TableProperties.WRITE_DISTRIBUTION_MODE,
+        TableProperties.WRITE_DISTRIBUTION_MODE_NONE);
+  }
+
   private void insertData(int filesCount) {
     insertData(tableName, filesCount);
   }
